/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.catalog.actions.AddCatalog');

org.ametys.odf.catalog.actions.AddCatalog = function (controlId, controlConfiguration, controlPluginName)
{
    org.ametys.odf.catalog.actions.AddCatalog._createBoxIfNeeded();
	
    org.ametys.odf.catalog.actions.AddCatalog._box.show();
	
    var form = org.ametys.odf.catalog.actions.AddCatalog._form.getForm();
	form.findField("title").setValue("<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CATALOGNAME"/>");
	form.findField("fromCatalog").getStore().load();
	form.findField("title").focus(true, 100);
}

org.ametys.odf.catalog.actions.AddCatalog._createBoxIfNeeded = function ()
{
    if (org.ametys.odf.catalog.actions.AddCatalog._box == null)
    {
    	org.ametys.odf.catalog.actions.AddCatalog._form = new Ext.form.FormPanel ({
    		labelSeparator : '',
			labelAlign: 'right',
			labelWidth: 120,
    		border: false,
    		defaults :{
    			msgTarget: 'side'
    		},
    		
    		items: [
	    		new org.ametys.HtmlContainer ({
	                cls: 'dialog-text-hint',
	                html: "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_HINT"/>"
	            }), 
	    		new org.ametys.form.TextField ({
	                fieldLabel : "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CATALOG_TITLE"/>",
	                name: 'title',
	                id: 'catalog-title-to-create',
	                allowBlank: false,
	                msgTarget: 'side',
	                width: 220
	            }),
	            new org.ametys.form.ComboField ({
	                mode: 'local',
	                forceSelection : true,
		   		 	triggerAction: 'all',
		   		 	
	                fieldLabel : "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_COPY_CATALOG"/>",
	                valueField : 'value',
	                displayField : 'displayText',
	                store: new Ext.data.XmlStore({
	                    url: getPluginDirectUrl('odf') + '/catalogs.xml',
	                    record: 'item',
	                    fields: [
	                        {name: 'value', mapping: 'code'},
	                        {name: 'displayText', mapping: 'title'}
	                    ]
	                }),
	                name: 'fromCatalog',
	                msgTarget: 'side',
	                width: 220
	            })
	    	]	
    	});
    	
        org.ametys.odf.catalog.actions.AddCatalog._box = new org.ametys.DialogBox(
        {
            title: "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_TITLE"/>",
            icon: getPluginResourcesUrl("odf") + "/img/catalog/add_catalog_16.png",
            
            width: 450,
            height: 200,
            autoScroll: true,
            cls: 'text-dialog',
    
            items: [ org.ametys.odf.catalog.actions.AddCatalog._form ],
            
            defaultButton: 'catalog-title-to-create',
            closeAction: 'hide',
            buttons : 
            [
                {
                    text :"<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_OK"/>",
                    handler : org.ametys.odf.catalog.actions.AddCatalog._okFn
                }, {
                    text :"<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CANCEL"/>",
                    parentCmp: this,
                    handler: function() { this.parentCmp._box.hide(); } 
                }
            ]       
        });
    }
}

org.ametys.odf.catalog.actions.AddCatalog._okFn = function()
{
	var form = org.ametys.odf.catalog.actions.AddCatalog._form.getForm();
    if (!form.isValid())
    {
        return;
    }
    
	var params = {};
	params["title"] = form.findField("title").getValue();
	params["catalogToCopy"] = form.findField("fromCatalog").getValue();
	
	org.ametys.odf.catalog.actions.AddCatalog._box.showWaitMsg();
	
	var serverMessage = new org.ametys.servercomm.ServerMessage("odf", 
	        'catalog/create',
	        params,
	        org.ametys.servercomm.ServerComm.PRIORITY_MAJOR,
	        org.ametys.odf.catalog.actions.AddCatalog._creationCb,
	        this, params, "xml");
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.catalog.actions.AddCatalog._creationCb = function(response, params)
{
	org.ametys.odf.catalog.actions.AddCatalog._box.hideWaitMsg();
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CREATIONFAILED'/>", response, "org.ametys.odf.catalog.actions.AddCatalog"))
    {
        return;
    }

    var msg = response.selectSingleNode("ActionResult/message")[org.ametys.servercomm.ServerComm.xmlTextContent];
    if (msg == 'already-exist')
    {
    	Ext.Msg.show ({
    		title: "<i18n:text i18n:key='PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CREATION_ERROR_TITLE'/>",
    		msg: "<i18n:text i18n:key='PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CREATION_ERROR_ALREADY_EXIST'/>",
    		buttons: Ext.Msg.OK,
    		icon: Ext.MessageBox.ERROR
    	});
    	return;
    }
    
    if (msg == 'not-found')
    {
    	Ext.Msg.show ({
    		title: "<i18n:text i18n:key='PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CREATION_ERROR_TITLE'/>",
    		msg: "<i18n:text i18n:key='PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CREATION_ERROR_NOT_FOUND'/>",
    		buttons: Ext.Msg.OK,
    		icon: Ext.MessageBox.ERROR
    	});
    	return;
    }
    
    org.ametys.odf.catalog.actions.AddCatalog._box.hide();
    
    var id = response.selectSingleNode("ActionResult/id")[org.ametys.servercomm.ServerComm.xmlTextContent];
    var title = response.selectSingleNode("ActionResult/title")[org.ametys.servercomm.ServerComm.xmlTextContent];

    var target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("catalog", {'id': id, 'title': title});
    var events = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED, null, [target])];
    org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);
}

