/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.catalog.actions.Delete');

org.ametys.odf.catalog.actions.Delete = function(controlId, controlConfiguration, controlPluginName)
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
    var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) {
        return target.getType() == "catalog";
    });
    
    if (target == null)
    {
        return;
    }
    
    org.ametys.odf.catalog.actions.Delete.pluginName = controlPluginName;
    
    Ext.Msg.confirm("<i18n:text i18n:key="PLUGINS_ODF_CATALOG_DELETE_LABEL"/>", "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_CATALOGACTIONS_DELETE_CONFIRM"/>",
            function(answer)
            {
                if (answer == 'yes')
                {
                	org.ametys.odf.catalog.actions.Delete._doDelete (target.getParameters().id);
                }
            }
        );
}

org.ametys.odf.catalog.actions.Delete._doDelete = function (id)
{
    var serverMessage = new org.ametys.servercomm.ServerMessage(org.ametys.odf.catalog.actions.Delete.pluginName, 
            'catalog/delete',
            {'id': id},
            org.ametys.servercomm.ServerComm.PRIORITY_MAJOR,
            org.ametys.odf.catalog.actions.Delete._deleteCb);
    
    org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);   
}

org.ametys.odf.catalog.actions.Delete._deleteCb = function(response, params)
{
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_CATALOG_CATALOGACTIONS_DELETE_DELETEFAILED' i18n:catalogue="plugin.odf"/>", response, "org.ametys.odf.catalog.actions.Delete"))
    {
        return;
    }
    
    var msg = response.selectSingleNode("ActionResult/message")[org.ametys.servercomm.ServerComm.xmlTextContent];
    if (msg == 'still-referenced')
    {
    	Ext.Msg.show ({
    		title: "<i18n:text i18n:key='PLUGINS_ODF_CATALOG_CATALOGACTIONS_DELETE_ERROR_TITLE'/>",
    		msg: "<i18n:text i18n:key='PLUGINS_ODF_CATALOG_CATALOGACTIONS_DELETE_ERROR_STILL_REFERENCED'/>",
    		buttons: Ext.Msg.OK,
    		icon: Ext.MessageBox.ERROR
    	});
    	return;
    }
    else
    {
        var id = response.selectSingleNode("ActionResult/id")[org.ametys.servercomm.ServerComm.xmlTextContent];

        var targets = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTargets("catalog", {'id': id});
        var events = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED, null, targets)];
        org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);
    }
}

