/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.catalog.actions');

org.ametys.odf.catalog.actions.Rename = function(controlId, controlConfiguration, controlPluginName)
{
    var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
    var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) {
        return target.getType() == "catalog";
    });
    
    if (target == null)
    {
        return;
    }
    
    org.ametys.odf.catalog.actions.Rename.pluginName = controlPluginName;
    
    org.ametys.odf.catalog.actions.Rename._createRenameBoxIfNeeded();
    
    org.ametys.odf.catalog.actions.Rename._box.show();
    
    var form = org.ametys.odf.catalog.actions.Rename._form.getForm();
    form.findField('id').setValue(target.getParameters().id);
    form.findField('title').setValue(target.getParameters().title);
    form.findField('title').focus(100, true);
}

org.ametys.odf.catalog.actions.Rename._createRenameBoxIfNeeded = function ()
{
    if (org.ametys.odf.catalog.actions.Rename._box == null)
    {
    	org.ametys.odf.catalog.actions.Rename._form = new Ext.form.FormPanel ({
    		labelSeparator : '',
			labelAlign: 'right',
			labelWidth: 120,
    		border: false,
    		defaults :{
    			msgTarget: 'side'
    		},
    		
    		items: [
	    		new org.ametys.HtmlContainer ({
	                cls: 'dialog-text-hint',
	                html: "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_CATALOGACTIONS_RENAME_HINT" i18n:catalogue="plugin.odf"/>"
	            }), 
	            new org.ametys.form.TextField ({
	                fieldLabel : "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_CATALOGACTIONS_RENAME_CATALOG_NAME" i18n:catalogue="plugin.odf"/>",
	                name: 'title',
	                allowBlank: false,
	                width: 250
	            }),
	            new Ext.form.Hidden ({
	                name: 'id'
	            })
	    	]
    	});
    	
        org.ametys.odf.catalog.actions.Rename._box = new org.ametys.DialogBox(
        {
            title: "<i18n:text i18n:key="PLUGINS_ODF_CATALOG_CATALOGACTIONS_RENAME_TITLE" i18n:catalogue="plugin.odf"/>",
            icon: getPluginResourcesUrl("odf") + "/img/catalog/catalog_16.png",
            
            width: 450,
            height: 150,
            autoScroll: true,
            cls: 'text-dialog',
    
            layout: 'form',
            labelWidth :120,
    
            items: [ org.ametys.odf.catalog.actions.Rename._form ],
            
            closeAction: 'hide',
            buttons : 
            [
                {
                    text :"<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_OK" i18n:catalogue="plugin.odf"/>",
                    handler : org.ametys.odf.catalog.actions.Rename._renameFn
                }, {
                    text :"<i18n:text i18n:key="PLUGINS_ODF_CATALOG_ADDCATALOGACTION_CANCEL" i18n:catalogue="plugin.odf"/>",
                    handler: function() { org.ametys.odf.catalog.actions.Rename._box.hide(); } 
                }
            ]       
        });
    }
}

org.ametys.odf.catalog.actions.Rename._renameFn = function()
{
	var form = org.ametys.odf.catalog.actions.Rename._form.getForm();
	
	if (!form.isValid())
	{
		 return ;
	}

    var params = {};
    params["title"] = form.findField('title').getValue();
    params["id"] = form.findField('id').getValue();
    
    org.ametys.odf.catalog.actions.Rename._box.showWaitMsg();
    
    var serverMessage = new org.ametys.servercomm.ServerMessage(org.ametys.odf.catalog.actions.Rename.pluginName, 
            'catalog/rename',
            params,
            org.ametys.servercomm.ServerComm.PRIORITY_MAJOR,
            org.ametys.odf.catalog.actions.Rename._renameCb,
            org.ametys.odf.catalog.actions.Rename, params, "xml");
    org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.catalog.actions.Rename._renameCb = function(response, params)
{
    org.ametys.odf.catalog.actions.Rename._box.hideWaitMsg();
    
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_CATALOG_CATALOGACTIONS_RENAME_RENAMEFAILED' i18n:catalogue="plugin.odf"/>", response, "org.ametys.odf.catalog.actions.Rename"))
    {
        return;
    }

    org.ametys.odf.catalog.actions.Rename._box.hide();
    
    var id = response.selectSingleNode("ActionResult/id")[org.ametys.servercomm.ServerComm.xmlTextContent];
    var title = response.selectSingleNode("ActionResult/title")[org.ametys.servercomm.ServerComm.xmlTextContent];
    
    var targets = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTargets("catalog", {'id': id, 'title': title});
    var events = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED, null, targets)];
    org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);
}
