/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.content.Delete');

org.ametys.odf.content.Delete = function (controlId, controlConfiguration, controlPluginName)
{
	org.ametys.odf.content.Delete._pluginName = controlPluginName;
	
	var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[controlId];
	
	var contents = control._currentToDeleteContentsId;
	
	var targets = [];
	for (var i=0; i &lt; contents.length; i++)
	{
		targets.push(org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': contents[i]}));
	}

	Ext.Msg.confirm("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_TITLE"/>", 
					"<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_CONFIRM"/>", 
			function (answer) {
				org.ametys.odf.content.Delete._doAction (answer, contents, targets);
			},
			this
	);
}

org.ametys.odf.content.Delete._doAction = function (answer, contents, targets)
{
	if (answer == 'yes')
	{
		var params = {contentId: contents};
		var uri = '';
		if(contents[0].match("^programContent:")=="programContent:" 
			|| contents[0].match("^subProgramContent:")=="subProgramContent:"
				|| contents[0].match("^container:")=="container:")
		{
			uri = '/program/delete';
		}
		else if(contents[0].match("^courseContent:")=="courseContent:")
		{
			uri = '/course/delete';
		}
		else if(contents[0].match("^orgunitContent:")=="orgunitContent:")
		{
			uri = '/orgunit/delete';
		}
		else if(contents[0].match("^personContent:")=="personContent:")
		{
			uri = '/person/delete';
		}
		
		var serverMessage = new org.ametys.servercomm.ServerMessage(org.ametys.odf.content.Delete._pluginName, uri, params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.content.Delete._callBack, this, [targets]);
		org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
		
		org.ametys.odf.content.Delete._waitMsg = new org.ametys.msg.Mask (Ext.getBody(), "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_WAIT_MSG"/>");
	}
}

org.ametys.odf.content.Delete._callBack = function (response, args)
{
	org.ametys.odf.content.Delete._waitMsg.hide();
	delete org.ametys.odf.content.Delete._waitMsg;
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_ERROR"/>", response, "org.ametys.odf.content.Delete"))
	{
		return;
	}
	
	var canNotDeleteRootOrgUnit = "";
	if(response.selectSingleNode("ActionResult/canNotDeleteRootOrgUnit") != null)
	{
		canNotDeleteRootOrgUnit = response.selectSingleNode("ActionResult/canNotDeleteRootOrgUnit")[org.ametys.servercomm.ServerComm.xmlTextContent];
	}
	var deletedContents = response.selectSingleNode("ActionResult/deleted-contents")[org.ametys.servercomm.ServerComm.xmlTextContent];
	var stillReferencedContents = response.selectSingleNode("ActionResult/still-referenced-contents")[org.ametys.servercomm.ServerComm.xmlTextContent];
	var failDeleteContents = response.selectSingleNode("ActionResult/fail-deleted-contents")[org.ametys.servercomm.ServerComm.xmlTextContent];

	if (stillReferencedContents == "" &amp;&amp; failDeleteContents == "")
	{
		var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED, null, args[0]);
		org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
	}
	var msg = "";
	if(canNotDeleteRootOrgUnit == "true")
	{
		msg += "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_CAN_NOT_DELETE_ROOT_ORGUNIT"/>";
	}
	if (deletedContents != "" || stillReferencedContents != "" || failDeleteContents != "")
	{
	    var icon = Ext.MessageBox.INFO;
	    
		if (deletedContents != "")
		{
			msg += "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_DELETED_CONTENTS"/>" + deletedContents;
		}
		
		if (stillReferencedContents != "")
		{
			icon = Ext.MessageBox.WARNING;
			
			if (msg != '')
			{
				msg += "&lt;br/&gt;&lt;br/&gt;";
			}
			msg += "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_STILL_REFERENCED_CONTENTS"/>" + stillReferencedContents;
		}
		
		if (failDeleteContents != "")
		{
		    icon = Ext.MessageBox.ERROR;
		    
			if (msg != '')
			{
				msg += "&lt;br/&gt;&lt;br/&gt;";
			}
			msg += "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_FAILED_CONTENTS"/>" + failDeleteContents;
		}
		
		Ext.Msg.show({
			   title: "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_DELETE_MSGBOX_TITLE"/>",
			   msg: msg,
			   buttons: Ext.Msg.OK,
			   icon: icon
		});
		return;
	}
}



