/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.content');

org.ametys.odf.content.Translate = function (control, state, configuration, index)
{
    org.ametys.odf.content.Translate._pluginName = control.ribbonControl._pluginName;
    org.ametys.odf.content.Translate._lang = configuration['gallery-' + index];
    org.ametys.odf.content.Translate._langLabel = configuration['gallery-' + index + '-label'];
    org.ametys.odf.content.Translate._fullCopy = false;
    
    org.ametys.odf.content.Translate.translate();
}

org.ametys.odf.content.TranslateFull = function (control, state, configuration, index)
{
    org.ametys.odf.content.Translate._pluginName = control.ribbonControl._pluginName;
    org.ametys.odf.content.Translate._lang = configuration['gallery-' + index];
    org.ametys.odf.content.Translate._langLabel = configuration['gallery-' + index + '-label'];
    org.ametys.odf.content.Translate._fullCopy = true;
    
    org.ametys.odf.content.Translate.translate();
}

org.ametys.odf.content.Translate.translate = function (control, state, configuration, index)
{
    var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
    var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == 'content' &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.program';});
    
    if (target != null)
    {
        org.ametys.odf.content.Translate._waitMsg = new org.ametys.msg.Mask (Ext.getBody(), "<i18n:text i18n:key="PLUGINS_ODF_UITOOL_TRANSLATE_WAITING_MESSAGE" i18n:catalogue='plugin.odf'/>");
        
        var params = {};
        params.contentId = target.getParameters().id;
        params.language = org.ametys.odf.content.Translate._lang;
        params.full = org.ametys.odf.content.Translate._fullCopy;
        
        var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/program/translate', params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.content.Translate._translateCb, this, params, 'xml');
        org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
    }
}

org.ametys.odf.content.Translate._translateCb = function(response, params)
{
    org.ametys.odf.content.Translate._waitMsg.hide();
    delete org.ametys.odf.content.Translate._waitMsg;
    
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:catalogue="plugin.odf" i18n:key="PLUGINS_ODF_UITOOL_TRANSLATE_ERROR"/>", response, 'org.ametys.odf.content.Translate'))
    {
        return;
    }
    
    var error = response.selectSingleNode('ActionResult/error')[org.ametys.servercomm.ServerComm.xmlTextContent];
    var contentId = response.selectSingleNode('ActionResult/translated-program-id')[org.ametys.servercomm.ServerComm.xmlTextContent];
    
    if (error == 'same-language')
    {
        Ext.Msg.show({
            title: "<i18n:text i18n:catalogue="plugin.odf" i18n:key="PLUGINS_ODF_UITOOL_TRANSLATE_TITLE"/>",
            msg: "<i18n:text i18n:catalogue="plugin.odf" i18n:key="PLUGINS_ODF_UITOOL_TRANSLATE_ERROR_SAME_LANGUAGE"/>",
            buttons: Ext.Msg.OK,
            icon: Ext.Msg.ERROR
        });
        return;
    }
    
    var alreadyExists = response.selectSingleNode('ActionResult/already-exists')[org.ametys.servercomm.ServerComm.xmlTextContent];
    var msg = alreadyExists != 'true' ? "<i18n:text i18n:catalogue="plugin.odf" i18n:key="PLUGINS_ODF_UITOOL_TRANSLATE_SUCCESS"/>" : "<i18n:text i18n:catalogue="plugin.odf" i18n:key="PLUGINS_ODF_UITOOL_TRANSLATE_ALREADY_EXIST"/>";
    Ext.Msg.show({
        title: "<i18n:text i18n:catalogue="plugin.odf" i18n:key="PLUGINS_ODF_UITOOL_TRANSLATE_TITLE"/>",
        msg: msg,
        buttons: Ext.Msg.OK,
        icon: Ext.Msg.INFO
    });
    
    // Open the tool.
    if (contentId != '')
    {
        org.ametys.uitool.ToolsManager.getInstance().openTool('uitool-content', {id: contentId});
    }
}
