/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.course');

org.ametys.odf.course.CourseSearchTool = function(id, pluginName) 
{
	org.ametys.odf.course.CourseSearchTool.superclass.constructor.call(this, id, pluginName);
};

Ext.extend(org.ametys.odf.course.CourseSearchTool, org.ametys.cms.tool.search.SearchTool, {});

org.ametys.odf.course.CourseSearchTool.prototype._preventFireMessage = false;

org.ametys.odf.course.CourseSearchTool.prototype._fireMessages = function (sm)
{
	if (this._preventFireMessage)
	{
		this._preventFireMessage = false;
		return;
	}
	org.ametys.odf.course.CourseSearchTool.superclass._fireMessages.call(this, sm);
}

org.ametys.odf.course.CourseSearchTool.prototype.onMessage = function (messages)
{
	org.ametys.odf.course.CourseSearchTool.superclass.onMessage.call(this, messages);
	
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._testTarget);
			
			if (target == null)
				return;
			
			if (this._currentContent == target.getParameters().id)
			{
				return;
			}
			
			var record = this._resultGrid.getStore().getById (target.getParameters().id);
			if (record == null)
			{
				this._currentContent = null;
				this._preventFireMessage = true;
				this._resultGrid.getSelectionModel().clearSelections();
			}
			else
			{
				this._currentContent = target.getParameters().id;
				this._preventFireMessage = true;
				this._resultGrid.getSelectionModel().selectRecords([record]);
			}
		}
	}
}

org.ametys.odf.course.CourseSearchTool.prototype._testTarget = function (target)
{
	return target.getType() == "content" &amp;&amp; target.getParameters().type == "org.ametys.plugins.odf.Content.course";
}

org.ametys.odf.course.CourseSearchTool.renderLanguage = function (value, p, record)
{
	return '&lt;img src="' + context.contextPath + record.data['language-image'] + '" style="float:left; margin-right: 5px" alt="' + value + '"/&gt;';
}

org.ametys.odf.course.CourseSearchTool.renderMultipleMetadata = function (value, p, record)
{
	var displayValue = "";
	
	var nodeValues = [];
	if (record.data[this.dataIndex + '_sync'] == 'true')
	{
		nodeValues = record.node.selectNodes("metadata/" + this.dataIndex + '_remote');
	}
	else
	{
		nodeValues = record.node.selectNodes("metadata/" + this.dataIndex);
	}
	
	for (var i=0; i &lt; nodeValues.length; i++)
	{
		if (i != 0)
		{
			displayValue += ", "
		}
		displayValue += nodeValues[i][org.ametys.servercomm.ServerComm.xmlTextContent];
	}
	
	return displayValue;
}
