/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.course');

org.ametys.odf.course.CourseTree = function(id, pluginName) 
{
	org.ametys.odf.course.CourseTree.superclass.constructor.call(this, id, pluginName);
};

Ext.extend(org.ametys.odf.course.CourseTree, org.ametys.uitool.tool.Tool, {});

org.ametys.odf.course.CourseTree.prototype._metAnError = false;
org.ametys.odf.course.CourseTree.prototype._refreshing = false;

org.ametys.odf.course.CourseTree.prototype.createPanel = function()
{	
	var loader = new org.ametys.odf.course.CourseXmlLoader ({
		dataUrl : getPluginDirectUrl('odf') + '/course-tree.xml' 
	});	
	
	this._tree = new Ext.tree.TreePanel({
		region: 'center',
		split:true,
		border: false,
		
		autoScroll:true,
	    animate:true,
	    
	    enableDD:true,
	    ddAppendOnly: true,
	    containerScroll: true,
		
		loader: loader,
		
		root: new Ext.tree.TreeNode (),
        rootVisible : true
	});
	
	this._tree.addListener ('blur', this._onBlur, this);
	this._tree.addListener ('focus', this._onFocus, this);
	
	this._tree.addListener ('beforemovenode', this._moveNode, this);
	this._tree.getSelectionModel().addListener('selectionchange', this._onSelectionChange, this);
	this._tree.getLoader().addListener("beforeload", this._beforeLoad, this);
	this._tree.addListener("afterrender", this._refreshTree, this);
	
	return this._tree;
}

/**
 * Listener when the panel receives the focus
 * Change the ribbon title and send a selection message
 * @private
 */
org.ametys.odf.course.CourseTree.prototype._onFocus = function ()
{
	this._hasFocus = true;

	if (this._tree != null)
	{
		var node = this._tree.getSelectionModel().getSelectedNode();
		if (node != null)
		{
			this._currentNode = node;
			this._sendMessage(node);
		}
	}
}
/**
 * Listener when the panel looses the focus
 * Change the ribbon title.
 * @private
 */
org.ametys.odf.course.CourseTree.prototype._onBlur = function ()
{
	this._hasFocus = false;
}


org.ametys.odf.course.CourseTree.prototype.setParams = function (params)
{
	this._params = params;
}

org.ametys.odf.course.CourseTree.prototype._createRootNode = function ()
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.course'});
	
	if (target == null)
		return new Ext.tree.TreeNode ();
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/course', {'id': target.getParameters().id}, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	// TODO Handle error
	
	var rootNode = new Ext.tree.AsyncTreeNode({
        text: target.getParameters().title,
        id: target.getParameters().id,
        name: response.selectSingleNode('course').getAttribute('name'),
        path: response.selectSingleNode('course').getAttribute('path'),
        icon: getPluginResourcesUrl ('odf') + '/img/course/elp_16.png',
        type: 'course'
    });
	
	return rootNode;
}

org.ametys.odf.course.CourseTree.prototype._onSelectionChange = function (sm, node)
{
	this._sendMessage (node);
}

org.ametys.odf.course.CourseTree.prototype._sendMessage = function (node)
{
	var target = null;
    if (node != null)
    {
    	var id = node.id;
    	var type = node.attributes.type;
    	if (type == 'courselist')
    	{
    		target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("course-list", {'id': id, 'name': node.attributes.name, 'title': node.attributes.title, 'lang': node.attributes.lang});
    	}
    	else
    	{
    		target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': id, 'parentList': node.parentNode != null ? node.parentNode.id : null});
    	}
    }
	
	var message = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, target != null ? [target] : []);
	org.ametys.messagebus.MessageBus.getInstance().fireMessages([message]);
}

org.ametys.odf.course.CourseTree.prototype._selectNode = function (id, callback, args)
{
	var node = this._tree.getNodeById(id);
	if (node != null)
	{
		node.select();
	}
}

/**
 * Refresh a node
 * @param id the id of the node to refresh
 */
org.ametys.odf.course.CourseTree.prototype._refreshNode = function (id, callback, args)
{
	var node = this._tree.getNodeById(id);
	if (node != null)
	{
		if (typeof callback == 'function')
		{
			node.reload(callback.createDelegate(this, args));
		}
		else
		{
			node.reload();
		}
	}
}

/**
 * Delete a node
 * @param id the id of the node to delete
 */
org.ametys.odf.course.CourseTree.prototype._deleteNode = function (id)
{
	if (this._tree)
	{
		var node = this._tree.getNodeById(id);
		if (node != null)
		{
			var parentNode = node.parentNode;
			node.remove();
			
			if (parentNode != null)
			{
				parentNode.select();
			}
		}
	}
}

org.ametys.odf.course.CourseTree.prototype._moveNode = function (tree, node, oldParent, newParent, index)
{
	if (node.attributes.type == 'courselist')
	{
		// A course list can not be moved : cancel the move
		return false;
	}
	
	if (newParent.attributes.type != 'courselist')
	{
		// A course can be moved only on a list: cancel the move
		return false;
	}
	
	var params = {};
	params.id = node.id;
	params.oldParent = oldParent.id;
	params.newParent = newParent.id;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/course/move', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_COURSE_TREE_ERROR_MOVE"/>", response, "org.ametys.odf.course.CourseTree.move"))
	{
		// Cancel the mode
		return false;
	}
}

org.ametys.odf.course.CourseTree.prototype._updateNodeText = function (id, text)
{
	if (this._tree)
	{
		var node = this._tree.getNodeById(id);
		if (node != null)
		{
			node.setText(text);
		}
	}
}

org.ametys.odf.course.CourseTree.prototype._isInTree = function (id)
{
	return this._tree.getNodeById(id) != null;
}

org.ametys.odf.course.CourseTree.prototype._beforeLoad = function (treeLoader, node)
{
    treeLoader.baseParams.id = node.attributes.id;	
}

org.ametys.odf.course.CourseTree.prototype._onRender = function ()
{
	this._outOfDate = true;
	this.refresh();
}

org.ametys.odf.course.CourseTree.prototype._refreshTree = function ()
{
	var rootNode = this._createRootNode ();
	this._tree.setRootNode(rootNode);
	
	this._tree.getRootNode().reload();
	this._tree.getRootNode().expand();
	
	this._tree.getRootNode().select();
	
	this._refreshing = false;
	this.metAnError = false;
	this.upToDate();
}
/**
 * Refresh the tool
 * @params manual true if the refresh action was called by manually action
 */
org.ametys.odf.course.CourseTree.prototype.refresh = function (manual)
{
	if (manual)
	{
		this._metAnError = false;
	}
	
	if (this._refreshing)
	{
		// The view is refreshing, but let it
	}
	
	this.refreshing();
	
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.course'});

	if (target != null)
	{
		if (this._currentContent == target.getParameters().id &amp;&amp; this.metAnError)
		{
			// Do not refresh the same parameters with an error
			this.upToDate();
			return;
		}
		
		// Change the current content
		this._currentContent = target.getParameters().id;
		this._refreshing = true;
		
		this._refreshTree();
	}
	else
	{
		this._setInNoSelectionState();
		this.upToDate();
	}
}

org.ametys.odf.course.CourseTree.prototype.onMessage = function (messages)
{
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.course'});
			
			if (target == null)
				return;

			if (this._currentContent == target.getParameters().id)
			{
				// target is the same as before
				if (!this.metAnError)
				{
					this.upToDate();
				}
			}
			else if (this._isInTree (target.getParameters().id))
			{
				this._selectNode(target.getParameters().id);
			}
			else if (this._currentContent != target.getParameters().id)
			{
				// target has changed
				this.outOfDate(true);
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "course-list";});
			
			if (target == null)
				return;
			
			var node = this._tree.getNodeById(target.getParameters().parentId);
			this._refreshNode (target.getParameters().parentId, this._selectNode, [target.getParameters().id]);
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "course-list";});
			
			if (target == null)
				return;
			
			if (target.getParameters().name)
			{
				this._updateNodeText (target.getParameters().id, target.getParameters().name);
			}
			this._refreshNode (target.getParameters().id);
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "course-list";});
			
			if (target == null)
				return;
			
			this._deleteNode (target.getParameters().id);
		}
	}
}

org.ametys.odf.course.CourseTree.prototype._setInNoSelectionState = function()
{
	this._currentContent = null;
	this._tree.setRootNode(new Ext.tree.TreeNode({
		text: '&lt;i&gt;' + 'Sélectionnez un élément pédagogique' + '&lt;i&gt;',
		icon: getPluginResourcesUrl ('odf') + '/img/course/elp_16.png'
	})); // FIXME I18n
	this._metAnError = false;
}
