/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Ext.namespace('org.ametys.odf.course.workflow');

org.ametys.odf.course.workflow.ValidateAction = function ()
{
}

org.ametys.odf.course.workflow.ValidateAction.act = function()
{
	var params = this.ribbonControl._lastParams;
	
	if (this.contents.length &gt; 1)
	{
		Ext.Msg.show({
			title: "<i18n:text i18n:key="PLUGINS_ODF_WORKFLOW_VALIDATE"/>",
			msg: "<i18n:text i18n:key="PLUGINS_ODF_WORKFLOW_SELECTION_ERROR"/>",
			buttons: Ext.Msg.INFO,
			icon: Ext.MessageBox.ERROR
		});
		
		return;
	}
	
	var alreadySent = org.ametys.odf.course.workflow.ValidateAction._isSent (this.contents[0]);
	
	if (alreadySent)
	{
		// Validate and re-sent the newsletter ?
		Ext.Msg.confirm("<i18n:text i18n:key="PLUGINS_ODF_WORKFLOW_VALIDATE"/>", 
				"<i18n:text i18n:key="PLUGINS_ODF_WORKFLOW_VALIDATE_CONFIRM"/>", 
				function (answer) {
					org.ametys.odf.course.workflow.ValidateAction._doAction (this.contents[0], this.actionId, this.ribbonControl, answer == 'yes');
				},
				this
		);
	}
	else
	{
		// Send and validate newsletter
		Ext.Msg.confirm("<i18n:text i18n:key="PLUGINS_ODF_WORKFLOW_VALIDATE"/>", 
				"<i18n:text i18n:key="PLUGINS_ODF_WORKFLOW_VALIDATE_AND_SEND_CONFIRM"/>", 
				function (answer) {	
					if (answer == 'yes')
					{
						org.ametys.odf.course.workflow.ValidateAction._doAction (this.contents[0], this.actionId, this.ribbonControl, true);
					}
					// else cancel the action
				},
				this
		);
	}
	
}

org.ametys.odf.course.workflow.ValidateAction._doAction = function (contentId, actionId, ribbonControl, send)
{
	var params = {'contentId': contentId};
	if (send)
	{
		params['send'] = true;
	}
	
	var target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': contentId});
	
	var serverMessage = new org.ametys.servercomm.ServerMessage("cms", "do-action/" + actionId, params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, ribbonControl.workflowActionCallback, ribbonControl, {content: contentId, max: 1});
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGING, null, [target]);
	org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
}

/**
 * Determines if a newsletter was already sent
 * @param id the content id
 * @return true if the newsletter was already sent
 * @private
 */
org.ametys.odf.course.workflow.ValidateAction._isSent = function (contentId)
{
	var serverMessage = new org.ametys.servercomm.ServerMessage("newsletter", "is-sent", {id: contentId}, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (response == null || response.getAttribute("code") == "500" || response.getAttribute("code") == "404")
	{
		// TODO
		return null;
	}
	
	return response.selectSingleNode("ActionResult/sent")[org.ametys.servercomm.ServerComm.xmlTextContent] == 'true';
}

