/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.courselist.AddCourses');
Ext.namespace('org.ametys.odf.courselist.DeleteCourses');

org.ametys.odf.courselist.AddCourses.search = function (control, configuration, index) // (controlId, controlConfiguration, pluginName)
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == 'course-list'});
	if (target == null)
		return;
	
	org.ametys.odf.courselist.AddCourses._courseListId = target.getParameters().id;
	
	org.ametys.odf.helper.ChooseCourseBySearch ("<i18n:text i18n:key="PLUGINS_ODF_COURSE_LIST_ADD_COURSE_DIALOG_TITLE"/>",
			getPluginResourcesUrl('odf') + '/img/course/elp_16.png',
			"<i18n:text i18n:key="PLUGINS_ODF_COURSE_LIST_ADD_COURSE_DIALOG_MSG1"/>",
			"<i18n:text i18n:key="PLUGINS_ODF_COURSE_LIST_ADD_COURSE_DIALOG_MSG2"/>",
			typeof(control) == 'string' ? configuration['search-factory-role'] : configuration['menu-' + index + '-search-factory-role'],
			org.ametys.odf.courselist.AddCourses._chooseCourseCb,
			true, // multiple selections
			target.getParameters().lang // language
	); 
}

org.ametys.odf.courselist.AddCourses._chooseCourseCb = function (courseIds)
{
	var params = {};
	params.id = org.ametys.odf.courselist.AddCourses._courseListId;
	params.courseIds = courseIds;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/add-course-to-list', params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.courselist.AddCourses._cb, this, [org.ametys.odf.courselist.AddCourses._courseListId]);
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.courselist.AddCourses._cb = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_COURSE_LIST_ADD_COURSE_ERROR"/>", response, "org.ametys.odf.courselist.AddCourses"))
	{
		return;
	}
	
	var target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("course-list", {'id': args[0]});
	var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED, null, [target]);
	org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
}

//----------------------------------------------------------------------------
org.ametys.odf.courselist.AddCourses.create = function (controlId, controlConfiguration, index)
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == 'course-list'});
	if (target == null)
		return;
	
	org.ametys.odf.courselist.AddCourses._courseListId = target.getParameters().id;
	
	org.ametys.cms.buttons.content.CreateContentAction._index = index;
	org.ametys.cms.buttons.content.CreateContentAction._configuration = controlConfiguration;
	// @Override 'ok' function
	org.ametys.cms.buttons.content.CreateContentAction._okFn = org.ametys.odf.courselist.AddCourses._okCreate;
	
	org.ametys.cms.buttons.content.CreateContentAction._createBoxIfNeeded();
	
	// Override title and icon
	org.ametys.cms.buttons.content.CreateContentAction._box.setTitle("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATEUEACTION_TITLE"/>" + "...");
	org.ametys.cms.buttons.content.CreateContentAction._box.setIconPath(getPluginResourcesUrl("odf") + "/img/course/elp_16.png");
	Ext.getCmp("content-type-to-create").setValue(controlConfiguration["menu-" + index + "-content-type-to-create"]);
	Ext.getCmp("content-language-to-create").setValue("");
	
	org.ametys.cms.buttons.content.CreateContentAction._box.show();
	
	var f = Ext.getCmp("content-name-to-create");
	f.setValue("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATECONTENTACTION_CONTENTNAME"/>");
	f.focus(true, 100);
}

org.ametys.odf.courselist.AddCourses._okCreate = function ()
{
	var actionId = org.ametys.cms.buttons.content.CreateContentAction._configuration["menu-" + org.ametys.cms.buttons.content.CreateContentAction._index + "-workflowInitActionId"];
	
	var params = org.ametys.odf.courselist.AddCourses._getParams();
	if (params == null)
	{
		return;
	}
	
	org.ametys.cms.buttons.content.CreateContentAction._box.showWaitMsg();
	
	var serverMessage = new org.ametys.servercomm.ServerMessage("cms", 'init-workflow/' + actionId, params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.courselist.AddCourses._createCb, this, params, "xml");
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.courselist.AddCourses._createCb = function (response, params)
{
	org.ametys.cms.buttons.content.CreateContentAction._box.hideWaitMsg();
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_COURSE_CREATIONFAILED"/>", response, "org.ametys.odf.program.AddCourseAction"))
	{
		return;
	}
	
	org.ametys.cms.buttons.content.CreateContentAction._box.hide();
	
	var newContentId = response.selectSingleNode("ActionResult/contentId")[org.ametys.servercomm.ServerComm.xmlTextContent];
	var targets = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': newContentId})];

	var events = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED, {'parentId': org.ametys.odf.courselist.AddCourses._courseListId}, targets)];
	org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);
	
	org.ametys.cms.buttons.content.CreateContentAction._finalizeCreation (response, params);
}

org.ametys.odf.courselist.AddCourses._getParams = function()
{
	var nameField = Ext.getCmp("content-name-to-create"); 
	if (!nameField.isValid())
	{
		return null;
	}
	
	var params = {};
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentName"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentTitle"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentType"] = Ext.getCmp("content-type-to-create").getValue();
	
	for (var c in org.ametys.cms.buttons.content.CreateContentAction._configuration)
	{
		var prefix = "menu-" + org.ametys.cms.buttons.content.CreateContentAction._index + "-";
		if (c.indexOf(prefix + "workflow-") == 0)
		{
			params[c.substring(prefix.length)] = org.ametys.cms.buttons.content.CreateContentAction._configuration[c];
		}
	}
	
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" });
	params["workflow-org.ametys.odf.workflow.CreateODFContentFunction$parentId"] = org.ametys.odf.courselist.AddCourses._courseListId;
	
	return params;
}
// ----------------------------------------------------------------------------
org.ametys.odf.courselist.DeleteCourse = function (controlId, controlConfiguration, controlPluginName)
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == 'content' &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.course';});
	if (target == null || target.getParameters().parentList == null)
		return;	
	
	Ext.Msg.confirm("<i18n:text i18n:key="PLUGINS_ODF_COURSE_DELETE_FROM_LIST"/>", 
			"<i18n:text i18n:key="PLUGINS_ODF_COURSE_DELETE_FROM_LIST_CONFIRM"/>", 
			function (answer) 
			{
				if (answer == 'yes')
				{
					org.ametys.odf.courselist.DeleteCourse._confirm (target.getParameters().parentList, target.getParameters().id);
				}
			},
			this
	);
}

org.ametys.odf.courselist.DeleteCourse._confirm = function (id, courseId)
{
	var params = {};
	params.id = id;
	params.courseId = courseId;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/delete-course-from-list', params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.courselist.DeleteCourse._cb, this, [id]);
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.courselist.DeleteCourse._cb = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_COURSE_DELETE_FROM_LIST_ERROR"/>", response, "org.ametys.odf.courselist.DeleteCourse"))
	{
		return;
	}
	
	var target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("course-list", {'id': args[0]});
	var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED, null, [target]);
	org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
}

