/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.dashboard.tool');

org.ametys.odf.dashboard.tool.ProgramDashboardTool = function(id, pluginName) 
{
    org.ametys.odf.dashboard.tool.ProgramDashboardTool.superclass.constructor.call(this, id, pluginName);
};

Ext.extend(org.ametys.odf.dashboard.tool.ProgramDashboardTool, org.ametys.uitool.tool.Tool, {});

//org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._proxy;
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._tasks;
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._grids;

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._prefixId = 'program-dashboard-';

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype.createPanel = function()
{
    this._tasks = this._getTasks();
    this._grids = [];
    
    
    var taskPanels = [];
    for (var taskId in this._tasks)
    {
        if (taskId != 'recent-drafts')
        {
            var taskLabel = this._tasks[taskId];
            taskPanels.push(
                new Ext.Panel({
                    id: this._prefixId + taskId + '-panel',
                    title: taskLabel,
                    cls: 'transparent-panel',
                    layout: 'border',
                    border: false,
                    items: [this._drawGridPanel(taskId, taskLabel, 10)]
                })
            );
        }
    }
    
    this._mainPanel = new Ext.Panel ({
        layout: 'border',
        layoutConfig: {
            columns: 1
        },
        autoScroll: true,
        cls: 'dashboard-panel',
        border: false,
        
        items: [
            new Ext.Panel({
                id: this._prefixId + 'recent-drafts-panel',
                region: 'north',
                cls: 'draft-panel',
                border: false,
                title: this._tasks['recent-drafts'],
                height: 200,
                items: [this._lastDraftPanel('recent-drafts', this._tasks['recent-drafts'], 5)]
            }),
            
            new Ext.TabPanel({
                activeTab: 0,
                region: 'center',
                cls: 'transparent-panel',
                deferredRender: false,
                border: false,
                items: taskPanels
            })
        ]
    });
    
    this._mainPanel.addListener('focus', this._onFocus, this);
    this._mainPanel.addListener('close', this._onClose, this);
    this._mainPanel.addListener('blur', this._onBlur, this);
    
    return this._mainPanel;
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype.refresh = function ()
{
    for (var i=0; i &lt; this._grids.length; i++)
    {
        this._grids[i].getStore().load();
    }
    
    this.upToDate();
}


org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._lastDraftPanel = function(taskId, taskLabel, max)
{
    // The mapping for XML doc
    var mapping = Ext.data.Record.create([
       {name: 'id', mapping: '@id'},    
       {name: 'name', mapping: '@name'},
       {name: 'language', mapping: '@language'},    
       {name: 'language-image', mapping: '@language-image'},    
       {name: 'icon-small', mapping: '@smallIcon'},    
       {name: 'title', mapping: '@title', sortType: Utils.sortAsNonAccentedUCString},
       {name: 'lastModified', mapping: '@lastModified'},
       {name: 'contributor', mapping: '@author'},
       {name: 'workflow-icon-small', mapping: 'workflow-icon-small'},
       {name: 'workflow-step', mapping: 'workflow-step'}
    ]);
    
    var url = this._getStoreUrl();
    
    var proxy = new Ext.data.HttpProxy({
        url: url,
        method: 'post',
        timeout: 60000*10
    });
    
    var store = new Ext.data.Store({
        proxy: proxy,
        reader: new Ext.data.XmlReader({
                record: 'content',       // The repeated element which contains record information
                id: '@id'                 // The element within the row that provides an ID for the record (optional)
            }, 
            // mapping XML
            mapping
        ),
        baseParams: {taskId: taskId},
        sortInfo: {field : 'lastModified', direction: "DESC"},
        taskId: taskId,
        taskLabel: taskLabel
    });
    
    var grid = new Ext.grid.GridPanel({
        id: this._prefixId + taskId + '-grid',
        store : store,
        autoScroll: true,
        
        region: 'north',
        deferRowRender : false,
        
        width: (270 + 60 + 160 + 50 + 22),
        height: 147,
        
        columns: [
            {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_CONTENT_TITLE'/>", width: 270, sortable: true, dataIndex: 'title', renderer: this.renderTitle},
            {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_LANGUAGE'/>", width: 60, sortable: true, dataIndex: 'language', renderer: this.renderLanguage},
            {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_LASTMODIFIED'/>", width: 160, sortable: true, dataIndex: 'lastModified', renderer: this.renderDate},
            {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_WORKFLOW_STEP'/>", width: 50, sortable: true, dataIndex: 'workflow-step', renderer: this.renderWorkflowStep}
        ],
        
        cls: 'mask-below-menu'
    });
    
    // Events
    grid.getSelectionModel().on('beforerowselect', this._onBeforeSelectionChange, this);
    grid.getSelectionModel().on('selectionchange', this._onSelectionChange, this);
    grid.on('celldblclick', this._openContent, this);
    grid.getStore().on('beforeload', this._onBeforeLoad, this);
    grid.getStore().on('load', this._onLoad, this, {taskId: taskId, taskLabel: taskLabel});
    
    // Load the grid contents.
    grid.getStore().load();
    
    this._grids.push(grid);
    
    return grid;
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._drawGridPanel = function(taskId, taskLabel, max)
{
    // The mapping for XML doc
    var mapping = Ext.data.Record.create([
       {name: 'id', mapping: '@id'},    
       {name: 'language', mapping: '@language'},    
       {name: 'language-image', mapping: '@language-image'},    
       {name: 'name', mapping: '@name'},
       {name: 'icon-small', mapping: '@smallIcon'},    
       {name: 'title', mapping: '@title', sortType: Utils.sortAsNonAccentedUCString},
       {name: 'lastModified', mapping: '@lastModified'},
       {name: 'contributor', mapping: '@author'}
    ]);
    
    var url = this._getStoreUrl();
    
    var proxy = new Ext.data.HttpProxy({
        url: url,
        method: 'post',
        timeout: 60000*10
    });
    
    var store = new Ext.data.Store({
        proxy: proxy,
        reader: new Ext.data.XmlReader({
               record: 'content',        // The repeated element which contains record information
               id: '@id'                 // The element within the row that provides an ID for the record (optional)
            }, 
            // mapping XML
            mapping
        ),
        baseParams: {taskId: taskId},
        sortInfo: {field : 'lastModified', direction: "DESC"},
        taskId: taskId,
        taskLabel: taskLabel
    });
    
    var grid = new Ext.grid.GridPanel({
        id: this._prefixId + taskId + '-grid',
        store : store,
        autoScroll: true,
        
        region: 'center',
        deferRowRender : false,
        
        columns: [
             {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_CONTENT_TITLE'/>", width: 270, sortable: true, dataIndex: 'title', renderer: this.renderTitle},
             {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_LANGUAGE'/>", width: 60, sortable: true, dataIndex: 'language', renderer: this.renderLanguage},
             {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_CONTRIBUTOR'/>", width: 270, sortable: true, dataIndex: 'contributor'},
             {header: "<i18n:text i18n:key='PLUGINS_ODF_DASHBOARD_COLUMN_LASTMODIFIED'/>", width: 160, sortable: true, dataIndex: 'lastModified', renderer: this.renderDate} 
        ],
        
        cls: 'mask-below-menu'
    });
    
    // Events.
    grid.getSelectionModel().on('beforerowselect', this._onBeforeSelectionChange, this);
    grid.getSelectionModel().on('selectionchange', this._onSelectionChange, this);
    grid.on('celldblclick', this._openContent, this);
    grid.getStore().on('beforeload', this._onBeforeLoad, this);
    grid.getStore().on('load', this._onLoad, this, {taskId: taskId, taskLabel: taskLabel});
    
    // Load the grid contents.
    grid.getStore().load();
    
    this._grids.push(grid);
    
    return grid;
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype.renderTitle = function(value, p, record)
{
    var title = '';
    if (record.data['icon-small'])
    {
        title += '&lt;img src="' + context.contextPath + record.data['icon-small'] + '" style="float:left; margin-right: 5px"/&gt;';
    }
    title += record.data['title'] ? record.data['title'] : record.data['name'];
    
    return title;
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype.renderDate = function(value, p, record)
{
    var parsedDate = Date.parseDate(value, 'c');
    
    var formattedValue = parsedDate == null ? '' : Ext.util.Format.date(parsedDate, "<i18n:text i18n:catalogue='plugin.cms' i18n:key='UITOOL_SEARCH_DATETIME_FORMAT'/>");
    
    return formattedValue;
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype.renderWorkflowStep = function(value, p, record)
{
    var step;
    if (record.data['workflow-icon-small'])
    {
        step = '&lt;img src="' + context.contextPath + record.data['workflow-icon-small'] + '" style="float:left; margin-right: 5px" alt="' + record.data['workflow-step'] + '" title="' + record.data['workflow-step'] + '"/&gt;';
    }
    else
    {
        step = record.data['workflow-step'];
    }
    return step;
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype.renderLanguage = function (value, p, record)
{
	return '&lt;img src="' + context.contextPath + record.data['language-image'] + '" style="float:left; margin-right: 5px" alt="' + value + '"/&gt;';
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._onBeforeSelectionChange = function (sm)
{
    // clear selections of the others grids
    for (var i=0; i &lt; this._grids.length; i++)
    {
        if (this._grids[i].id != sm.grid.id)
        {
            this._grids[i].getSelectionModel().clearSelections();
        }
    }
}

/**
 * Call when selection change in the grid
 * @param Ext.grid.AbstractSelectionModel sm The selection model
 * @private
 */
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._onSelectionChange = function(sm)
{
    if (!this._hasFocus)
    {
        // Force focus
        org.ametys.uitool.ToolsManager.getInstance().gotElFocus(this._mainPanel);
    }
    
    window.clearTimeout(this._sendTimeout);
    this._sendTimeout = this._fireMessages.defer(10, this, [sm]);
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._fireMessages = function(sm)
{
    var targets = [];
    
    if (sm != null)
    {
        var records = sm.getSelections();
        for (var i=0; i &lt; records.length; i++)
        {
            var id = records[i].get('id');
            var contentTarget = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget('content', {'id': id});
            targets.push(contentTarget);
        }
    }
    
    var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, {creation: "content"}, targets);
    org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
}

/**
 * Open the selected content
 * @param grid The grid
 * @param rowIndex The selected row index
 * @param columnIndex The selected column index
 * @param e The event
 */
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._openContent = function(grid, rowIndex, columnIndex, e)
{
    var record = grid.getSelectionModel().getSelected();
    var id = record.get('id');
    
    org.ametys.uitool.ToolsManager.getInstance().openTool('uitool-content', {'id': id});
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._onBeforeLoad = function (store, options)
{
	options.params = options.params || {};
	for (var i in context.parameters)
	{
		options.params[i] = encodeURIComponent(context.parameters[i]);
	}
}
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._onLoad = function(store, records, options)
{
    this._modifyPanelTitle(store.taskId, store.taskLabel, records.length);
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._modifyPanelTitle = function(taskId, taskLabel, count)
{
    if (taskId &amp;&amp; taskLabel)
    {
        var panel = Ext.getCmp(this._prefixId + taskId + '-panel');
        if (panel != null)
        {
            panel.setTitle(taskLabel + ' (' + count + ')');
        }
    }
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._matchTargets = function (targets)
{
	for (var i = 0; i &lt; targets.length; i++)
	{
		if (this._testTargetContentType(targets[i]))
		{
			return true;
		}
	}
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype.onMessage = function (messages)
{
    for (var i=messages.length - 1; i &gt;= 0; i--)
    {
        if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGED ||
                messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
        {
            var allTargets = messages[i].getTargets();
            var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(allTargets, function(target) { return target.getType() == "content";});
            
            if (this._matchTargets(targets))
            {
                this.outOfDate();
                return;
            }
        }
        else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED)
        {
            var allTargets = messages[i].getTargets();
            var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(allTargets, function(target) { return target.getType() == 'content';});
            
            var contentIds = this._convertToId(targets);
            var upToDate = true;
            
            for (var j = 0; j &lt; contentIds.length; j++)
            {
                for (var k=0; k &lt; this._grids.length; k++)
                {
                    var store = this._grids[k].getStore();
                    var record = store.getById(contentIds[j]);
                    if (record != null)
                    {
                        store.remove(record);
                        
                        this._modifyPanelTitle(store.taskId, store.taskLabel, store.getCount());
                        upToDate = false;
                    }
                }
            }
            
            if (!upToDate)
            {
                this.outOfDate();
            }
        }
    }
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._convertToId = function (targets)
{
    var targetsIds = [];
    for (var i = 0; i &lt; targets.length; i++)
    {
        targetsIds.push(targets[i].getParameters()['id']);
    }
    return targetsIds;
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._areInStore = function (contentIds)
{
    for (var i = 0; i &lt; contentIds.length; i++)
    {
        for (var j=0; j &lt; this._grids.length; j++)
        {
            var record = this._grids[j].getStore().getById(contentIds[i]);
            if (record != null)
            {
                return true;
            }
        }
    }
    
    return false;
}
// ----------------------------------------------------------------------------
/**
 * Get the list of tasks for ODF program contents.
 * Override this method to get your own tasks if your dashboard does not handle 'program' contents.
 */
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._getTasks = function ()
{
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/programs/tasks.xml', {}, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
    var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
    
    var tasks = {};
    
    var taskNodes = response.selectNodes('tasks/task');
    for (var i=0; i &lt; taskNodes.length; i++)
    {
        var taskId = taskNodes[i].getAttribute('id');
        var taskLabel = taskNodes[i][org.ametys.servercomm.ServerComm.xmlTextContent];
        tasks[taskId] = taskLabel;
    }
    
    return tasks;
}

/**
 * Get the stores' URL for grids.
 * The store will be filled with 'program' contents.
 * Override this method if your dashboard does not handle 'program' contents
 */
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._getStoreUrl = function ()
{
	return getPluginDirectUrl('odf') + '/programs/todo-list.xml';
}

/**
 * Determine if the tool is concerned by target's content type.
 * Override this method if your dashboard does not handle 'program' contents
 * @return true if tool is concerned by target's content type.
 */
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._testTargetContentType = function (target)
{
	return target.getParameters().type == 'org.ametys.plugins.odf.Content.program';
}

// ----------------------------------------------------------------------------
org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._onFocus = function ()
{
    this._hasFocus = true;
    
    for (var i=0; i &lt; this._grids.length; i++)
    {
        var sm = this._grids[i].getSelectionModel();
        if (sm.getSelections().length &gt; 0)
        {
            this._fireMessages(sm);
            return;
        }
    }
    
    // No selection
    var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, []);
    var eventBus =  org.ametys.messagebus.MessageBus.getInstance();
    eventBus.fireMessages([event]);
    
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._onClose = function ()
{
    if (this._hasFocus)
    {
        var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, []);
        var eventBus =  org.ametys.messagebus.MessageBus.getInstance();
        eventBus.fireMessages([event]);
    }
}

org.ametys.odf.dashboard.tool.ProgramDashboardTool.prototype._onBlur = function ()
{
    this._hasFocus = false;
}
