/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Ext.namespace('org.ametys.odf.helper');

/**
 * Allow the user to choose a content by a search
 * @param {String} icon The full path to icon (16x16) for the dialog box
 * @param {String} title The title of the dialog box.
 * @param {String} helpmessage1 The message displayed at the top of the dialog box on the first card (search form)
 * @param {String} helpmessage2 The message displayed at the top of the dialog box on the second card (search result)
 * @param {String} factoryRole The role of the factory used to display the search configuration.
 * @param {Function} callback The method that will be called when the dialog box is closed. The method signature depends on selection type:&lt;br&gt; if multiple selections &lt;ul&gt;&lt;li&gt;ids: The ids of the contents in a Array&lt;/li&gt;&lt;/ul&gt;&lt;br&gt;if single selection &lt;ul&gt;&lt;li&gt;id: The id of the content&lt;/li&gt;&lt;/ul&gt;.
 * @param {boolean} multiple True to allow multiple selections. Defaults to false.
 * @param {String} lang Contents' language. Can be null.
 */
org.ametys.odf.helper.ChooseCourseBySearch = function(title, icon, helpMessage1, helpMessage2, factoryRole, callback, multiple, lang)
{
	org.ametys.odf.helper.ChooseCourseBySearch._cb = callback;
	org.ametys.odf.helper.ChooseCourseBySearch._singleSelect = multiple ? false : true;
	org.ametys.odf.helper.ChooseCourseBySearch._lang = lang; 
	
	var factory = org.ametys.uitool.ToolsManager.getInstance()._factories[factoryRole];
	org.ametys.odf.helper.ChooseCourseBySearch._factory = factory;
	org.ametys.odf.helper.ChooseCourseBySearch._config = factory._config;
	
	org.ametys.odf.helper.ChooseCourseBySearch._initialize(title, icon, helpMessage1, helpMessage2);

	org.ametys.odf.helper.ChooseCourseBySearch._box.show();
	
	org.ametys.odf.helper.ChooseCourseBySearch._navHandler (0);
	org.ametys.odf.helper.ChooseCourseBySearch._box.buttons[2].setDisabled(true);
	org.ametys.odf.helper.ChooseCourseBySearch._formPanel.getForm().reset();
}

org.ametys.odf.helper.ChooseCourseBySearch._initialize = function (title, icon, helpMessage1, helpMessage2)
{
	if (!org.ametys.odf.helper.ChooseCourseBySearch._initialized)
	{
		org.ametys.odf.helper.ChooseCourseBySearch._formPanel = new Ext.form.FormPanel ({
			border: false,
			region: 'center',
        	labelWidth: 130,
        	items: org.ametys.cms.helper.SearchContentHMIHelper.getFormItems (this._config)
		});
		
		org.ametys.odf.helper.ChooseCourseBySearch._resultPanel = org.ametys.odf.helper.ChooseCourseBySearch._drawResultPanel();
		org.ametys.odf.helper.ChooseCourseBySearch._resultPanel.getStore().addListener('beforeload', this._onBeforeLoad, this);
		
		org.ametys.odf.helper.ChooseCourseBySearch._helpMsg1 = new org.ametys.HtmlContainer ({region: 'north', cls: 'dialog-text-hint', html: helpMessage1});
		org.ametys.odf.helper.ChooseCourseBySearch._helpMsg2 = new org.ametys.HtmlContainer ({region: 'north', cls: 'dialog-text-hint', html: helpMessage2});
		
		org.ametys.odf.helper.ChooseCourseBySearch._box = new org.ametys.DialogBox ({
			title: title,
			icon: icon,
			
			width: 500,
			height: 465,
			autoScroll: true,
			
			defaultValue: org.ametys.odf.helper.ChooseCourseBySearch._formPanel.getForm().items.get(0),
			items: [{
				layout:'card',
				border: false,
				height: 400,
				cls: 'dialog-search-form',
				
				activeItem: 0, // index or id
				
				items: [ 
				         {
				        	 border: false,
				        	 layout: 'border',
				        	 items : [
				        	          org.ametys.odf.helper.ChooseCourseBySearch._helpMsg1,
				        	          org.ametys.odf.helper.ChooseCourseBySearch._formPanel
				        	 ]
				         },
				         {
				        	 border: false,
				        	 layout: 'border',
				        	 items : [  
				        	          	org.ametys.odf.helper.ChooseCourseBySearch._helpMsg2,
				        	            org.ametys.odf.helper.ChooseCourseBySearch._resultPanel
				        	 ]
				         }
				]
			}],
				
			closeAction: 'hide',
			validateAction: function() 
			{
				this.buttons[2].btnEl.dom.click();
			},
			
			buttons : [
					    {
				            text: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSECONTENTBYSEARCH_PREV_BUTTON"/>", 
				            handler: org.ametys.odf.helper.ChooseCourseBySearch._navHandler.createDelegate(this, [0]),
				            disabled: true
						},{
							text: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSECONTENTBYSEARCH_NEXT_BUTTON"/>", 
				            handler: org.ametys.odf.helper.ChooseCourseBySearch._navHandler.createDelegate(this, [1]),
				            disabled: false
				        },{
							text : "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSECONTENTBYSEARCH_OKBUTTON"/>",
							disabled: true,
							handler: function() 
							{ 
				        		if (org.ametys.odf.helper.ChooseCourseBySearch._singleSelect)
				        		{
				        			var contentId = org.ametys.odf.helper.ChooseCourseBySearch._resultPanel.getSelectionModel().getSelected().id;
				        			if (org.ametys.odf.helper.ChooseCourseBySearch._cb(contentId) !== false)
									{
						        		org.ametys.odf.helper.ChooseCourseBySearch._box.hide();
									}
				        		}
				        		else
				        		{
					        		var contentIds = [];
					        		var records = org.ametys.odf.helper.ChooseCourseBySearch._resultPanel.getSelectionModel().getSelections();
					        		for (var i=0; i &lt; records.length; i++)
					        		{
					        			contentIds.push (records[i].id);
					        		}
						        	if (org.ametys.odf.helper.ChooseCourseBySearch._cb(contentIds) !== false)
									{
						        		org.ametys.odf.helper.ChooseCourseBySearch._box.hide();
									}
				        		}
							} 
					    }, 
					    {
					    	text : "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSECONTENTBYSEARCH_CANCELBUTTON"/>",
							handler: function() 
							{ 
								org.ametys.odf.helper.ChooseCourseBySearch._box.hide(); 
							} 
					    }
			 ]
		});
		org.ametys.odf.helper.ChooseCourseBySearch._box.addListener ('show', org.ametys.odf.helper.ChooseCourseBySearch._onRender, org.ametys.odf.helper.ChooseCourseBySearch, {single: true});
		org.ametys.odf.helper.ChooseCourseBySearch._resultPanel.getSelectionModel().addListener('selectionchange', org.ametys.odf.helper.ChooseCourseBySearch._selectContent, org.ametys.odf.helper.ChooseCourseBySearch);
		org.ametys.odf.helper.ChooseCourseBySearch._initialized = true;
	}
	else
	{
		org.ametys.odf.helper.ChooseCourseBySearch._box.setIconPath(icon);
		org.ametys.odf.helper.ChooseCourseBySearch._box.setTitle(title);
		org.ametys.odf.helper.ChooseCourseBySearch._helpMsg1.el.update(helpMessage1);
		org.ametys.odf.helper.ChooseCourseBySearch._helpMsg2.el.update(helpMessage2);
		org.ametys.odf.helper.ChooseCourseBySearch._formPanel.getForm().reset();
		org.ametys.odf.helper.ChooseCourseBySearch._navHandler (0);
	}
}

org.ametys.odf.helper.ChooseCourseBySearch._navHandler = function (index)
{
	if (index == 1)
	{
		var params = {start:0, limit: 50};
		
		// Clear old selections
		this._resultPanel.getSelectionModel().clearSelections();
		
		this._resultPanel.getStore().load({
			params: params
		});
	}
	
	var cardLayout = org.ametys.odf.helper.ChooseCourseBySearch._box.items.get(0).getLayout();
	cardLayout.setActiveItem(index);
	org.ametys.odf.helper.ChooseCourseBySearch._box.buttons[0].setDisabled(index==0);
	org.ametys.odf.helper.ChooseCourseBySearch._box.buttons[1].setDisabled(index==1);
	
	org.ametys.odf.helper.ChooseCourseBySearch._box.items.get(0).items.get(index).doLayout();
}

org.ametys.odf.helper.ChooseCourseBySearch._drawResultPanel = function ()
{
	// The mapping for XML doc
	var mapping = Ext.data.Record.create(org.ametys.odf.helper.ChooseCourseBySearch._getRecordMapping());
	
	var url = getPluginDirectUrl('cms') + '/search/list.xml';
	if (this._config['search-url'] != null)
	{
		url = context.contextPath + this._config['search-url'];
	}
	var proxy = new Ext.data.HttpProxy({
		url: url,
		method: 'post',
		timeout: 60000*10
	});
	
	var store = new Ext.data.GroupingStore({
		proxy: proxy,
        reader: new Ext.data.XmlReader({
               record: 'content',		 // The repeated element which contains record information
               totalProperty: "total", // The element which contains the total dataset size (optional)
               id: "@id"                 // The element within the row that provides an ID for the record (optional)
        }, 
        // mapping XML
        mapping
        ),
        
        sortInfo: {field : this._config['column-0-id'], direction: "ASC"}
    });
	
	// Group information
	if (this._config['group-by'])
	{
		store.groupBy(this.getConfiguration ()['group-by']);
	}
	
	// Sort information
	if (this._config['sort-by'])
	{
		store.setDefaultSort(this._config['sort-by'], 'ASC');
	}
	
	// The paging bottom bar
	var pagingBar = new Ext.PagingToolbar({
        pageSize: 50,
        store: store,
        displayInfo: true,
        displayMsg: "<i18n:text i18n:key="UITOOL_SEARCH_CONTENT_RESULT_1" i18n:catalogue="plugin.cms"/>{0}<i18n:text i18n:key="UITOOL_SEARCH_CONTENT_RESULT_2" i18n:catalogue="plugin.cms"/>{1}<i18n:text i18n:key="UITOOL_SEARCH_CONTENT_RESULT_3" i18n:catalogue="plugin.cms"/>{2}",
        emptyMsg: "<i18n:text i18n:key="UITOOL_SEARCH_NO_RESULT" i18n:catalogue="plugin.cms"/>"
    });
	
	var grid = new Ext.grid.GridPanel({
		store : store,
		region: 'center',
		
		sm: new Ext.grid.RowSelectionModel ({
			singleSelect: org.ametys.odf.helper.ChooseCourseBySearch._singleSelect
		}),
		view: new Ext.grid.GroupingView({
		       forceFit:true,
		       groupTextTpl: '{text}'
		}),
		    
	    columns: org.ametys.odf.helper.ChooseCourseBySearch._getColumns(),
	    
        // paging bar on the bottom
        bbar: pagingBar,
        
        cls: 'mask-below-menu'
	});
	
	grid.getStore().addListener('beforeload', org.ametys.odf.helper.ChooseCourseBySearch._onBeforeLoad, org.ametys.odf.helper.ChooseCourseBySearch);
	grid.getSelectionModel().addListener('selectionchange', org.ametys.odf.helper.ChooseCourseBySearch._selectContent, org.ametys.odf.helper.ChooseCourseBySearch);
	
	return grid;
}

org.ametys.odf.helper.ChooseCourseBySearch._getRecordMapping = function ()
{
	return org.ametys.cms.helper.SearchContentHMIHelper.getRecordMapping (this._config);
}

org.ametys.odf.helper.ChooseCourseBySearch._getColumns = function ()
{
	var columns = [];
	var columnCount = parseInt(this._config["column-size"]); 
	
	for (var i=0;  i &lt; columnCount; i++)
	{
		var header = this._config["column-" + i + "-label"];
		var dataIndex = this._config["column-" + i + "-id"];
		var width = this._config["column-" + i + "-width"];
		var sortable = this._config["column-" + i + "-sortable"] != 'false';
		var renderer = this._config["column-" + i + "-renderer"];
		// Show only title and code columns.
		var hidden = !(dataIndex == 'title' || dataIndex == 'elpCode');
		
		var column = {
				header: header,
				dataIndex: dataIndex,
				width: parseInt(width),
				sortable: sortable,
				hideable: hidden,
				hidden: hidden
		};
		if (renderer != null)
		{
			column.renderer = eval (renderer);
		}
		columns.push (column);
	}
	
	return columns;
}


/**
 * This function is called before launching search.
 * Fills the request parameters with criteria search.
 * Display a waiting message to the user.
 */
org.ametys.odf.helper.ChooseCourseBySearch._onBeforeLoad = function (store, options)
{
	// Get criteria search
	org.ametys.cms.helper.SearchContentHMIHelper.getSearchParameters (this._config, this._formPanel.getForm(), options.params);
	
	options.params['siteName'] = context.parameters.siteName;
	
	if (org.ametys.odf.helper.ChooseCourseBySearch._lang)
	{
		options.params['lang'] = org.ametys.odf.helper.ChooseCourseBySearch._lang;
	}
	else
	{
		var currentTargets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
		var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(currentTargets, function(target) {return target.getType() == 'page'});
		if (target != null)
		{
			options.params['lang'] = target.getParameters()['lang'];
		}
	}
}

org.ametys.odf.helper.ChooseCourseBySearch._onRender = function ()
{
	var formPanel = org.ametys.odf.helper.ChooseCourseBySearch._formPanel;
	formPanel.items.each (function (item) {item.setWidth (formPanel.getWidth() - 142 - 20)});
}

org.ametys.odf.helper.ChooseCourseBySearch._selectContent = function (sm)
{
	org.ametys.odf.helper.ChooseCourseBySearch._box.buttons[2].setDisabled(sm.getSelected() == null);
}
