/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.helper');

/**
 * Allow the user to choose a OrgUnit
 * @param {String} icon The full path to icon (16x16) for the dialog box
 * @param {String} title The title of the dialog box.
 * @param {String} helpmessage The message displayed at the top of the dialog box.
 * @param {Function} callback The method that will be called when the dialog box is closed. The method signature is &lt;ul&gt;&lt;li&gt;id: The id of the orgunit&lt;/li&gt;&lt;li&gt;title: The name of the title&lt;/li&gt;&lt;/ul&gt;.
 * @param {boolean} multiple Is selection multiple. false by default.
 * @param {String} values The selected orgunit(s). Can be null.
 */
org.ametys.odf.helper.ChooseOrgUnit = function(icon, title, helpmessage, callback, multiple, values)
{
	org.ametys.odf.helper.ChooseOrgUnit._cb = callback;
	org.ametys.odf.helper.ChooseOrgUnit._multiple = multiple;
	org.ametys.odf.helper.ChooseOrgUnit._values = values;
	
	org.ametys.odf.helper.ChooseOrgUnit._initialize(icon, title, helpmessage);
	
	org.ametys.odf.helper.ChooseOrgUnit._box.show();
}
//--------------------------------
//--------------------------------
org.ametys.odf.helper.ChooseOrgUnit._initialize = function (icon, title, helpmessage)
{
	org.ametys.odf.helper.ChooseOrgUnit._helpMsg = new org.ametys.HtmlContainer ({region: 'north', height: 30, cls: 'dialog-text-hint', html: helpmessage});
		
	org.ametys.odf.helper.ChooseOrgUnit._tree = new org.ametys.odf.orgunit.OrgUnitTreePanel ({
		region: 'center',
	    enableDD:false,
	    
	    checkMode: org.ametys.odf.helper.ChooseOrgUnit._multiple
	});
	
	
	var plugin = org.ametys.odf.helper.ChooseOrgUnit.plugin;
	
    var items = [
        org.ametys.odf.helper.ChooseOrgUnit._helpMsg, 
        org.ametys.odf.helper.ChooseOrgUnit._tree
    ];
    
	org.ametys.odf.helper.ChooseOrgUnit._box = new org.ametys.DialogBox ({
		title: title,
		icon: icon,
		
		layout: 'border',
		width : 395,
		height : 400,
		
		items: items,
		
		defaultButton: org.ametys.odf.helper.ChooseOrgUnit._tree,
		closeAction: 'hide',
		
		buttons : [ 
		    {
				text : "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEORGUNIT_OKBUTTON"/>",
				disabled: !org.ametys.odf.helper.ChooseOrgUnit._multiple,
				handler: function() 
				{ 
		    		var orgunits = [];
			    	if (org.ametys.odf.helper.ChooseOrgUnit._multiple)
			    	{
			    		var selNodes = org.ametys.odf.helper.ChooseOrgUnit._tree.getChecked();
			    		for (var i=0; i &lt; selNodes.length; i++)
			    		{
			    			orgunits[i] = {'id': selNodes[i].id, 'title': selNodes[i].text};
			    		}
			    	}
			    	else
			    	{
			    		var node = org.ametys.odf.helper.ChooseOrgUnit._tree.getSelectionModel().getSelectedNode();
			    		orgunits[0] = {'id': node.id, 'title': node.text};
			    	}
		    	
					if (org.ametys.odf.helper.ChooseOrgUnit._cb(orgunits) !== false)
					{
						org.ametys.odf.helper.ChooseOrgUnit._box.hide();
					}
				} 
		    }, 
		    {
				text : "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEORGUNIT_CANCELBUTTON"/>",
				handler: function() 
				{ 
					org.ametys.odf.helper.ChooseOrgUnit._cb(null); 
					org.ametys.odf.helper.ChooseOrgUnit._box.hide(); 
				} 
		    } 
		]
	});
	
	org.ametys.odf.helper.ChooseOrgUnit._tree.getSelectionModel().addListener('selectionchange', org.ametys.odf.helper.ChooseOrgUnit._selectionChange);
	org.ametys.odf.helper.ChooseOrgUnit._tree.getLoader().addListener ('beforeload', this._onBeforeLoad, this);
	org.ametys.odf.helper.ChooseOrgUnit._tree.addListener ('load', this._onLoad, this);
	org.ametys.odf.helper.ChooseOrgUnit._tree.createRootNode ('root');
	org.ametys.odf.helper.ChooseOrgUnit._tree.getRootNode().reload ();
	org.ametys.odf.helper.ChooseOrgUnit._tree.getRootNode().expand();
}

/**
 * @private
 * Listener when a node is selected in the tree
 */
org.ametys.odf.helper.ChooseOrgUnit._selectionChange = function(selectionModel, node)
{
	if (!org.ametys.odf.helper.ChooseOrgUnit._multiple)
	{
		var orgUnitSelected = node != null &amp;&amp; node.attributes["type"] == "orgunit";
		org.ametys.odf.helper.ChooseOrgUnit._box.buttons[0].setDisabled(!orgUnitSelected);
	}
	
}

org.ametys.odf.helper.ChooseOrgUnit._onBeforeLoad = function (treeLoader, node)
{
    treeLoader.baseParams.id = node != null ? node.attributes.id : null;	
}

org.ametys.odf.helper.ChooseOrgUnit._onLoad = function (node)
{
	if (org.ametys.odf.helper.ChooseOrgUnit._values == null || org.ametys.odf.helper.ChooseOrgUnit._values.length == 0)
		return;
	
	var orgunits = org.ametys.odf.helper.ChooseOrgUnit._values.split(',');
	
	for (var i=0; i &lt; orgunits.length; i++)
	{
		var child = node.findChild ('id', orgunits[i]);
		if (child != null)
		{
			if (org.ametys.odf.helper.ChooseOrgUnit._multiple)
			{
				child.attributes.checked = true;
				child.getUI().toggleCheck(true);
			}
			else
			{
				child.select();
			}
		}
	}
}

/**
 * Select the tree nodes according to the input field value
 * @private
 */
org.ametys.odf.helper.ChooseOrgUnit._init = function (values)
{
	if (values == null || values.length == 0)
		return;
	
	var orgunits = values.split(',');
	
	for (var i=0; i &lt; orgunits.length; i++)
	{
		var node = org.ametys.odf.helper.ChooseOrgUnit._tree.getNodeById(orgunits[i]);
		if (node != null)
		{
			if (org.ametys.odf.helper.ChooseOrgUnit._multiple)
			{
				node.attributes.checked = true;
				node.getUI().toggleCheck(true);
			}
			else
			{
				node.select();
			}
		}
	}
}

