/*
 *  Copyright 2009 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Ext.namespace('org.ametys.odf.helper');

org.ametys.odf.helper.SelectPerson = function (callback, cancelCallback)
{
	org.ametys.odf.helper.SelectPerson.delayedInitialize();
	org.ametys.odf.helper.SelectPerson.callback = callback;
	org.ametys.odf.helper.SelectPerson.cancelCallback = cancelCallback;
	
	org.ametys.odf.helper.SelectPerson.criteria.setValue("");

	org.ametys.odf.helper.SelectPerson.box.show();
	
	org.ametys.odf.helper.SelectPerson.load();
	
	try
	{
		org.ametys.odf.helper.SelectPerson.criteria.focus();
	} catch (e) {}
}
// --------------------------------
org.ametys.odf.helper.SelectPerson._initialized = false;
// --------------------------------
org.ametys.odf.helper.SelectPerson.delayedInitialize = function ()
{
	if (org.ametys.odf.helper.SelectPerson._initialized)
		return true;
	
	org.ametys.odf.helper.SelectPerson._initialized = true;

	org.ametys.odf.helper.SelectPerson.criteria = new Ext.form.TextField ({
		 listeners: {'keyup': org.ametys.odf.helper.SelectPerson.reload},
		 fieldLabel: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_HELPTEXT"/>",
		 name: "criteria",
		 width: 140,
		 enableKeyEvents: true,
		 value: ""
	});
	
	var form = new Ext.FormPanel( {
		region: 'north',
		height: 37,
		
		formId : 'select-user-form',
		labelWidth :70,
		border: false,
		items: [org.ametys.odf.helper.SelectPerson.criteria]
	});
	
	org.ametys.odf.helper.SelectPerson.listview = new org.ametys.ListView({
		region: 'center',
		
	    store : new Ext.data.SimpleStore({
			id:0,
	        fields: [
	           {name: 'name'}
	        ]
	    }),
	    hideHeaders : true,
	    columns: [
	        {header: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_COL_NAME"/>", width : 240, menuDisabled : true, sortable: true, dataIndex: 'name'}
	    ],
		id: 'select-user-list',
		baseCls: 'select-user-list',
		autoScroll: true
	});	
	org.ametys.odf.helper.SelectPerson.listview.setMultipleSelection(false);
	
	var warning = new org.ametys.HtmlContainer ({
		region: 'south',
		height: 26,
		cls: 'select-user-warning',
		
		html: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_DIALOG_WARN100"/>"
	});
	
	org.ametys.odf.helper.SelectPerson.box = new org.ametys.DialogBox({
		title :"<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_DIALOG_TITLE"/>",
		layout :'border',
		width :280,
		height : 340,
		cls : 'select-user-box',
		icon: getPluginResourcesUrl('core') + '/img/users/icon_small.png',
		items : [form, org.ametys.odf.helper.SelectPerson.listview, warning],
		closeAction: 'hide',
		defaultButton: org.ametys.odf.helper.SelectPerson.criteria,
		buttons : [ {
			text :"<i18n:text i18n:key="PLUGINS_CORE_USERS_SELECTUSER_DIALOG_OK" i18n:catalogue="plugin.core"/>",
			handler : function() {
			org.ametys.odf.helper.SelectPerson.ok();
			}
		}, {
			text :"<i18n:text i18n:key="PLUGINS_CORE_USERS_SELECTUSER_DIALOG_CANCEL" i18n:catalogue="plugin.core"/>",
			handler : function() {
			org.ametys.odf.helper.SelectPerson.cancel();
			}
		} ]
	});
}

// --------------------------------
org.ametys.odf.helper.SelectPerson.reload = function (field, newValue, oldValue)
{
	if (org.ametys.odf.helper.SelectPerson.reloadTimer != null)
		window.clearTimeout(org.ametys.odf.helper.SelectPerson.reloadTimer);
	
	org.ametys.odf.helper.SelectPerson.reloadTimer = window.setTimeout(org.ametys.odf.helper.SelectPerson.load, 500);
}
// --------------------------------
org.ametys.odf.helper.SelectPerson.load = function ()
{
	org.ametys.odf.helper.SelectPerson.reloadTimer = null;

	var criteria = org.ametys.odf.helper.SelectPerson.criteria.getValue();
	
	var params = { criteria: criteria, limit: 100, start: 0, siteName: context.parameters.siteName };
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', "person/widget-search.xml", params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var result = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);

    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_DIALOG_ERROR_LISTING"/>", result, "org.ametys.odf.helper.SelectPerson.load"))
    {
       return;
    }

	org.ametys.odf.helper.SelectPerson.listview.getStore().removeAll();
	
	var users = result.selectNodes("contents/content");

	for (var i=0; i &lt; users.length; i++)
	{
		var id = users[i].getAttribute('id');
		
		var lastName = users[i].selectSingleNode('metadata/lastName') != null ? users[i].selectSingleNode('metadata/lastName')[org.ametys.servercomm.ServerComm.xmlTextContent] : '';
		var givenName = users[i].selectSingleNode('metadata/givenName') != null ? users[i].selectSingleNode('metadata/givenName')[org.ametys.servercomm.ServerComm.xmlTextContent] : '';
		var title = users[i].selectSingleNode('metadata/personTitle') != null ? users[i].selectSingleNode('metadata/personTitle')[org.ametys.servercomm.ServerComm.xmlTextContent] : '';
		
		var fullname = '';
		if (lastName != '' || givenName != '')
		{
			fullname += lastName + (givenName != '' ? " " + givenName : "");
		}
		else
		{
			fullname += title;
		}
		
		org.ametys.odf.helper.SelectPerson.listview.addElement(id, {name: fullname});
	}
	
	if (users.length == 0)
    {
		Ext.Msg.show({
			   title: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_DIALOG_TITLE"/>",
			   msg: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_DIALOG_NORESULT"/>",
			   buttons: Ext.Msg.OK,
			   icon: Ext.MessageBox.INFO
			});
    }
}
// --------------------------------
org.ametys.odf.helper.SelectPerson.ok = function ()
{
	if (org.ametys.odf.helper.SelectPerson.callback != null)
	{
		var addedusers = {}
		
		var selection = org.ametys.odf.helper.SelectPerson.listview.getSelection();
		if (selection.length == 0)
		{
			Ext.Msg.show({
				   title: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_DIALOG_TITLE"/>",
				   msg: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_DIALOG_ERROR_EMPTY"/>",
				   buttons: Ext.Msg.OK,
				   icon: Ext.MessageBox.INFO
				});
			return;
		}

		org.ametys.odf.helper.SelectPerson.box.hide();
		
		for (var i=0; i &lt; selection.length; i++)
		{
			var opt = selection[i];
			addedusers[opt.id] = opt.get('name');
		}
	
		org.ametys.odf.helper.SelectPerson.callback(addedusers);
	}
	else
	{
		org.ametys.odf.helper.SelectPerson.box.hide();
	}
}
	
// --------------------------------
org.ametys.odf.helper.SelectPerson.cancel = function ()
{
	org.ametys.odf.helper.SelectPerson.box.hide();

	if (org.ametys.odf.helper.SelectPerson.cancelCallback != null)
	{
		org.ametys.odf.helper.SelectPerson.cancelCallback();
	}
}
