/*
 *  Copyright 2009 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Ext.namespace('org.ametys.odf.helper');

// ----------------------------------------------------------------
// 				SELECT PERSONS 
// ----------------------------------------------------------------
org.ametys.odf.helper.SelectPersons = function (callback, cancelCallback, users)
{
	org.ametys.odf.helper.SelectPersons.delayed_initialize();
	org.ametys.odf.helper.SelectPersons.callback = callback;
	org.ametys.odf.helper.SelectPersons.cancelCallback = cancelCallback;
	
    org.ametys.odf.helper.SelectPersons.init(users);
    
	org.ametys.odf.helper.SelectPersons.box.show();
}
org.ametys.odf.helper.SelectPersons.initialized = false;
// --------------------------------
org.ametys.odf.helper.SelectPersons.delayed_initialize = function ()
{
	if (org.ametys.odf.helper.SelectPersons.initialized)
		return true;
	org.ametys.odf.helper.SelectPersons.initialized = true;

	var plugin = org.ametys.odf.helper.SelectPersons.plugin;

	org.ametys.odf.helper.SelectPersons.listview = new org.ametys.ListView({
		region: 'center',
		
	    store : new Ext.data.SimpleStore({
			id:0,
	        fields: [
	           {name: 'name'}
	        ]
	    }),
	    hideHeaders : true,
	    columns: [
	        {header: "<i18n:text i18n:key="PLUGINS_ODF_HELPER_CHOOSEPERSON_COL_NAME"/>", width : 240, menuDisabled : true, sortable: true, dataIndex: 'name'}
	    ],
		id: 'select-user-list',
		baseCls: 'select-user-list',
		autoScroll: true
	});	
	org.ametys.odf.helper.SelectPersons.listview.getSelectionModel().addListener('selectionchange', org.ametys.odf.helper.SelectPersons._onSelectUsers, this);
	
	org.ametys.odf.helper.SelectPersons.buttons = new Ext.Panel({
		region: 'east',
		cls: 'buttons',
		border: false,
		width: 100,
		items: [
			new Ext.Button({
				width: 80,
				text: "<i18n:text i18n:key="PLUGINS_CORE_USERS_SELECTUSERS_BTN_ADDUSER" i18n:catalogue="plugin.core"/>",
				handler : org.ametys.odf.helper.SelectPersons._addUser
			}),
			new Ext.Button({
				width: 80,
				text: "<i18n:text i18n:key="PLUGINS_CORE_USERS_SELECTUSERS_BTN_DELETEUSERS" i18n:catalogue="plugin.core"/>",
				handler : org.ametys.odf.helper.SelectPersons._deleteUsers,
				disabled: true
			})
		]
	});
	org.ametys.odf.helper.SelectPersons.listview.setMultipleSelection(true);
	
	org.ametys.odf.helper.SelectPersons.box = new org.ametys.DialogBox({
		title :"<i18n:text i18n:key="PLUGINS_CORE_USERS_SELECTUSERS_DIALOG_CAPTION" i18n:catalogue="plugin.core"/>",
		layout :'border',
		width :360,
		height : 340,
		cls : 'select-user-box',
		icon: getPluginResourcesUrl('core') + '/img/users/icon_small.png',
		items : [org.ametys.odf.helper.SelectPersons.listview, org.ametys.odf.helper.SelectPersons.buttons],
		closeAction: 'hide',
		buttons : [ {
			text :"<i18n:text i18n:key="PLUGINS_CORE_USERS_SELECTUSER_DIALOG_OK" i18n:catalogue="plugin.core"/>",
			handler : function() {
				org.ametys.odf.helper.SelectPersons.ok();
			}
		}, {
			text :"<i18n:text i18n:key="PLUGINS_CORE_USERS_SELECTUSER_DIALOG_CANCEL" i18n:catalogue="plugin.core"/>",
			handler : function() {
				org.ametys.odf.helper.SelectPersons.cancel();
			}
		} ]
	});
}
// --------------------------------
org.ametys.odf.helper.SelectPersons.initialize = function (plugin)
{
	org.ametys.odf.helper.SelectPersons.plugin = plugin;
}

org.ametys.odf.helper.SelectPersons._onSelectUsers = function (sm)
{
	var selection = org.ametys.odf.helper.SelectPersons.listview.getSelection();
	org.ametys.odf.helper.SelectPersons.buttons.items.get(1).setDisabled(selection.length == 0);
}

org.ametys.odf.helper.SelectPersons._addUser = function ()
{
	org.ametys.odf.helper.SelectPerson(org.ametys.odf.helper.SelectPersons._addUserCb, null);	
}
org.ametys.odf.helper.SelectPersons._addUserCb = function (users)
{
	if (users.length == 0)
	{
		return;
	}
	
	var records = [];
	for (var i in users)
	{
		var record = new Ext.data.Record();
		record.id = i;
		record.data.name = users[i];
		records.push(record);
	}
	
	org.ametys.odf.helper.SelectPersons.listview.getStore().add(records);
}
org.ametys.odf.helper.SelectPersons._deleteUsers = function ()
{
	var selection = org.ametys.odf.helper.SelectPersons.listview.getSelection();
	for (var i=0; i &lt; selection.length; i++)
	{
		org.ametys.odf.helper.SelectPersons.listview.getStore().remove(selection[i]);
	}
}
//---------------------------------
org.ametys.odf.helper.SelectPersons.init = function (users)
{
	org.ametys.odf.helper.SelectPersons.listview.getStore().removeAll();
	
	var records = [];
	for (var i in users)
	{
		var record = new Ext.data.Record();
		record.id = i;
		record.data.name = users[i];
		records.push(record);
	}
	
	org.ametys.odf.helper.SelectPersons.listview.getStore().add(records);
}
// --------------------------------
org.ametys.odf.helper.SelectPersons.ok = function ()
{
	if (org.ametys.odf.helper.SelectPersons.callback != null)
	{
		var addedusers = {}
		
		var store = org.ametys.odf.helper.SelectPersons.listview.getStore();
		var records = store.data.items;
		
		org.ametys.odf.helper.SelectPersons.box.hide();
		
		for (var i=0; i &lt; records.length; i++)
		{
			var opt = records[i];
			addedusers[opt.id] = opt.get('name');
		}
	
		org.ametys.odf.helper.SelectPersons.callback(addedusers);
	}
	else
	{
		org.ametys.odf.helper.SelectPersons.box.hide();
	}
}
	
// --------------------------------
org.ametys.odf.helper.SelectPersons.cancel = function ()
{
	org.ametys.odf.helper.SelectPersons.box.hide();

	if (org.ametys.odf.helper.SelectPersons.cancelCallback != null)
	{
		org.ametys.odf.helper.SelectPersons.cancelCallback();
	}
}
