/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.orgunit');
Ext.namespace('org.ametys.odf.orgunit.OrgUnitActions');
Ext.namespace('org.ametys.odf.orgunit.OrgUnitActions.Export2CDMfr');
//------------------------------------------------------------------
org.ametys.odf.orgunit.OrgUnitActions.openTools = function(id, configuration, pluginName)
{
	var tree = org.ametys.uitool.ToolsManager.getInstance().getTool('uitool-odf-orgunit-tree');
	var search = org.ametys.uitool.ToolsManager.getInstance().getTool('uitool-odf-orgunit-search');
	
	if(tree == null || search == null)
	{
		// open tools
		if(tree == null)
		{
			org.ametys.uitool.ToolsManager.getInstance().openTool('uitool-odf-orgunit-tree', {});
		}
		if(search == null)
		{
			org.ametys.uitool.ToolsManager.getInstance().openTool('uitool-odf-orgunit-search', {});
		}
	}
	else
	{
		// close tools
		tree.close();
		search.close();
	}

}

org.ametys.odf.orgunit.OrgUnitActions.AddOrgUnit = function (controlId, controlConfiguration, controlPluginName)
{
	org.ametys.cms.buttons.content.CreateContentAction._configuration = controlConfiguration;
	// @Override 'ok' function
	org.ametys.cms.buttons.content.CreateContentAction._okFn = org.ametys.odf.orgunit.OrgUnitActions.AddOrgUnit._ok;
	
	org.ametys.cms.buttons.content.CreateContentAction._createBoxIfNeeded();
	
	// Override title and icon
	org.ametys.cms.buttons.content.CreateContentAction._box.setTitle("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_ORGUNIT_TITLE"/>" + "...");
	org.ametys.cms.buttons.content.CreateContentAction._box.setIconPath(getPluginResourcesUrl("odf") + "/img/orgunit/orgunit_16.png");
	Ext.getCmp("content-type-to-create").setValue(controlConfiguration["content-type-to-create"]);
	Ext.getCmp("content-language-to-create").setValue("");
	
	org.ametys.cms.buttons.content.CreateContentAction._box.show();
	
	var f = Ext.getCmp("content-name-to-create");
	f.setValue("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_ORGUNIT_CONTENTNAME"/>");
	f.focus(true, 100);
}

org.ametys.odf.orgunit.OrgUnitActions.AddOrgUnit._ok = function()
{
	var actionId = org.ametys.cms.buttons.content.CreateContentAction._configuration["workflowInitActionId"];
	
	var params = org.ametys.odf.orgunit.OrgUnitActions.AddOrgUnit._getParams();
	if (params == null)
	{
		return;
	}
	
	org.ametys.cms.buttons.content.CreateContentAction._box.showWaitMsg();
	
	var serverMessage = new org.ametys.servercomm.ServerMessage("odf", 'init-workflow-ou/' + actionId, params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.orgunit.OrgUnitActions.AddOrgUnit._creationCb, this, params, "xml");
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.orgunit.OrgUnitActions.AddOrgUnit._creationCb = function(response, params)
{
	org.ametys.cms.buttons.content.CreateContentAction._box.hideWaitMsg();
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_CONTENT_CREATE_ORGUNIT_CREATIONFAILED'/>", response, "org.ametys.cms.buttons.content.CreateContentAction"))
	{
		return;
	}

	org.ametys.cms.buttons.content.CreateContentAction._box.hide();
	
	var newContentId = response.selectSingleNode("ActionResult/contentId")[org.ametys.servercomm.ServerComm.xmlTextContent];

	var targets = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': newContentId})];

	var events = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED, {'parentId':params["workflow-org.ametys.odf.workflow.CreateODFContentFunction$parentId"]}, targets)];
	org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);

	org.ametys.cms.buttons.content.CreateContentAction._finalizeCreation(response, params);
}

org.ametys.odf.orgunit.OrgUnitActions.AddOrgUnit._getParams = function()
{
	var nameField = Ext.getCmp("content-name-to-create"); 
	if (!nameField.isValid())
	{
		return null;
	}
	
	var params = {};
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentName"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentTitle"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentType"] = Ext.getCmp("content-type-to-create").getValue();
	
	for (var c in org.ametys.cms.buttons.content.CreateContentAction._configuration)
	{
		if (c.indexOf("workflow-") == 0)
		{
			params[c] = org.ametys.cms.buttons.content.CreateContentAction._configuration[c];
		}
	}
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content"  &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.orgunit'});
	
	params["workflow-org.ametys.odf.workflow.CreateODFContentFunction$parentId"] = target != null ? target.getParameters().id : "";
	
	return params;
}

//-----------------------------------------------------------------------
org.ametys.odf.orgunit.Validate = function (item, event)
{
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', 'orgunit/is-hierarchy-valid', {contentId: item.contents}, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
    var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
     
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_VALID_ORGUNIT_INVALID_HIERARCHY_ERROR"/>", response, "org.ametys.odf.orgunit.Validate"))
 	{
 		return;
 	}
    
    var ouInvalidHierarchy = response.selectSingleNode('ActionResult/ou-invalid-hierarchy')[org.ametys.servercomm.ServerComm.xmlTextContent];
    if (ouInvalidHierarchy != '')
    {
    	var msg = "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_VALID_ORGUNIT_INVALID_HIERARCHY_MSG"/>";
    	msg += ouInvalidHierarchy;
    	
    	Ext.Msg.show ({
    		title: "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_VALID_ORGUNIT_TITLE"/>",
    		msg: msg,
    		buttons: Ext.Msg.OK,
    		icon: Ext.MessageBox.WARNING,
    		fn: org.ametys.cms.ribbon.button.WorkflowMenu.menuAct.createDelegate(item, [item, event])
    	})
    }
    else
    {
    	org.ametys.cms.ribbon.button.WorkflowMenu.menuAct (item, event);
    }
}
