/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.orgunit');

/**
 * ORGUNIT TREE FACTORY
 */
org.ametys.odf.orgunit.OrgUnitTreeFactory = function(id, config, pluginName) 
{
	org.ametys.odf.orgunit.OrgUnitTreeFactory.superclass.constructor.call(this, id, config, pluginName);
};

Ext.extend(org.ametys.odf.orgunit.OrgUnitTreeFactory, org.ametys.uitool.tool.impl.UniqueInstanceToolFactory,
{
	createTool : function (id)
	{
		return new org.ametys.odf.orgunit.OrgUnitTree(id, this.getPluginName());
	}
});


/**
 * ORGUNIT TREE 
 */
org.ametys.odf.orgunit.OrgUnitTree = function(id, pluginName) 
{
	org.ametys.odf.orgunit.OrgUnitTree.superclass.constructor.call(this, id, pluginName);
};

Ext.extend(org.ametys.odf.orgunit.OrgUnitTree, org.ametys.uitool.tool.Tool, {});

org.ametys.odf.orgunit.OrgUnitTree.prototype._metAnError = false;
/** Refreshing state */
org.ametys.odf.orgunit.OrgUnitTree.prototype._refreshing = false;

org.ametys.odf.orgunit.OrgUnitTree.prototype._tree;

org.ametys.odf.orgunit.OrgUnitTree.prototype.createPanel = function()
{	
	var loader = new org.ametys.odf.orgunit.OrgUnitXmlLoader ({
		baseParams : { id : this._currentContent },
		dataUrl : getPluginDirectUrl('odf') + '/orgunit/tree'  
	});	
	
	this._tree = new Ext.tree.TreePanel({
		region: 'center',
		
		split:true,
		border: false,
		autoScroll:true,
	    animate:true,
	    
	    enableDD:true,
	    ddAppendOnly: true,
		containerScroll: true,
		
		loader: loader,
		root: new Ext.tree.TreeNode (),
        rootVisible : true,

        initEvents: function()
    	{
    		Ext.tree.TreePanel.superclass.initEvents.call(this);

    		if(this.containerScroll)
    		{
    			Ext.dd.ScrollManager.register(this.body);
    		}
    		
    		if((this.enableDD || this.enableDrop) &amp;&amp; !this.dropZone)
    		{

    			this.dropZone = new org.ametys.odf.orgunit.TreeDropZone (this, this.dropConfig || {
    				ddGroup: this.ddGroup || "TreeDD", appendOnly: this.ddAppendOnly === true
    			});
    		}
    		
    		if((this.enableDD || this.enableDrag) &amp;&amp; !this.dragZone)
    		{
    			this.dragZone = new Ext.tree.TreeDragZone(this, this.dragConfig || {
    				ddGroup: this.ddGroup || "TreeDD",
    				scroll: this.ddScroll
    			});
    		}
    	
    		this.getSelectionModel().init(this);
    	}
	});

	// Alphabetical sort
	this._treeSorter = new Ext.tree.TreeSorter(this._tree, {
		folderSort: true,
		leafAttr: 'leafSort'
	});
	
	//Listeners
	this._tree.addListener ('blur', this._onBlur, this);
	this._tree.addListener ('focus', this._onFocus, this);
	
	this._tree.addListener ('beforemovenode', this._moveNode, this);
	this._tree.getSelectionModel().addListener("selectionchange", this._onSelectionChange, this);	
	this._tree.getLoader().addListener("beforeload", this._beforeLoad , this);
	this._tree.addListener("afterrender", this._refreshTree, this);
	this._tree.on('dblclick', this._open);

	return this._tree;
}

/**
 * Listener when the panel receives the focus
 * Change the ribbon title and send a selection message
 * @private
 */
org.ametys.odf.orgunit.OrgUnitTree.prototype._onFocus = function ()
{
	this._hasFocus = true;

	if (this._tree != null)
	{
		var node = this._tree.getSelectionModel().getSelectedNode();
		if (node != null)
		{
			this._currentNode = node;
			this._sendMessage(node);
		}
	}
}
/**
 * Listener when the panel looses the focus
 * Change the ribbon title.
 * @private
 */
org.ametys.odf.orgunit.OrgUnitTree.prototype._onBlur = function ()
{
	this._hasFocus = false;
}


org.ametys.odf.orgunit.OrgUnitTree.prototype.setParams = function (params)
{
	this._params = params;
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._createRootNode = function ()
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.orgunit'});
	
	if (target == null)
		var id = 'root'
	else
		var id = target.getParameters().id;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/orgunit', {'id': id}, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	// TODO Handle error
	
	var rootNode = new Ext.tree.AsyncTreeNode({
        text: response.selectSingleNode('orgunits/orgunit').getAttribute('title'),
        id: response.selectSingleNode('orgunits/orgunit').getAttribute('id'),
        icon: getPluginResourcesUrl ('odf') + '/img/orgunit/orgunit_16.png',
        name: 'root-orgunit',
        type: 'orgunit'
    });
	
	return rootNode;
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._onSelectionChange = function (sm, node)
{
	this._sendMessage (node);
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._sendMessage = function (node)
{
	var target = null;
    if (node != null)
    {
    	var id = node.id;
    	var type = node.attributes.type;
    	target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': id, 'rightContext' : node.attributes.path});	
    }
	
	var message = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, target != null ? [target] : []);
	org.ametys.messagebus.MessageBus.getInstance().fireMessages([message]);
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._expandPath = function (id)
{
	var node = this._tree.getNodeById(id);
	if (node != null)
	{
		this._tree.expandPath("/root-orgunit" + node.attributes.path, 'name', this._selectNodeById.createDelegate (this, [id]));
	}
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._selectNodeById = function (id)
{
	var node = this._tree.getNodeById(id);
	if (node != null)
	{
		if (node.ui.rendered)
		{
			node.select();
			this._currentSelectedContentId = id;
		}
	}
	else
	{
		this._currentSelectedContentId = null;
	}
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._refreshNode = function (id, callback, args)
{
	if (this._tree)
	{
		var node = this._tree.getNodeById(id);
		if (node != null)
		{
				if (typeof callback == 'function')
				{
					node.reload(callback.createDelegate(this, args));
				}
				else
				{
					node.reload();
				}
			
		}
	}
}

/**
 * Delete a node
 * @param id the id of the node to delete
 */
org.ametys.odf.orgunit.OrgUnitTree.prototype._deleteNode = function (id)
{
	if (this._tree)
	{
		var node = this._tree.getNodeById(id);
		if (node != null)
		{
			var parentNode = node.parentNode;
			node.remove();
			if (parentNode != null)
				parentNode.select();
		}
	}
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._moveNode = function (tree, node, oldParent, newParent, index)
{
	var params = {};
	params.id = node.id;
	params.oldParent = oldParent.id;
	params.newParent = newParent.id;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/orgunit/move', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_ORGUNIT_TREE_ERROR_MOVE"/>", response, "org.ametys.odf.orgunit.OrgUnitTree.move"))
	{
		// Cancel the mode
		return false;
	}
	
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._updateNodeText = function (id, text)
{
	if (this._tree)
	{
		var node = this._tree.getNodeById(id);
		if (node != null)
		{
			node.setText(text);
		}
	}
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._isInTree = function (id)
{
	return this._tree.getNodeById(id) != null;
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._beforeLoad = function (treeLoader, node)
{
    treeLoader.baseParams.id = node.attributes.id;	
    treeLoader.baseParams.parentPath = node.attributes.path;	
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._onRender = function ()
{
	this._outOfDate = true;
	this.refresh();
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._refreshTree = function ()
{
	var rootNode = this._createRootNode ();
	this._tree.setRootNode(rootNode);
	
	this._tree.getRootNode().reload();
	
	this._refreshing = false;
	this.metAnError = false;
	this.upToDate();
}

/**
 * Refresh the tool
 * @params manual true if the refresh action was called by manually action
 */
org.ametys.odf.orgunit.OrgUnitTree.prototype.refresh = function (manual)
{
	if (manual)
	{
		this._metAnError = false;
	}
	
	if (this._refreshing)
	{
		// The view is refreshing, but let it
	}
	
	this.refreshing();
	
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.orgunit'});

	if (target != null)
	{
		if (this._currentContent == target.getParameters().id &amp;&amp; this.metAnError)
		{
			// Do not refresh the same parameters with an error
			this.upToDate();
			return;
		}
		
		// Change the current content
		this._currentContent = target.getParameters().id;
		this._refreshing = true;
		
		this._refreshTree();
	}
	else
	{
		//this._setInNoSelectionState();
		this.upToDate();
	}
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._open = function (node, e)
{
	org.ametys.uitool.ToolsManager.getInstance().openTool ("uitool-content", {'id': node.id});
}

org.ametys.odf.orgunit.OrgUnitTree.prototype._setInNoSelectionState = function()
{
	this._currentContent = null;
	//this._tree.setRootNode(new Ext.tree.TreeNode({text: 'test'}));
	this._metAnError = false;
}

org.ametys.odf.orgunit.OrgUnitTree.prototype.onMessage = function (messages)
{
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.orgunit'});
			
			if (target == null)
			{
				// No more target
				this._currentContent = null;
				this.upToDate();
			}
			else if (this._currentContent == target.getParameters().id)
			{
				// target is the same as before
				if (!this.metAnError)
				{
					this.upToDate();
				}
			}
			else if (target.getParameters().id != this._currentSelectedContentId)
			{
				this._expandPath(target.getParameters().id);
			}
		}
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.orgunit'});
			
			if (target == null)
				return;
			
			var parentId = messages[i].getType().getParameters() != null ? messages[i].getType().getParameters().parentId : null;
			if(parentId == null || parentId == "")
			{
				this._refreshNode(this._tree.getRootNode().id, this._selectNodeById, [target.getParameters().id]);
			}
			else
			{
				this._refreshNode(parentId, this._selectNodeById, [target.getParameters().id]);
			}	
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) {return target.getType() == "content"  &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.orgunit'});
			
			if (target == null)
				return;
			
			this._deleteNode (target.getParameters().id);
		}		
	}
}


org.ametys.odf.orgunit.TreeDropZone = Ext.extend(Ext.tree.TreeDropZone, {
	
	/** Override isValidDropPoint */
	isValidDropPoint: function(n, pt, dd, e, data) 
	{
		var isLeaf = n.node.leaf;
	 	var targetNode = n.node;
	 	if (isLeaf)
	 	{
	 		targetNode.leaf = false;	// Change leaf property to allow DD for leaf nodes
	 	}
	 	var result = org.ametys.odf.orgunit.TreeDropZone.superclass.isValidDropPoint.call(this, n, pt, dd, e, data);
	 	
 	 	return result;
	}
});


