/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.orgunit');

org.ametys.odf.orgunit.TreeDropZone = Ext.extend(Ext.tree.TreeDropZone, {
	
	/** Override isValidDropPoint */
	isValidDropPoint: function(n, pt, dd, e, data) 
	{
		var isLeaf = n.node.leaf;
	 	var targetNode = n.node;
	 	if (isLeaf)
	 	{
	 		targetNode.leaf = false;	// Change leaf property to allow DD for leaf nodes
	 	}
	 	var result = org.ametys.odf.orgunit.TreeDropZone.superclass.isValidDropPoint.call(this, n, pt, dd, e, data);
	 	
 	 	return result;
	}
});
/********************************************/
org.ametys.odf.orgunit.OrgUnitTreePanel = function(config) 
{
    config.loader = new org.ametys.odf.orgunit.OrgUnitXmlLoader ({
        dataUrl: getPluginDirectUrl('odf') + '/orgunit/tree',
        checkMode : config.checkMode
    });
    
	org.ametys.odf.orgunit.OrgUnitTreePanel.superclass.constructor.call(this, config);
	
	// Alphabetical sort
	this._treeSorter = new Ext.tree.TreeSorter(this, {
		folderSort: true,
		leafAttr: 'leafSort'
	});
}; 

Ext.extend(org.ametys.odf.orgunit.OrgUnitTreePanel, Ext.tree.TreePanel, {
	autoScroll: true,
    animate:true,
    enableDD:true,
    containerScroll: true,

	/**
     * @cfg {boolean} checkMode To select pages by checkboxes.  Defaults to 'false'.
     */
	checkMode : false,
	
    initEvents: function()
	{
		Ext.tree.TreePanel.superclass.initEvents.call(this);

		if(this.containerScroll)
		{
			Ext.dd.ScrollManager.register(this.body);
		}
		
		if((this.enableDD || this.enableDrop) &amp;&amp; !this.dropZone)
		{

			this.dropZone = new org.ametys.odf.orgunit.TreeDropZone (this, this.dropConfig || {
				ddGroup: this.ddGroup || "TreeDD", appendOnly: this.ddAppendOnly === true
			});
		}
		
		if((this.enableDD || this.enableDrag) &amp;&amp; !this.dragZone)
		{
			this.dragZone = new Ext.tree.TreeDragZone(this, this.dragConfig || {
				ddGroup: this.ddGroup || "TreeDD",
				scroll: this.ddScroll
			});
		}
	
		this.getSelectionModel().init(this);
	}
});

/**
 * Override the setRootNode method to unregister old root node
 */
org.ametys.odf.orgunit.OrgUnitTreePanel.prototype.setRootNode = function (node)
{
	var oldRoot = this.root;
	
	node = org.ametys.odf.orgunit.OrgUnitTreePanel.superclass.setRootNode.call(this, node);
	
	// Unregister old root node if exists
	if (oldRoot != null)
		this.unregisterNode(oldRoot);
	
    return node;
}

org.ametys.odf.orgunit.OrgUnitTreePanel.prototype.onRender = function(ct, position)
{
	org.ametys.odf.orgunit.OrgUnitTreePanel.superclass.onRender.call(this, ct, position);
}

/**
 * This function creates the root node
 * @return The created root node
 */
org.ametys.odf.orgunit.OrgUnitTreePanel.prototype.createRootNode = function (id)
{
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/orgunit', {'id': id}, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	// TODO Handle error
	
	var rootNode = new Ext.tree.AsyncTreeNode({
		draggable: false, //This node is not draggable
        text: response.selectSingleNode('orgunits/orgunit').getAttribute('title'),
        id: response.selectSingleNode('orgunits/orgunit').getAttribute('id'),
        icon: getPluginResourcesUrl ('odf') + '/img/orgunit/orgunit_16.png',
        type: 'orgunit'
    });
	
	this.setRootNode(rootNode);	
}
