/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.pdfexport');

//------------------------------------------------------------------
org.ametys.odf.pdfexport.PDFExport = function(controlId, controlConfiguration, controlPluginName)
{
	org.ametys.odf.pdfexport.PDFExport.chooseCatalogDelayedInitialized(org.ametys.odf.pdfexport.PDFExport._doExport);
	org.ametys.odf.pdfexport.PDFExport._box.show();
	
	var form = org.ametys.odf.pdfexport.PDFExport._form.getForm();
	form.findField('catalog').getStore().load();
	form.findField('catalog').setValue();
	form.findField('catalog').clearInvalid();
}

org.ametys.odf.pdfexport.PDFExport.chooseCatalogDelayedInitialized = function (callback)
{
	if (org.ametys.odf.pdfexport.PDFExport._initialized)
		return true;
	
	org.ametys.odf.pdfexport.PDFExport._form = new Ext.FormPanel ({
		border: false,
		items: [ 
		        new org.ametys.HtmlContainer ({
		        	html: "<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_CHOOSE_CATALOG_HINT'/>",
		        	cls: 'dialog-text-hint'
		        }),
		        new org.ametys.form.ComboField ({
		            mode: 'local',
		            forceSelection : true,
		   		 	triggerAction: 'all',
		   		 
		            fieldLabel : "<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_CATALOG'/>",
		            valueField : 'value',
		            displayField : 'displayText',
		            store: new Ext.data.XmlStore({
		                url: getPluginDirectUrl('odf') + '/catalogs.xml',
		                record: 'item',
		                fields: [
		                    {name: 'value', mapping: 'code'},
		                    {name: 'displayText', mapping: 'title'}
		                ]
		            }),
		            name: 'catalog',
		            allowBlank: false,
		            msgTarget: 'side',
		            width: 240
		        })
	    ]
	});
	
	org.ametys.odf.pdfexport.PDFExport._box = new org.ametys.DialogBox( {
		title : "<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_LABEL'/>",
		icon : getPluginResourcesUrl('odf') + "/img/actions/export_pdf_16.png",
		cls: 'text-dialog',
		width: 450,
		height: 150,
		autoScroll: true,
		items : [ org.ametys.odf.pdfexport.PDFExport._form ],
		closeAction: 'hide',
		buttons : [{
			text: "<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_OK_BUTTON'/>",
			handler: function () {org.ametys.odf.pdfexport.PDFExport._chooseCatalogCb (callback); }
		}, {
			text: "<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_CANCEL_BUTTON'/>",
			handler : function () { org.ametys.odf.pdfexport.PDFExport._box.hide(); }
		} ]
	});
	
	org.ametys.odf.pdfexport.PDFExport._initialized = true;
}

org.ametys.odf.pdfexport.PDFExport._chooseCatalogCb = function (callback)
{
	var form = org.ametys.odf.pdfexport.PDFExport._form.getForm();
	if (!form.isValid())
	{
		return;
	}
	
	var catalog = form.findField('catalog').getValue();
	
	if (typeof callback === 'function')
	{
		callback(catalog);
	}
}
org.ametys.odf.pdfexport.PDFExport._doExport = function (catalog)
{
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/' + catalog + '/generate-pdf', {}, 
			org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.pdfexport.PDFExport._pdfExportCb, 
			this, null);
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.pdfexport.PDFExport._pdfExportCb = function(response)
{
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_ERROR'/>", response, 'org.ametys.odf.pdfexport.PDFExport'))
    {
        throw "org.ametys.odf.pdfexport.PDFExport request failed";
    }
    
    org.ametys.odf.pdfexport.PDFExport._box.hide();
    
    var errorNode = response.selectSingleNode('ActionResult/error');
    if (errorNode != null &amp;&amp; errorNode[org.ametys.servercomm.ServerComm.xmlTextContent] != '')
    {
        var error = errorNode[org.ametys.servercomm.ServerComm.xmlTextContent];
        if (error == 'already-running')
        {
            Ext.Msg.show({
                title: "<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_ALREADY_RUNNING_MESSAGE_TITLE'/>",
                msg: "<i18n:text i18n:key='PLUGINS_ODF_PDFEXPORT_ALREADY_RUNNING_MESSAGE_TEXT'/>",
                buttons: Ext.Msg.OK,
                icon: Ext.Msg.ERROR
            });
        }
    }
    else
	{
	    Ext.Msg.show({
	        title: "<i18n:text i18n:key="PLUGINS_ODF_PDFEXPORT_LAUNCH_GENERATION_MESSAGE_TITLE" i18n:catalogue="plugin.odf"/>",
	        msg: "<i18n:text i18n:key="PLUGINS_ODF_PDFEXPORT_LAUNCH_GENERATION_MESSAGE_TEXT" i18n:catalogue="plugin.odf"/>",
	        buttons: Ext.Msg.OK,
	        icon: Ext.Msg.INFO
	    });
	}
}
