/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.program.Container');

//--------------------------------------------------------------------------------------
/**
 * Add a new sub-program to selected program, container or sub-program
 */
org.ametys.odf.program.Container.addSubProgram = function(control, configuration, index)
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { 
		return target.getType() == 'content' &amp;&amp; (target.getParameters().type == 'org.ametys.plugins.odf.Content.program' 
			|| target.getParameters().type == 'org.ametys.plugins.odf.Content.subProgram' 
				|| target.getParameters().type == 'org.ametys.plugins.odf.Content.container')
		});
	if (target == null)
		return;
	
	org.ametys.odf.program.Container.addSubProgram._parentId = target.getParameters().id;
	
	org.ametys.cms.buttons.content.CreateContentAction._configuration = configuration;
	org.ametys.cms.buttons.content.CreateContentAction._index = index;
	// @Override 'ok' function
	org.ametys.cms.buttons.content.CreateContentAction._okFn = org.ametys.odf.program.Container.addSubProgram._ok;
	
	org.ametys.cms.buttons.content.CreateContentAction._createBoxIfNeeded("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_SUBPROGRAMACTION_HELP1"/>", "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_SUBPROGRAMACTION_HELP2"/>");
	
	// Override title and icon
	org.ametys.cms.buttons.content.CreateContentAction._box.setTitle("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_SUBPROGRAMACTION_TITLE"/>" + "...");
	org.ametys.cms.buttons.content.CreateContentAction._box.setIconPath(getPluginResourcesUrl("odf") + "/img/education/parcours_16.png");
	Ext.getCmp("content-type-to-create").setValue(configuration["menu-" + index + "-content-type-to-create"]);
	Ext.getCmp("content-language-to-create").setValue("");
	
	org.ametys.cms.buttons.content.CreateContentAction._box.show();
	
	var f = Ext.getCmp("content-name-to-create");
	f.setValue("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_SUBPROGRAMACTION_CONTENTNAME"/>");
	f.focus(true, 100);	
}

org.ametys.odf.program.Container.addSubProgram._ok = function()
{
	var actionId = org.ametys.cms.buttons.content.CreateContentAction._configuration["menu-" + org.ametys.cms.buttons.content.CreateContentAction._index + "-workflowInitActionId"];
	
	var params = org.ametys.odf.program.Container.addSubProgram._getParams();
	if (params == null)
	{
		return;
	}
	
	org.ametys.cms.buttons.content.CreateContentAction._box.showWaitMsg();
	
	var serverMessage = new org.ametys.servercomm.ServerMessage("cms", 'init-workflow/' + actionId, params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.program.Container.addSubProgram._creationCb, this, params, "xml");	
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.program.Container.addSubProgram._creationCb = function(response, params)
{
	org.ametys.cms.buttons.content.CreateContentAction._box.hideWaitMsg();
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_CONTENT_CREATE_CONTAINER_CREATIONFAILED'/>", response, "org.ametys.cms.buttons.content.CreateContentAction"))
	{
		return;
	}

	org.ametys.cms.buttons.content.CreateContentAction._box.hide();
	
	var newContentId = response.selectSingleNode("ActionResult/contentId")[org.ametys.servercomm.ServerComm.xmlTextContent];

	var targets = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': newContentId})];

	var events = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED, {'parentId': org.ametys.odf.program.Container.addSubProgram._parentId}, targets)];
	org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);

	org.ametys.cms.buttons.content.CreateContentAction._finalizeCreation(response, params);
}

org.ametys.odf.program.Container.addSubProgram._getParams = function()
{
	var nameField = Ext.getCmp("content-name-to-create"); 
	if (!nameField.isValid())
	{
		return null;
	}
	
	var params = {};
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentName"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentTitle"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentType"] = Ext.getCmp("content-type-to-create").getValue();
	
	for (var c in org.ametys.cms.buttons.content.CreateContentAction._configuration)
	{
		var prefix = "menu-" + org.ametys.cms.buttons.content.CreateContentAction._index + "-";
		if (c.indexOf(prefix + "workflow-") == 0)
		{
			params[c.substring(prefix.length)] = org.ametys.cms.buttons.content.CreateContentAction._configuration[c];
		}
	}
	
	params["workflow-org.ametys.odf.workflow.CreateODFContentFunction$parentId"] = org.ametys.odf.program.Container.addSubProgram._parentId;

	return params;
}

//-------------------------------------------------------------------------------------
/**
 * Add a new container to selected program, container or sub-program
 */
org.ametys.odf.program.Container.addContainer = function(control, configuration, index)
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { 
		return target.getType() == 'content' &amp;&amp; (target.getParameters().type == 'org.ametys.plugins.odf.Content.program' 
			|| target.getParameters().type == 'org.ametys.plugins.odf.Content.subProgram' 
				|| target.getParameters().type == 'org.ametys.plugins.odf.Content.container')
		});
	if (target == null)
		return;
	
	org.ametys.odf.program.Container.addContainer._parentId = target.getParameters().id;
	
	org.ametys.cms.buttons.content.CreateContentAction._configuration = configuration;
	org.ametys.cms.buttons.content.CreateContentAction._index = index;
	
	// @Override 'ok' function
	org.ametys.cms.buttons.content.CreateContentAction._okFn = org.ametys.odf.program.Container.addContainer._ok;
	
	org.ametys.cms.buttons.content.CreateContentAction._createBoxIfNeeded("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_CONTAINER_ACTION_HELP1"/>", "<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_CONTAINER_ACTION_HELP2"/>");
	
	// Override title and icon
	org.ametys.cms.buttons.content.CreateContentAction._box.setTitle("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_CONTAINER_ACTION_TITLE"/>" + "...");
	org.ametys.cms.buttons.content.CreateContentAction._box.setIconPath(getPluginResourcesUrl("odf") + "/img/education/container_16.png");
	Ext.getCmp("content-type-to-create").setValue(configuration["menu-" + index + "-content-type-to-create"]);
	Ext.getCmp("content-language-to-create").setValue("");
	
	org.ametys.cms.buttons.content.CreateContentAction._box.show();
	
	var f = Ext.getCmp("content-name-to-create");
	f.setValue("<i18n:text i18n:key="PLUGINS_ODF_CONTENT_CREATE_CONTAINER_ACTION_CONTENTNAME"/>");
	f.focus(true, 100);	
}
org.ametys.odf.program.Container.addContainer._ok = function()
{
	var actionId = org.ametys.cms.buttons.content.CreateContentAction._configuration["menu-" + org.ametys.cms.buttons.content.CreateContentAction._index + "-workflowInitActionId"];
	
	var params = org.ametys.odf.program.Container.addContainer._getParams();
	if (params == null)
	{
		return;
	}
	
	org.ametys.cms.buttons.content.CreateContentAction._box.showWaitMsg();
	
	var serverMessage = new org.ametys.servercomm.ServerMessage("cms", 'init-workflow/' + actionId, params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.program.Container.addContainer._creationCb, this, params, "xml");	
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.program.Container.addContainer._creationCb = function(response, params)
{
	org.ametys.cms.buttons.content.CreateContentAction._box.hideWaitMsg();
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_CONTENT_CREATE_CONTAINER_CREATIONFAILED'/>", response, "org.ametys.cms.buttons.content.CreateContentAction"))
	{
		return;
	}

	org.ametys.cms.buttons.content.CreateContentAction._box.hide();
	
	var newContentId = response.selectSingleNode("ActionResult/contentId")[org.ametys.servercomm.ServerComm.xmlTextContent];

	var targets = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': newContentId})];

	var events = [org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED, {'parentId': org.ametys.odf.program.Container.addContainer._parentId}, targets)];
	org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);
}

org.ametys.odf.program.Container.addContainer._getParams = function()
{
	var nameField = Ext.getCmp("content-name-to-create"); 
	if (!nameField.isValid())
	{
		return null;
	}
	
	var params = {};
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentName"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentTitle"] = nameField.getValue();
	params["workflow-org.ametys.cms.workflow.CreateContentFunction$contentType"] = Ext.getCmp("content-type-to-create").getValue();
	
	for (var c in org.ametys.cms.buttons.content.CreateContentAction._configuration)
	{
		var prefix = "menu-" + org.ametys.cms.buttons.content.CreateContentAction._index + "-";
		if (c.indexOf(prefix + "workflow-") == 0)
		{
			params[c.substring(prefix.length)] = org.ametys.cms.buttons.content.CreateContentAction._configuration[c];
		}
	}
	
	params["workflow-org.ametys.odf.workflow.CreateODFContentFunction$parentId"] = org.ametys.odf.program.Container.addContainer._parentId;

	return params;
}
