/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.program.Export2CDMfr');
//------------------------------------------------------------------

/**
 * Export a program to CDM-fr format
 */
org.ametys.odf.program.Export2CDMfr = function (id, config, pluginName)
{
	//Get the ID of the selected program
    var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; (target.getParameters().type == 'org.ametys.plugins.odf.Content.program' || target.getParameters().type == 'org.ametys.plugins.odf.Content.subProgram');});
	
	if (target == null)
		return; 
	
    var url = getPluginDirectUrl('odf') + '/export-cdmfr.xml?id=' + target.getParameters().id + "&amp;siteName=" + context.parameters.siteName;
    window.open(url);
}


//------------------------------------------------------------------
org.ametys.odf.program.Validate = function (item, event)
{
	// Get the ID of the selected program
    var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var allTargets = org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.program'});
	
	if (allTargets.length == 0)
		return; 
	
	var contentIds = [];
	for (var i=0; i &lt; allTargets.length; i++)
	{
		contentIds.push(allTargets[i].getParameters().id);
	}
	
	var params = {'contentIds': contentIds};
	var serverMessage = new org.ametys.servercomm.ServerMessage("odf", 'program/is-valid', params, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.program._isValidCb, this, [item], "text");
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.odf.program._isValidCb = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_CHECK_ERROR"/>", response, "org.ametys.odf.program.Validate"))
	{
		return;
	}
	
	var result = Ext.util.JSON.decode(response[org.ametys.servercomm.ServerComm.xmlTextContent]);
	if (result.invalidPrograms)
	{
		var msg = org.ametys.odf.program.Validate._getErrorMessage (result);
		Ext.Msg.show({
			title: "<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_LABEL"/>",
			msg: msg,
			buttons: Ext.Msg.OK,
			icon: Ext.Msg.ERROR
		});
	}
	
	// Do workflow action on all valid programs
	var validPrograms = result.validPrograms;
	if (validPrograms.length &gt; 0)
	{
		var item = args[0];
		org.ametys.odf.program.Validate.doMenuAct (item, validPrograms);
	}
}

//Mimic the menuAct and doMenuAct from the WorkflowMenu.
org.ametys.odf.program.Validate.doMenuAct = function(item, validPrograms)
{
    var params = item.ribbonControl._lastParams;
    var targets = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTargets('content', {'ids': validPrograms});
    
    var url = 'validate-action/' + item.actionId;
    
    org.ametys.servercomm.ServerComm.getInstance().suspend();
    for (var i=0; i &lt; validPrograms.length; i++)
    {
    	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', url, {contentId: validPrograms[i], id: validPrograms[i], comment: ''}, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, org.ametys.odf.program.Validate.workflowActionCallback, item.ribbonControl, {content: validPrograms[i], max: validPrograms.length});
        org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
    }
    org.ametys.servercomm.ServerComm.getInstance().restart();

    var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGING, null, targets);
    org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
}

org.ametys.odf.program.Validate.cumulate = 0;
org.ametys.odf.program.Validate.cumulatedIds = [];
org.ametys.odf.program.Validate.contentsWithPubError = {};
org.ametys.odf.program.Validate.contentsWithExportError = [];
org.ametys.odf.program.Validate.workflowActionCallback = function(response, args)
{
	org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_CMS_WORKFLOW_ERROR_DESC' i18n:catalogue='plugin.cms'/>" + args.content , response, "org.ametys.odf.program.Validate");
    
	var contentWithPubError = response.selectSingleNode("ActionResult/cdmfr-publication-error")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (contentWithPubError != '')
	{
		org.ametys.odf.program.Validate.contentsWithPubError[contentWithPubError] = '';
	}
	
	var serverUrlPubError = response.selectSingleNode("ActionResult/cdmfr-publication-failed-url")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (serverUrlPubError != '')
	{
		org.ametys.odf.program.Validate.contentsWithPubError[contentWithPubError] = serverUrlPubError;
	}
	
	var contentWithExportError = response.selectSingleNode("ActionResult/cdmfr-export-error")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (contentWithExportError != '')
	{
		org.ametys.odf.program.Validate.contentsWithExportError.push(contentWithExportError);
	}
	
	org.ametys.odf.program.Validate.cumulate++;
	org.ametys.odf.program.Validate.cumulatedIds.push(args.content)
	
	if (org.ametys.odf.program.Validate.cumulate == args.max)
	{
		var msg = org.ametys.odf.program.Validate._getErrorMessage2(org.ametys.odf.program.Validate.contentsWithPubError, org.ametys.odf.program.Validate.contentsWithExportError);
		if (msg != '')
		{
			Ext.Msg.show({
				title: "<i18n:text i18n:key="PLUGINS_ODF_PUBLISH_PROGRAM_LABEL"/>",
				msg: msg,
				buttons: Ext.Msg.OK,
				icon: Ext.Msg.WARNING
			});
		}
		
		var nonoptimizedTargets = [];
		if (org.ametys.odf.program.Validate.cumulatedIds.length &gt; 0)
		{
			nonoptimizedTargets = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTargets("content", {'ids': org.ametys.odf.program.Validate.cumulatedIds});
		}
		
		var messages = [];
		messages.push(org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGED, null, nonoptimizedTargets));
		messages.push(org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_LOCKCHANGED, null, nonoptimizedTargets));
		org.ametys.messagebus.MessageBus.getInstance().fireMessages(messages);
		
		org.ametys.odf.program.Validate.cumulatedIds = []
		org.ametys.odf.program.Validate.contentsWithPubError = {};
		org.ametys.odf.program.Validate.contentsWithExportError = [];
		org.ametys.odf.program.Validate.cumulate = 0;
	}
}

org.ametys.odf.program.Validate._getErrorMessage = function (result)
{
	var html = "<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_ERROR_MSG_1"/>";
	var invalidPrograms = result.invalidPrograms;
	for (var i=0; i &lt; invalidPrograms.length; i++)
	{
		if (i != 0)
			html += ", ";
		html += invalidPrograms[i];
	}
	
	html += "<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_ERROR_MSG_2"/>";
	if (result.invalidCourses)
	{
		var invalidCourses = result.invalidCourses;
		html += "&lt;br/&gt;&lt;b&gt;- " + invalidCourses.length + "<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_ERROR_MSG_ELP"/>:&lt;/b&gt; ";
		for (var i=0; i &lt; invalidCourses.length; i++)
		{
			if (i != 0)
				html += ", ";
			html += invalidCourses[i];
		}
	}
	
	if (result.invalidOrgUnits)
	{
		var invalidOrgUnits = result.invalidOrgUnits;
		html += "&lt;br/&gt;&lt;b&gt;- " + invalidOrgUnits.length + "<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_ERROR_MSG_ORGUNIT"/>:&lt;/b&gt; ";
		for (var i=0; i &lt; invalidOrgUnits.length; i++)
		{
			if (i != 0)
				html += ", ";
			html += invalidOrgUnits[i];
		}
	}
	
	if (result.invalidPersons)
	{
		var invalidPersons = result.invalidPersons;
		html += "&lt;br/&gt;&lt;b/&gt;- " + invalidPersons.length + "<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_ERROR_MSG_PERSON"/>:&lt;/b/&gt; ";
		for (var i=0; i &lt; invalidPersons.length; i++)
		{
			if (i != 0)
				html += ", ";
			html += invalidPersons[i];
		}
	}
	
	html += "<i18n:text i18n:key="PLUGINS_ODF_VALIDATE_PROGRAM_ERROR_MSG_3"/>";
	return html;
}

org.ametys.odf.program.Validate._getErrorMessage2 = function (contentsWithPubError, contentsWithExportError)
{
	var html = '';
	if (Object.keys(contentsWithPubError).length > 0)
	{
		html += "<i18n:text i18n:key="PLUGINS_ODF_PUBLISH_PROGRAM_PORTAL_ERROR"/>";
		for (var i in contentsWithPubError)
		{
			html += "&lt;br/&gt;- " + i;
			if (contentsWithPubError[i] != '')
			{
				html += "&lt;span style=\"font-size: 0.9em; font-style:italic\"&gt; (<i18n:text i18n:key='PLUGINS_ODF_VALIDATE_PROGRAM_ERROR_FAILED_URL'/>" + contentsWithPubError[i] + ")&lt;/span&gt;";
			}
		}
		html += "&lt;br/&gt;&lt;br/&gt;";
	}
	
	if (contentsWithExportError.length &gt; 0)
	{
		html += "<i18n:text i18n:key="PLUGINS_ODF_PUBLISH_PROGRAM_CDMFR_ERROR"/>";
		for (var i=0; i &lt; contentsWithExportError.length; i++)
		{
			if (i != 0)
				html += ", ";
			html += contentsWithExportError[i];
		}
		html += "&lt;br/&gt;&lt;br/&gt;";
	}
	
	if (contentsWithPubError.length &gt; 0 || contentsWithExportError.length &gt; 0)
	{
		html += "<i18n:text i18n:key="PLUGINS_ODF_PUBLISH_PROGRAM_SEE_LOGS"/>";
	}
	
	return html;
}
