/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.program');

org.ametys.odf.program.ProgramTree = function(id, pluginName) 
{
	org.ametys.odf.program.ProgramTree.superclass.constructor.call(this, id, pluginName);
};

Ext.extend(org.ametys.odf.program.ProgramTree, org.ametys.uitool.tool.Tool, {});

org.ametys.odf.program.ProgramTree.prototype._metAnError = false;
org.ametys.odf.program.ProgramTree.prototype._refreshing = false;
org.ametys.odf.program.ProgramTree.prototype._noSelectionNode;

org.ametys.odf.program.ProgramTree.prototype.createPanel = function()
{	
	var loader = new org.ametys.odf.program.ProgramStructXmlLoader ({
		dataUrl : getPluginDirectUrl('odf') + '/program-tree.xml' 
	});	
	
	this._tree = new Ext.tree.TreePanel({
		region: 'center',
		split:true,
		border: false,
		
		autoScroll:true,
	    animate:true,
	    enableDD:true,
		
	    containerScroll: true,
		
		loader: loader,
		
		root: new Ext.tree.TreeNode (),
        rootVisible : true,
        
        initEvents: function()
    	{
    		Ext.tree.TreePanel.superclass.initEvents.call(this);

    		if(this.containerScroll)
    		{
    			Ext.dd.ScrollManager.register(this.body);
    		}
    		
    		if((this.enableDD || this.enableDrop) &amp;&amp; !this.dropZone)
    		{

    			this.dropZone = new org.ametys.odf.program.ProgramTreeDropZone (this, this.dropConfig || {
    				ddGroup: this.ddGroup || "TreeDD", appendOnly: this.ddAppendOnly === true
    			});
    		}
    		
    		if((this.enableDD || this.enableDrag) &amp;&amp; !this.dragZone)
    		{
    			this.dragZone = new Ext.tree.TreeDragZone(this, this.dragConfig || {
    				ddGroup: this.ddGroup || "TreeDD",
    				scroll: this.ddScroll
    			});
    		}
    	
    		this.getSelectionModel().init(this);
    	}
	});
	
	this._tree.addListener ('blur', this._onBlur, this);
	this._tree.addListener ('focus', this._onFocus, this);
	
	this._tree.addListener ('beforemovenode', this._moveNode, this);
	this._tree.getSelectionModel().addListener('selectionchange', this._onSelectionChange, this);
	this._tree.getLoader().addListener("beforeload", this._beforeLoad, this);
	this._tree.getLoader().addListener("load", this._onLoad, this);
	this._tree.addListener("afterrender", this._refreshTree, this);
	this._tree.on('dblclick', this._open);
	
	this._noSelectionNode = new Ext.tree.TreeNode({text: "<i18n:text i18n:key='PLUGINS_ODF_PROGRAM_TREE_NO_SELECTION_NODE'/>"});
	this._noSelectionNode.on('beforeclick', function(node, event) {return false;});
	
	return this._tree;
}

/**
 * Listener when the panel receives the focus
 * Change the ribbon title and send a selection message
 * @private
 */
org.ametys.odf.program.ProgramTree.prototype._onFocus = function ()
{
	this._hasFocus = true;

	if (this._tree != null)
	{
		var node = this._tree.getSelectionModel().getSelectedNode();
		this._currentNode = node;
		this._sendMessage(node);
	}
}
/**
 * Listener when the panel looses the focus
 * Change the ribbon title.
 * @private
 */
org.ametys.odf.program.ProgramTree.prototype._onBlur = function ()
{
	this._hasFocus = false;
}


org.ametys.odf.program.ProgramTree.prototype.setParams = function (params)
{
	this._params = params;
}

org.ametys.odf.program.ProgramTree.prototype._createRootNode = function ()
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.program'});
	
	if (target == null)
		return new Ext.tree.TreeNode ();
	
	var rootNode = new Ext.tree.AsyncTreeNode({
        text: target.getParameters().title,
        id: target.getParameters().id,
        name: target.getParameters().title,
        icon: getPluginResourcesUrl ('odf') + '/img/education/education_16.png',
        type: 'program'
    });
	
	return rootNode;
}

org.ametys.odf.program.ProgramTree.prototype._moveNode = function (tree, node, oldParent, newParent, index)
{
	// Move
	var params = {};
	params.id = node.id;
	params.oldParent = oldParent.id;
	params.newParent = newParent.id;
	
	var sibling = newParent.item(index);
	if (sibling != null)
	{
		params.sibling = sibling.id;
	}
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/program-tree/move', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_PROGRAM_TREE_ERROR_MOVE"/>", response, "org.ametys.odf.program.ProgramTree.move"))
	{
		// Cancel the mode
		return false;
	}
	
	var locked = response.selectSingleNode("ActionResult/locked") != null ? response.selectSingleNode("ActionResult/locked")[org.ametys.servercomm.ServerComm.xmlTextContent] == 'true' : false;
	if (locked)
	{
		var msg = response.selectSingleNode("ActionResult/message")[org.ametys.servercomm.ServerComm.xmlTextContent];
		Ext.Msg.show({
			title: "<i18n:text i18n:key="PLUGINS_ODF_PROGRAM_TREE_MOVE_FAILED"/>",
			msg: msg,
			buttons: Ext.Msg.OK,
			icon: Ext.MessageBox.ERROR
		});
		
		// Cancel the move
		return false;
	}
	
}

org.ametys.odf.program.ProgramTree.prototype._onSelectionChange = function (sm, node)
{
	this._sendMessage (node);
}

org.ametys.odf.program.ProgramTree.prototype._sendMessage = function (node)
{
	var target = null;
    if (node != null)
    {
    	if (node.attributes.type == 'courselist')
    	{
    		target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("course-list", {'id': node.id, 'name': node.attributes.name, 'title': node.attributes.title, 'lang': node.attributes.lang});
    	}
    	else
    	{
    		var params = {'id': node.id};
    		if (node.attributes.type == 'course')
    		{
    			params.parentList = node.parentNode != null ? node.parentNode.id : null;
    		}
    		target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", params);
    	}
    }
	
	var message = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, target != null ? [target] : []);
	org.ametys.messagebus.MessageBus.getInstance().fireMessages([message]);
}

org.ametys.odf.program.ProgramTree.prototype._selectNode = function (id, callback, args)
{
	var node = this._tree.getNodeById(id);
	if (node != null)
	{
		node.select();
		this._currentSelectedNodeId = id;
	}
}

/**
 * Refresh a node
 * @param id the id of the node to refresh
 */
org.ametys.odf.program.ProgramTree.prototype._refreshNode = function (id, callback, args)
{
	var node = this._tree.getNodeById(id);
	if (node != null)
	{
		if (typeof callback == 'function')
		{
			node.reload(callback.createDelegate(this, args));
		}
		else
		{
			node.reload();
		}
	}
}

/**
 * Update the text of a node
 * @param id the id of the node
 * @param text the text to update
 */
org.ametys.odf.program.ProgramTree.prototype._updateNodeText = function (id, text)
{
	if (this._tree)
	{
		var node = this._tree.getNodeById(id);
		if (node != null)
		{
			node.setText(text);
		}
	}
}

/**
 * Delete a node
 * @param id the id of the node to delete
 */
org.ametys.odf.program.ProgramTree.prototype._deleteNode = function (id)
{
	if (this._tree)
	{
		var node = this._tree.getNodeById(id);
		if (node == null)
			return;
		
		if (node.isRoot)
		{
			this._setInNoSelectionState();
		}
		else
		{
			var parentNode = node.parentNode;
			node.remove();
			if (parentNode != null)
				parentNode.select();
		}
	}
}

org.ametys.odf.program.ProgramTree.prototype._isInTree = function (id)
{
	return this._tree.getNodeById(id) != null;
}

org.ametys.odf.program.ProgramTree.prototype._beforeLoad = function (treeLoader, node)
{
    treeLoader.baseParams.id = node.attributes.id;	
}

org.ametys.odf.program.ProgramTree.prototype._onLoad = function (treeLoader, node)
{
	if (node.isRoot)
	{
		this._tree.getRootNode().select();
	}
	
}

org.ametys.odf.program.ProgramTree.prototype._refreshTree = function ()
{
	var rootNode = this._createRootNode ();
	this._tree.setRootNode(rootNode);
	
	this._tree.getRootNode().reload();
	
	this._refreshing = false;
	this.metAnError = false;
	this.upToDate();
}

org.ametys.odf.program.ProgramTree.prototype._onRender = function ()
{
	this._outOfDate = true;
	this.refresh();
}

/**
 * Refresh the tool
 * @params manual true if the refresh action was called by manually action
 */
org.ametys.odf.program.ProgramTree.prototype.refresh = function (manual)
{
	if (manual)
	{
		this._metAnError = false;
	}
	
	if (this._refreshing)
	{
		// The view is refreshing, but let it
	}
	
	this.refreshing();
	
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.program'});

	if (target != null)
	{
		if (this._currentContent == target.getParameters().id &amp;&amp; this.metAnError)
		{
			// Do not refresh the same parameters with an error
			this.upToDate();
			return;
		}
		
		// Change the current content
		this._currentContent = target.getParameters().id;
		this._refreshing = true;
		
		this._refreshTree();
	}
	else
	{
		this._setInNoSelectionState();
		this.upToDate();
	}
}

org.ametys.odf.program.ProgramTree.prototype._open = function (node, e)
{
	if (node.attributes.type == 'courselist' || node.attributes.type == 'container')
	{
		return;
	}
	org.ametys.uitool.ToolsManager.getInstance().openTool ("uitool-content", {'id': node.id});
}

org.ametys.odf.program.ProgramTree.prototype.onMessage = function (messages)
{
	function _testTarget (target)
	{
		return target.getType() == "content" &amp;&amp; (
				target.getParameters().type == 'org.ametys.plugins.odf.Content.program' ||
				target.getParameters().type == 'org.ametys.plugins.odf.Content.container' ||
				target.getParameters().type == 'org.ametys.plugins.odf.Content.subProgram' ||
				target.getParameters().type == 'org.ametys.plugins.odf.Content.course'
				);
	}
	
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
            var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == 'content' &amp;&amp; target.getParameters().type == 'org.ametys.plugins.odf.Content.program'; });
			
			if (target == null)
			{
				// No more target
				//this.upToDate();
				//this._setInNoSelectionState();
			}
			else if (this._currentContent == target.getParameters().id)
			{
				// target is the same as before
				if (!this.metAnError)
				{
					this.upToDate();
				}
			}
			else if (this._isInTree (target.getParameters().id))
			{
				if (target.getParameters().id == this._currentSelectedNodeId)
				{
					// same selection
					return;
				}
				
				this._selectNode(target.getParameters().id);
			}
			else if (this._currentContent != target.getParameters().id)
			{
				// target has changed
				this.outOfDate(true);
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return _testTarget(target) || target.getType() == "course-list";});
			
			if (target != null)
			{
				var node = this._tree.getNodeById(target.getParameters().id);
				if (node != null &amp;&amp; target.getParameters().title != null)
				{
					node.setText(target.getParameters().title + " [" + node.attributes.code + "]");
				}
				this._refreshNode(target.getParameters().id);
				return;
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return _testTarget(target) || target.getType() == "course-list";});
			
			if (target != null)
			{
				// refresh the parent node
				var parentId = target.getType() == "course-list" ? target.getParameters().parentId : (messages[i].getType().getParameters() != null ? messages[i].getType().getParameters().parentId : null);
				var parentNode = parentId != null ? this._tree.getNodeById(parentId) : null;
				if (parentNode != null)
				{
					// Make sure to render plus/minus icon
					parentNode.leaf = false;
					this._refreshNode(parentId, this._selectNode, [target.getParameters().id]);
				}
				return;
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED)
		{
			var targets = messages[i].getTargets();
			
			target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return _testTarget(target) || target.getType() == "course-list";});
			
			if (target == null)
				return;
			
			this._deleteNode (target.getParameters().id);
		}
	}
}

org.ametys.odf.program.ProgramTree.prototype._setInNoSelectionState = function()
{
	this._currentContent = null;
	this._currentSelectedNodeId = null;
	this._tree.setRootNode(this._noSelectionNode);
	this._metAnError = false;
}

org.ametys.odf.program.ProgramTreeDropZone = Ext.extend(Ext.tree.TreeDropZone, {
	
	/** Override isValidDropPoint */
	isValidDropPoint: function(n, pt, dd, e, data) 
	{
		var targetNode = n.node;
		var sourceNode = dd.dragData.node;
		
		var srcType = sourceNode.attributes.type;
		var targetType = targetNode.attributes.type;
		
		if ((srcType == 'course' &amp;&amp; pt == 'append' &amp;&amp; targetType != 'courselist')
			|| (srcType == 'course' &amp;&amp; (pt == 'below' || pt == 'above') &amp;&amp; targetType != 'course')
			|| (srcType == 'container' &amp;&amp; (targetType == 'courselist' || targetType == 'course'))
			|| (srcType == 'subprogram' &amp;&amp; (targetType == 'courselist' || targetType == 'course'))
			|| (srcType == 'courselist' &amp;&amp; pt == 'append' &amp;&amp; targetType == 'courselist')
			|| (srcType == 'courselist' &amp;&amp; (pt == 'below' || pt == 'above') &amp;&amp; targetType != 'courselist'))
		{
			// Invalid drop
			return false;
		}
		
		var isLeaf = targetNode.leaf;
	 	if (isLeaf)
	 	{
	 		targetNode.leaf = false;	// Change leaf property to allow DD for leaf nodes
	 	}
	 	
	 	var result = org.ametys.odf.orgunit.TreeDropZone.superclass.isValidDropPoint.call(this, n, pt, dd, e, data);
 	 	return result;
	}
});

