/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.program.button');

/**
 * Menu that is enabled on a program only.
 */
org.ametys.odf.program.button.OdfContentMenu = function(id, configuration, pluginName) 
{
    org.ametys.odf.program.button.OdfContentMenu.superclass.constructor.call(this, id, configuration, pluginName);
    
    if (configuration['content-types'] != null)
    {
        this._contentTypes = configuration['content-types'].split('|');
    }
};

Ext.extend(org.ametys.odf.program.button.OdfContentMenu, org.ametys.cms.ribbon.button.Menu, {});

/**
 * Get the messages to determine enable / disable
 * @param {org.ametys.messagebus.message.Message[]} messages The messages received
 */
org.ametys.odf.program.button.OdfContentMenu.prototype.onMessage = function(messages)
{
    for (var i = 0; i < messages.length; i++)
    {
        var message = messages[i];
        if (message.getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
        {
            var targets = message.getTargets();
            var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._testTarget.createDelegate(this));

            this.getElements().each(function(element) {
                element.setDisabled(target == null);
                if (target != null)
                {
                    var language = target.getParameters().lang;
                    
                    for (var itemId in element._galleryItems)
                    {
                        var item = element._galleryItems[itemId];
                        item.setDisabled(item.actionId == language);
                    }
                }
            });
        }
    }
}

org.ametys.odf.program.button.OdfContentMenu.prototype._testTarget = function(target)
{
    return target.getType() == 'content' && this._contentTypes.indexOf(target.getParameters().type) > -1;
}
