/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.rights.context');

org.ametys.odf.rights.context.ComposanteContextInitialize = function(tool, context)
{
	// Open sitemap
	org.ametys.uitool.ToolsManager.getInstance().openTool('uitool-odf-orgunit-tree', {});
	
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content" &amp;&amp; target.getParameters()['type'] == "org.ametys.plugins.odf.Content.orgunit";});
	
	if (target == null)
	{
		tool.updateContext (null, true);
		tool.updateContextHelperText ("<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_NO_SELECTION"/>");
	}
	else
	{
		if (target.getParameters()['rightContext'] != null)
		{
			var ctx = '/orgunits/fr' + target.getParameters().rightContext;
			
			var text = "<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_COMPOSANTE_1"/>";
			text += '&lt;b&gt;' + target.getParameters().title + '&lt;/b&gt;'
			text += "<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_COMPOSANTE_2"/>";
			
			tool.updateContext (ctx, true);
			tool.updateContextHelperText (text);
		}
		else
		{
			var ctx = '/orgunits/fr'; 
			var text = "<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_COMPOSANTES"/>";
			tool.updateContext (ctx, true);
			tool.updateContextHelperText (text);
		}
	}
	
}

org.ametys.odf.rights.context.ComposanteContextSelectionListener = function(tool, targets)
{
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "content"  &amp;&amp; target.getParameters()['type'] == "org.ametys.plugins.odf.Content.orgunit";});
	
	if (target != null)
	{
		if (target.getParameters()['rightContext'] != null)
		{
			var ctx = '/orgunits/fr' + target.getParameters().rightContext;
		
			var text = "<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_COMPOSANTE_1"/>";
			text += '&lt;b&gt;' + target.getParameters().title + '&lt;/b&gt;'
			text += "<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_COMPOSANTE_2"/>";
			
			tool.updateContext (ctx, true);
			tool.updateContextHelperText (text);
		}
		else
		{
			var ctx = '/orgunits/fr';
			
			var text = "<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_COMPOSANTES"/>";
			
			tool.updateContext (ctx);
			tool.updateContextHelperText (text);
		}
		
		return;
	}
	
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "profile";})
	if (target == null)
	{
		var text = "<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_COMPOSANTE_CONTEXT_NO_SELECTION"/>";
		
		tool.updateContext (null);
		tool.updateContextHelperText (text);
	}
}

org.ametys.odf.rights.context.ComposanteContextUpToContext = function(tool, context)
{
	var regresult;
	if (regresult = /^\/([^\/]*)\/orgunits\/([a-z]{2})\/(.*)$/.exec(context))
	{
		var params = {"siteName": regresult[1], "language": regresult[2], "path": regresult[3] }; 
		var serverMessage = new org.ametys.servercomm.ServerMessage('odf', 'orgunit/path-to-id.xml', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
		var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);

		if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_CONVERTNAMETOID_ERROR"/>", response, "org.ametys.odf.rights.context.ComposanteContextUpToContext"))
		{
			return false;
		}
		
		var id = response.selectSingleNode("content")[org.ametys.servercomm.ServerComm.xmlTextContent];
		if (id != '')
		{
			var contentTarget = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': id});
			var message = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, [contentTarget]);
			org.ametys.messagebus.MessageBus.getInstance().fireMessages([message]);
		}
	}
	else if (regresult = /^\/orgunits\/([a-z]{2})\/(.*)$/.exec(context))
	{
		var params = {"language": regresult[1], "path": regresult[2] }; 
		var serverMessage = new org.ametys.servercomm.ServerMessage('odf', 'orgunit/path-to-id.xml', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
		var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);

		if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_CONVERTNAMETOID_ERROR"/>", response, "org.ametys.odf.rights.context.ComposanteContextUpToContext"))
		{
			return false;
		}
		
		var id = response.selectSingleNode("content")[org.ametys.servercomm.ServerComm.xmlTextContent];
		if (id != '')
		{
			var contentTarget = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': id});
			var message = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, [contentTarget]);
			org.ametys.messagebus.MessageBus.getInstance().fireMessages([message]);
		}
	}
	else if (regresult = /^\/([^\/]*)\/orgunits\/([a-z]{2})$/.exec(context))
	{
		var params = {"siteName": regresult[1], "language": regresult[2]}; 
		var serverMessage = new org.ametys.servercomm.ServerMessage('odf', 'orgunit/path-to-id.xml', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
		var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
		
		if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_CONVERTNAMETOID_ERROR"/>", response, "org.ametys.odf.rights.context.ComposanteContextUpToContext"))
		{
			return false;
		}
		
		var id = response.selectSingleNode("content")[org.ametys.servercomm.ServerComm.xmlTextContent];
		if (id != '')
		{
			var contentTarget = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': id});
			var message = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, [contentTarget]);
			org.ametys.messagebus.MessageBus.getInstance().fireMessages([message]);
		}
	}
	else if (regresult = /^\/orgunits\/([a-z]{2})$/.exec(context))
	{
		var params = {"language": regresult[1]}; 
		var serverMessage = new org.ametys.servercomm.ServerMessage('odf', 'orgunit/path-to-id.xml', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
		var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
		
		if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_RIGHTS_ASSIGNMENT_CONVERTNAMETOID_ERROR"/>", response, "org.ametys.odf.rights.context.ComposanteContextUpToContext"))
		{
			return false;
		}
		
		var id = response.selectSingleNode("content")[org.ametys.servercomm.ServerComm.xmlTextContent];
		if (id != '')
		{
			var contentTarget = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': id});
			var message = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED, null, [contentTarget]);
			org.ametys.messagebus.MessageBus.getInstance().fireMessages([message]);
		}
	}
}