/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.program.workflow');

org.ametys.odf.program.workflow.GlobalValidateAction = function()
{
	Ext.Msg.confirm("<i18n:text i18n:key="WORKFLOW_ACTION_GLOBAL_VALIDATION"/>", 
			"<i18n:text i18n:key="WORKFLOW_ACTION_GLOBAL_VALIDATION_CONFIRM"/>", 
			function (answer) {
				if (answer == 'yes')
				{
					org.ametys.odf.program.workflow.GlobalValidateAction._doAction (this.contents, this.actionId, this.ribbonControl);
				}
			},
			this
	);
	
}

org.ametys.odf.program.workflow.GlobalValidateAction._doAction = function (contents, actionId, ribbonControl)
{
	ribbonControl.contentsWithPubError = {};
	ribbonControl.contentsWithExportError = [];
	
	var targets = [];

    org.ametys.servercomm.ServerComm.getInstance().suspend();
    for (var i=0; i &lt; contents.length; i++)
    {
        targets.push(org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget("content", {'id': contents[i]}));

        var serverMessage = new org.ametys.servercomm.ServerMessage("odf", "validate-action/" + actionId, 
        		{contentId: contents[i], id: contents[i]}, 
        		org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, 
        		function (response, args) {org.ametys.odf.program.workflow.GlobalValidateAction._workflowActionCallback (response, args, ribbonControl)},
        		ribbonControl, 
        		{content: contents[i], max: contents.length}
        );
        org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
    }
    org.ametys.servercomm.ServerComm.getInstance().restart();

    var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGING, null, targets);
    org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
}

org.ametys.odf.program.workflow.GlobalValidateAction._workflowActionCallback = function(response, args, ribbonControl)
{
	org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="WORKFLOW_ACTION_GLOBAL_VALIDATION_ERROR"/>" + args.content , response, "org.ametys.cms.ribbon.button.WorkflowMenu");
	
	var contentWithPubError = response.selectSingleNode("ActionResult/cdmfr-publication-error")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (contentWithPubError != '')
	{
		ribbonControl.contentsWithPubError[contentWithPubError] = '';
	}
	
	var serverUrlPubError = response.selectSingleNode("ActionResult/cdmfr-publication-failed-url")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (serverUrlPubError != '')
	{
		ribbonControl.contentsWithPubError[contentWithPubError] = serverUrlPubError;
	}
	
	var contentWithExportError = response.selectSingleNode("ActionResult/cdmfr-export-error")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (contentWithExportError != '')
	{
		ribbonControl.contentsWithExportError.push(contentWithExportError);
	}
	
	var invalidatedContents = response.selectSingleNode("ActionResult/invalidated-contents")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (invalidatedContents != '')
	{
		Ext.Msg.show({
			title: "<i18n:text i18n:key="WORKFLOW_ACTION_GLOBAL_VALIDATION"/>", // FIXME i18n
			msg: "<i18n:text i18n:key="WORKFLOW_ACTION_GLOBAL_VALIDATION_INVALIDATED_CONTENTS_1"/>" + invalidatedContents + "<i18n:text i18n:key="WORKFLOW_ACTION_GLOBAL_VALIDATION_INVALIDATED_CONTENTS_2"/>",
			buttons: Ext.Msg.OK,
			icon: Ext.Msg.WARNING
		});
	}
	
	ribbonControl.cumulate++;
	ribbonControl.cumulatedIds.push(args.content)
	
	if (ribbonControl.cumulate == args.max)
	{
		var msg = org.ametys.odf.program.Validate._getErrorMessage2(ribbonControl.contentsWithPubError, ribbonControl.contentsWithExportError);
		if (msg != '')
		{
			Ext.Msg.show({
				title: "<i18n:text i18n:key="WORKFLOW_ACTION_VALIDATION_PUBLICATION"/>", // FIXME i18n
				msg: msg,
				buttons: Ext.Msg.OK,
				icon: Ext.Msg.WARNING
			});
		}
		
		var nonoptimizedTargets = [];
		if (ribbonControl.cumulatedIds.length &gt; 0)
		{
			nonoptimizedTargets = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTargets("content", {'ids': ribbonControl.cumulatedIds});
		}
		
		var messages = [];
		messages.push(org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGED, null, nonoptimizedTargets));
		messages.push(org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage(org.ametys.ribbon.RibbonManager.EVENTTYPE_LOCKCHANGED, null, nonoptimizedTargets));
		org.ametys.messagebus.MessageBus.getInstance().fireMessages(messages);
		
		ribbonControl.cumulatedIds = []
		ribbonControl.contentsWithPubError = {};
		ribbonControl.contentsWithExportError = [];
		ribbonControl.cumulate = 0;
	}
}

