/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.widgets');

// Register widget
org.ametys.utils.Widgets.registerWidget ('string', 'grouped-enumeration', 'org.ametys.odf.widgets.GroupedEnumerationWidget');

org.ametys.odf.widgets.GroupedEnumerationWidget = function (config) 
{
	if (!config.width)
		config.width = 490; // default width
	
	config.valueField = 'value';
	config.displayField = 'displayText';
	config.mode = 'local';
	
	// The store
	config.store = new Ext.data.XmlStore({
	    url: getPluginDirectUrl('odf') + '/grouped-items/' + this._getLang() + '/' + config.enumerationName,
	    record: 'item',
	    fields: [
	        // set up the fields mapping into the xml doc
	        // The first needs mapping, the others are very basic
	        {name: 'value', mapping: 'id'},
	        {name: 'displayText', mapping: 'value', sortType: Utils.sortAsNonAccentedUCString},
	        {name: 'group', mapping: 'group', sortType: Utils.sortAsNonAccentedUCString}
	    ]
	});
	
	config.tpl = new Ext.XTemplate(
			'&lt;tpl for="."&gt;',
			'&lt;tpl if="this.group != values.group"&gt;',
			'&lt;tpl exec="this.group = values.group"&gt;&lt;/tpl&gt;',
			'&lt;h1&gt;{group}&lt;/h1&gt;',
			'&lt;/tpl&gt;',
			'&lt;tpl if="this.group != \'\'"&gt;',
            '&lt;div class="x-combo-list-item grouped-item"&gt;{displayText}&lt;/div&gt;',
            '&lt;/tpl&gt;',
            '&lt;tpl if="this.group == \'\'"&gt;',
            '&lt;div class="x-combo-list-item"&gt;{displayText}&lt;/div&gt;',
            '&lt;/tpl&gt;',
			'&lt;/tpl&gt;'
	 );
	
	org.ametys.odf.widgets.GroupedEnumerationWidget.superclass.constructor.call (this, config);
}

Ext.extend(org.ametys.odf.widgets.GroupedEnumerationWidget, org.ametys.form.ComboField, {
	forceSelection : true,
	triggerAction: 'all'
});

org.ametys.odf.widgets.GroupedEnumerationWidget.prototype.onRender = function(ct, position)
{
	org.ametys.odf.widgets.GroupedEnumerationWidget.superclass.onRender.call(this, ct, position);
	this.store.load ({'callback' : this._loadCb, 'scope': this})
}

org.ametys.odf.widgets.GroupedEnumerationWidget.prototype.setValue = function(value)
{
	if (Ext.isArray (value))
	{
		value = value[0];
	}
	
	org.ametys.odf.widgets.GroupedEnumerationWidget.superclass.setValue.call(this, value);
	this._value = value;
}

org.ametys.odf.widgets.GroupedEnumerationWidget.prototype._loadCb = function (records, opts, success)
{
	this.setValue(this._value);
}

org.ametys.odf.widgets.GroupedEnumerationWidget.prototype._getLang = function ()
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function (target) { return target.getType() == 'content'});
	
	return target != null ? target.getParameters().lang : 'fr';
}