/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.widgets');

// Register widget
org.ametys.utils.Widgets.registerEnumeratedWidget ('string', 'mention-enumeration', 'org.ametys.odf.widgets.MentionWidget');

org.ametys.odf.widgets.MentionWidget = function(config, enumeratedValues)
{
	config.listEmptyText = config.listEmptyText || "<i18n:text i18n:key='PLUGINS_ODF_WIDGET_MENTIONWIDGET_EMPTY_LIST'/>";
	
    org.ametys.odf.widgets.MentionWidget.superclass.constructor.call(this, config, enumeratedValues);
}; 

Ext.extend(org.ametys.odf.widgets.MentionWidget, org.ametys.widgets.SortEnumeratedStringWidget, {});

org.ametys.odf.widgets.MentionWidget.prototype.onRender = function (ct, position)
{
    org.ametys.odf.widgets.MentionWidget.superclass.onRender.call(this, ct, position);
    
    org.ametys.odf.widgets.DegreeWidget.registerListener(this);
}

org.ametys.odf.widgets.MentionWidget.prototype.onSelectDegree = function(degree)
{
    var params = {};
    params["degree"] = degree;
    
    var serverMessage = new org.ametys.servercomm.ServerMessage("odf", 
            'program/mentions.xml',
            params,
            org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,
            this._loadMentionCb,
            this, params, "xml");
    var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
    
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_WIDGET_MENTIONWIDGET_ERROR'/>", response, "org.ametys.odf.widgets.MentionWidget"))
    {
        return;
    }

    var items = response.selectNodes("items/item");
    var currentValue = this.getValue();
    
    var data = [];
    
    for (var i=0; i &lt; items.length; i++)
    {
        var code = items[i].selectSingleNode("id")[org.ametys.servercomm.ServerComm.xmlTextContent];
        var text = items[i].selectSingleNode("value")[org.ametys.servercomm.ServerComm.xmlTextContent];
        data.push([code, text]);
    }
    
    this.store.loadData(data, false);
    
    this.setValue(this.store.findExact("value", currentValue) != -1 ? currentValue : null);
}

org.ametys.odf.widgets.MentionWidget.prototype._loadMentionCb = function(response, params)
{
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='PLUGINS_ODF_WIDGET_MENTIONWIDGET_ERROR'/>", response, "org.ametys.odf.widgets.MentionWidget"))
    {
        return;
    }

    var items = response.selectNodes("items/item");
    var currentValue = this.getValue();
    
    var data = [];
    
    for (var i=0; i &lt; items.length; i++)
    {
        var code = items[i].selectSingleNode("id")[org.ametys.servercomm.ServerComm.xmlTextContent];
        var text = items[i].selectSingleNode("value")[org.ametys.servercomm.ServerComm.xmlTextContent];
        data.push([code, text]);
    }
    
    this.store.loadData(data, false);
    
    this.setValue(this.store.findExact("value", currentValue) != -1 ? currentValue : null);
}