/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.widgets');

// Register widget
org.ametys.utils.Widgets.registerWidget ('string', 'multiple-grouped-enumeration', 'org.ametys.odf.widgets.MultipleGroupedEnumerationWidget');

org.ametys.odf.widgets.MultipleGroupedEnumerationWidget = function (config) 
{
	if (!config.width)
		config.width = 490; // default width
	
	if (!config.height)
		config.height = 160; // default height
	
	
	config.valueField = 'value';
	config.displayField = 'displayText';
	// The store
	var proxy = new Ext.data.HttpProxy({
		url: getPluginDirectUrl('odf') + '/grouped-items/' + this._getLang() + '/' + config.enumerationName,
		method: 'post',
		timeout: 60000*10
	});
	
	config.store = new Ext.data.GroupingStore({
		proxy: proxy,
		enableGroup: true,
		groupField: 'group',
        reader: new Ext.data.XmlReader({
               record: 'item'
        }, 
        [ 
		  {name: 'value', mapping: 'id'},
	      {name: 'displayText', mapping: 'value', sortType: Utils.sortAsNonAccentedUCString},
	      {name: 'group', mapping: 'group', sortType: Utils.sortAsNonAccentedUCString}
		])
    });
	config.store.groupBy('group');
	
	org.ametys.odf.widgets.MultipleGroupedEnumerationWidget.superclass.constructor.call (this, config);
}

Ext.extend(org.ametys.odf.widgets.MultipleGroupedEnumerationWidget, org.ametys.form.MultiSelectField, {
	xtype: 'textfield',
	forceSelection : true,
	triggerAction: 'all'
});

org.ametys.odf.widgets.MultipleGroupedEnumerationWidget.prototype.onRender = function(ct, position)
{
	Ext.ux.form.MultiSelect.superclass.onRender.call(this, ct, position);
	
    var fs = this.fs = new Ext.form.FieldSet({
        renderTo: this.el,
        title: this.legend,
        height: this.height,
        width: this.width,
        style: "padding:0;",
        tbar: this.tbar
    });
    fs.body.addClass('ux-mselect');

    this.view = new Ext.grid.GridPanel({
        multiSelect: true,
        view: new Ext.grid.GroupingView({
	        // custom grouping text template to display the number of items per group
	        groupTextTpl: '{text}',
	        showGroupName: false
	    }),
	    height: this.height,
        store: this.store,
        columns: [ {header: "Group", width: this.width-20, sortable: true, dataIndex: 'group', hidden: true, hideable: false},
                   {header: 'Value', width: this.width-20, dataIndex: this.displayField }],
        hideHeaders: true
    });

    fs.add(this.view);

    this.view.on('click', this.onViewClick, this);
    this.view.on('beforeclick', this.onViewBeforeClick, this);
    this.view.on('dblclick', this.onViewDblClick, this);

    this.hiddenName = this.name || Ext.id();
    var hiddenTag = { tag: "input", type: "hidden", value: "", name: this.hiddenName };
    this.hiddenField = this.el.createChild(hiddenTag);
    this.hiddenField.dom.disabled = this.hiddenName != this.name;
    fs.doLayout();
    
    if (this.desc)
	{
		this.itemCt.child('div.x-form-element div.x-form-field').insertSibling({
			id: this.id + '-img',
			tag:'img',
			style: 'padding-left: 20px; padding-top : 6px; float: left;',
			src: getPluginResourcesUrl('core') + '/img/administrator/config/help.gif'}, 'after');
	
		var tooltip = new Ext.ToolTip({
	        target: this.id + '-img',
	        html: this.desc,
	        
	        dismissDelay: 0 // disable automatic hiding
	    });
	}
    
	this.store.load ({'callback' : this._loadCb, 'scope': this})
}

org.ametys.odf.widgets.MultipleGroupedEnumerationWidget.prototype.getValue = function (valueField)
{
    var returnArray = [];
    var records = this.view.getSelectionModel().getSelections();
    
    if (records.length == 0) {return '';}
    
    for (var i=0; i &lt; records.length; i++) 
    {
        returnArray.push(records[i].get((valueField != null) ? valueField : this.valueField));
    }
    return returnArray.join(this.delimiter);
},

org.ametys.odf.widgets.MultipleGroupedEnumerationWidget.prototype.setValue = function(values)
{
	this.view.getSelectionModel().clearSelections();
    this.hiddenField.dom.value = '';
	if (!values || (values == '')) { return; }
	
	if (!Ext.isArray (values))
	{
		values = values.split(',');
	}
	values = this._trim (values);
	
	var index;
    var selections = [];

    if (!Ext.isArray(values)) { values = values.split(this.delimiter); }
    for (var i=0; i &lt; values.length; i++) 
    {
        index = this.view.store.indexOf(this.view.store.query(this.valueField, new RegExp('^' + values[i] + '$', "i")).itemAt(0));
        selections.push(this.store.getAt(index));
    }
    
    this.view.getSelectionModel().selectRecords(selections);
    this.hiddenField.dom.value = this.getValue();
    this.validate();
    
	// store values
	this._values = values;
}

org.ametys.odf.widgets.MultipleGroupedEnumerationWidget.prototype._trim = function (values)
{
	var trimValues = []
	for (var i=0; i &lt; values.length; i++)
	{
		trimValues.push(values[i].trim ());
	}
	return trimValues;
}
org.ametys.odf.widgets.MultipleGroupedEnumerationWidget.prototype._loadCb = function (records, opts, success)
{
	this.setValue(this._values);
}

org.ametys.odf.widgets.MultipleGroupedEnumerationWidget.prototype._getLang = function ()
{
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function (target) { return target.getType() == 'content'});
	
	return target != null ? target.getParameters().lang : 'fr';
}