/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.widgets');

// Register widget
org.ametys.utils.Widgets.registerWidget ('string', 'orgunit', 'org.ametys.odf.widgets.OrgUnitWidget');

/**
 * @class This class provides a widget to select a OrgUnit
 * @extends Ext.form.TextField
 */
org.ametys.odf.widgets.OrgUnitWidget = function(config) 
{
	config.itemCls = "ametys-input";
	config.labelSeparator = '';
	
	// Override the hidden field
	config.hidden = false;
	
	if (!config.width)
		config.width = 490; // default width
	
	org.ametys.odf.widgets.OrgUnitWidget.superclass.constructor.call(this, config);
}; 

Ext.extend(org.ametys.odf.widgets.OrgUnitWidget, Ext.form.TextField, {
	/**
     * @cfg {String} buttonText The button text to display on the action button.
     * Note that if you supply a value for {@link #buttonCfg}, the buttonCfg.text
     * value will be used instead if available.
     */
	buttonText: "",
	/**
     * @cfg {Boolean} buttonOnly True to display the field as a button with no visible
     * text field (defaults to true).  If true, all inherited TextField members will still be available.
     */
	buttonOnly: false,
	/**
     * @cfg {Number} buttonOffset The number of pixels of space reserved between the button and the text field
     * (defaults to 3).  Note that this only applies if {@link #buttonOnly} = false.
     */
	buttonOffset: 5,
	/**
	 * @cfg {String} buttonIcon The button icon path for the action button.
	 */
	buttonIcon: getPluginResourcesUrl('odf') + '/img/widgets/orgunit_16.png',
	/**
	 * @cfg {Boolean} hidden True to hide the text field (defaults to true).
	 */
	hidden: true,
	/**
	 * @cfg {Boolean} multiple True to allow multi-selection and display checkboxes (defaults to false).
	 */
	multiple: false,
	// private
    readOnly: true
});

org.ametys.odf.widgets.OrgUnitWidget.prototype.getBtnConfig = function ()
{
	var btnCfg = Ext.applyIf(this.buttonCfg || {}, {
        text: this.buttonText, 
        icon: this.buttonIcon,
        disabled: this.disabled,
        handler: this.selectOrgUnit,
    	scope: this
    });
	
	return btnCfg;
}


org.ametys.odf.widgets.OrgUnitWidget.prototype.onRender = function(ct, position)
{
	org.ametys.odf.widgets.OrgUnitWidget.superclass.onRender.call(this, ct, position);
	
	this.wrap = this.el.wrap({cls:'x-form-field-wrap x-form-orgunit-wrap'});
	this.el.addClass('x-form-orgunit-text');
	
	this.displayField = new org.ametys.HtmlContainer ({
		id: this.id + '-display',
		html: '&lt;span class="empty"&gt;' + "<i18n:text i18n:key="PLUGINS_ODF_WIDGET_ORGUNITWIDGET_SELECT"/>" + '&lt;/span&gt;',
		cls: 'x-form-widget-display-field',
		hidden: false,
    	renderTo: this.wrap,
    	width: (this.width - 20)
    });
	
	// Button to delete the setted org units(s)
	this.deleteBtn = new Ext.Button ({
		tooltip: "<i18n:text i18n:key="PLUGINS_ODF_WIDGET_ORGUNITWIDGET_DELETE"/>",
		handler: this.deleteOrgUnit,
		scope: this,
		disabled: this.disabled,
		hidden: true,
		cls: 'x-form-orgunit-btn x-btn-icon',
		icon: getPluginResourcesUrl('odf') + '/img/widgets/delete_16.png',
		renderTo: this.wrap
	});
	
	var btnCfg = this.getBtnConfig();
    this.button = new Ext.Button(Ext.apply(btnCfg, {
        renderTo: this.wrap,
        widget: this,
        cls: 'x-form-orgunit-btn' + (btnCfg.iconCls ? ' x-btn-icon' : ''),
        handler: this.selectOrgUnit,
        tooltip: "<i18n:text i18n:key="PLUGINS_ODF_WIDGET_ORGUNITWIDGET_SELECT"/>"
    }));
    
    if (this.buttonOnly){
        this.el.hide();
        this.wrap.setWidth(this.button.getEl().getWidth());
    }
    
    if (this.desc)
	{
		this.itemCt.child('div.x-form-element div.x-form-field-wrap').insertSibling({
			id: this.id + '-img',
			tag:'img',
			style: 'padding-left: 20px; padding-top : 7px;',
			src: getPluginResourcesUrl('core') + '/img/administrator/config/help.gif'}, 'after');
	
		var tooltip = new Ext.ToolTip({
	        target: this.id + '-img',
	        html: this.desc
	    });
	}
    
    if (this.width != null &amp;&amp; this.width &gt; 0)
    {
    	this.setWidth(this.width);
    }
}

org.ametys.odf.widgets.OrgUnitWidget.prototype.markInvalid = function (msg)
{
	org.ametys.odf.widgets.OrgUnitWidget.superclass.markInvalid.call(this, msg);
	
	if(!this.rendered || this.preventMark){ // not rendered
        return;
    }
	
	this.wrap.addClass('x-widget-invalid');
	this.displayField.el.dom.qtip = msg;
	this.displayField.el.dom.qclass = 'x-form-invalid-tip'; 
}

org.ametys.odf.widgets.OrgUnitWidget.prototype.clearInvalid = function ()
{
	org.ametys.odf.widgets.OrgUnitWidget.superclass.clearInvalid.call(this);
	
	if(!this.rendered || this.preventMark){ // not rendered
        return;
    }
	
	this.wrap.removeClass('x-widget-invalid');
	this.displayField.el.dom.qtip = '';
}

/**
 * @private
 */
org.ametys.odf.widgets.OrgUnitWidget.prototype.selectOrgUnit = function ()
{
    org.ametys.odf.helper.ChooseOrgUnit (
			getPluginResourcesUrl('odf') + '/img/widgets/orgunit_16.png',
			"<i18n:text i18n:key="PLUGINS_ODF_WIDGET_ORGUNITWIDGET_SELECTTITLE"/>", 
			"<i18n:text i18n:key="PLUGINS_ODF_WIDGET_ORGUNITWIDGET_SELECTDESCRIPTION"/>",
			this._selectOrgUnitCb.createDelegate(this), this.multiple,
			this.getValue());
}

org.ametys.odf.widgets.OrgUnitWidget.prototype._selectOrgUnitCb = function (pages)
{
	if (pages != null &amp;&amp; pages.length &gt; 0)
	{
		var values = [];
		for (var i=0; i &lt; pages.length; i++)
		{
			values[i] = pages[i].id;
		}
		this.setValue (values);
	}
	else
	{
		this.setValue ('');
	}
}

org.ametys.odf.widgets.OrgUnitWidget.prototype.deleteOrgUnit = function ()
{
	this.setValue ('');
}



/**
 * Sets a data value into the field.
 * 
 * @param {String} id The uploaded file id
 * @param {String} fileName The uploaded file name
 * @param {Number} fileSize The uploaded file size in bytes.
 * @return {org.ametys.odf.widgets.OrgUnitWidget} this
 */
org.ametys.odf.widgets.OrgUnitWidget.prototype.setValue = function (values)
{
	// Update input field with the file id
	org.ametys.odf.widgets.OrgUnitWidget.superclass.setValue.call(this, values);
	
	if (this.rendered)
	{
		if ((Ext.isArray(values) &amp;&amp; values.length == 0) || (!Ext.isArray(values) &amp;&amp; values == ''))
		{
			var tooltip = Ext.getCmp(this.fieldName + '-tooltip');
			if (tooltip)
				tooltip.destroy();
			
			var text = '&lt;span class="empty"&gt;' + "<i18n:text i18n:key="PLUGINS_ODF_WIDGET_ORGUNITWIDGET_SELECT"/>" + '&lt;/span&gt;';
			text = org.ametys.utils.Utils.getTruncatedText (this.displayField.el, text, this.displayField.getWidth() != 0 ? this.displayField.getWidth() : this.displayField.width);
			this.displayField.el.update (text);
			
			this.deleteBtn.hide();
			this.button.show();
		}
		else
		{
			var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/orgunit', {'id': typeof(values) == 'string' ? values.split(",") : values}, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, this._updateDisplayField, this, [values]);
			org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
			
			if (this.multiple)
			{
				this.deleteBtn.hide();
				this.button.show();
			}
			else
			{
				this.deleteBtn.show();
				this.button.hide();
			}
		}
	}
	return this;
}

org.ametys.odf.widgets.OrgUnitWidget.prototype._updateDisplayField = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_WIDGET_ORGUNITWIDGET_ERROR"/>", response, "org.ametys.odf.widgets.OrgUnitWidget"))
	{
		return;
	}
	
	var displayValue = "";
	var orgunits = {};
	var nodes = response.selectNodes("orgunits/orgunit");
	
	for (var i=0; i &lt; nodes.length; i++)
	{
		var id = nodes[i].getAttribute('id');
		var title = nodes[i].getAttribute('title');
		
		if (i != 0)
		{
			displayValue += ", ";
		}
		displayValue += '&lt;a href="javascript:org.ametys.odf.widgets.OrgUnitWidget._openOrgUnit(\'' + id + '\');"&gt;' + title + '&lt;/a&gt;';
	
		orgunits[id] = {};
		orgunits[id]['title'] = title;
	}	
	displayValue = org.ametys.utils.Utils.getTruncatedText (this.displayField.el, displayValue, this.displayField.getWidth() != 0 ? this.displayField.getWidth() : this.displayField.width);
	this.displayField.el.update(displayValue);
	
	this._setTooltip (orgunits);
}

org.ametys.odf.widgets.OrgUnitWidget.prototype._setTooltip = function (orgunits)
{
	// Remove if exists
	var tooltip = Ext.getCmp(this.id + '-tooltip');
	if (tooltip)
		tooltip.destroy();
	
	var text = "&lt;div class='orgunit-tooltip'&gt;";
	
	for (var i in orgunits)
	{
		text += orgunits[i].title;
		text += "&lt;br/&gt;";
	}
	
	text += "&lt;/div&gt;";
	
	// Create tooltip
	new Ext.ToolTip({
		id: this.id + '-tooltip',
	    target: this.id + '-display',
	    html: text
	});
}

org.ametys.odf.widgets.OrgUnitWidget.prototype.setWidth = function (width)
{
	org.ametys.odf.widgets.OrgUnitWidget.superclass.setWidth.call(this, width);
	// width - btn width - padding left - padding right
	this.displayField.setWidth (width - 25 - 5 - 10);
	
	var text = this.displayField.el.dom.innerHTML;
	text = org.ametys.utils.Utils.getTruncatedText (this.displayField.el, text, width - 25 - 5 - 10);
	this.displayField.el.update (text);
	
}

org.ametys.odf.widgets.OrgUnitWidget._openOrgUnit = function (id)
{
	org.ametys.uitool.ToolsManager.getInstance().openTool ("uitool-content", {'id' : id});
}



