/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.widgets');

// Register widget
org.ametys.utils.Widgets.registerWidget ('string', 'odf-person', 'org.ametys.odf.widgets.PersonWidget');

/**
 * Creates a file widget field.
 * 
 * @class This class provides a widget to select a ODF person.&lt;br&gt;
 * @extends Ext.form.TextField
 * 
 */
org.ametys.odf.widgets.PersonWidget = function(config) 
{
	org.ametys.odf.widgets.PersonWidget.superclass.constructor.call(this, config);
}; 

Ext.extend(org.ametys.odf.widgets.PersonWidget, org.ametys.cms.widgets.UserSelectorWidget, {
});

org.ametys.odf.widgets.PersonWidget.prototype.setWidth = function (width)
{
	org.ametys.odf.widgets.PersonWidget.superclass.setWidth.call(this, width);
	// width - btn width - padding left - padding right
	this.displayField.setWidth (width - 25 - 5 - 10);
	
	var text = this.displayField.el.dom.innerHTML;
	text = org.ametys.utils.Utils.getTruncatedText (this.displayField.el, text, width - 25 - 5 - 10);
	this.displayField.el.update (text);
	
}

org.ametys.odf.widgets.PersonWidget.prototype.selectUsers = function ()
{
	org.ametys.odf.helper.SelectPersons (this._selectPersonsCb.createDelegate(this), null, this._users);
}
org.ametys.odf.widgets.PersonWidget.prototype._selectPersonsCb = function (persons)
{
	this._users = persons;
	
	if (persons.length == 0)
	{
		this.setUserValue ('', '');
		this.displayField.setValue ('');
		return;
	}
	
	var ids = '';
	var names = '';
	if (persons.length == 0)
	{
		// Nothing
	}
	else
	{
		var index=0;
		for (var i in persons)
		{
			if (index != 0)
			{
				ids += ',';
				names += ',';
			}
			ids += i;
			names += persons[i];
			index ++;
		}
	}
	
	this.setValue (ids, names);
}
org.ametys.odf.widgets.PersonWidget.prototype.selectUser = function ()
{
	org.ametys.odf.helper.SelectPerson (this._selectPersonCb.createDelegate(this));
}
org.ametys.odf.widgets.PersonWidget.prototype._selectPersonCb = function (persons)
{
	this._users = persons;
	
	if (persons.length == 0)
	{
		this.setValue ('', '');
		this.displayField.setValue ('');
		return;
	}
	
	var ids = '';
	var names = '';
	if (persons.length == 0)
	{
		// Nothing
	}
	else
	{
		var index=0;
		for (var i in persons)
		{
			if (index != 0)
			{
				ids += ',';
				names += ',';
			}
			ids += i;
			names += persons[i];
			index ++;
			
			if (!this.multiple)
				continue;
		}
	}
	
	this.setValue (ids, names);
}

/**
 * Sets a data value into the field.
 * 
 * @param {String} id The uploaded file id
 * @param {String} fileName The uploaded file name
 * @param {Number} fileSize The uploaded file size in bytes.
 * @return {org.ametys.odf.widgets.PersonWidget} this
 */
org.ametys.odf.widgets.PersonWidget.prototype.setValue = function (values)
{
	Ext.form.TextField.superclass.setValue.call(this, values);
	
	if (this.rendered)
	{
		if ((Ext.isArray(values) &amp;&amp; values.length == 0) || (!Ext.isArray(values) &amp;&amp; values == ''))
		{
			var tooltip = Ext.getCmp(this.fieldName + '-tooltip');
			if (tooltip)
				tooltip.destroy();
			
			var text = '&lt;span class="empty"&gt;' + "<i18n:text i18n:key="PLUGINS_ODF_WIDGET_PERSON_SELECT"/>" + '&lt;/span&gt;';
			text = org.ametys.utils.Utils.getTruncatedText (this.displayField.el, text, this.displayField.getWidth() != 0 ? this.displayField.getWidth() : this.displayField.width);
			this.displayField.el.update (text);
			if (!this.multiple)
			{
				this.deleteBtn.hide();
				this.button.show();
			}
		}
		else
		{
			var serverMessage = new org.ametys.servercomm.ServerMessage('odf', '/person', {'id': typeof(values) == 'string' ? values.split(",") : values}, org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, this._updateDisplayField, this, [values]);
			org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
			
			if (!this.multiple)
			{
				this.deleteBtn.show();
				this.button.hide();
			}
		}
	}
	return this;
}

org.ametys.odf.widgets.PersonWidget.prototype._updateDisplayField = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="PLUGINS_ODF_WIDGET_PERSON_ERROR"/>", response, "org.ametys.odf.widgets.PersonWidget"))
	{
		return;
	}
	
	var displayValue = "";
	this._users = {};
	var persons = {};
	var nodes = response.selectNodes("persons/person");
	
	for (var i=0; i &lt; nodes.length; i++)
	{
		var id = nodes[i].getAttribute('id');
		var firstname = nodes[i].getAttribute('firstname');
		var lastname = nodes[i].getAttribute('lastname');
		var personTitle = nodes[i].getAttribute('personTitle');
		
		var fullname = '';
		if (lastname != '' || firstname != '')
		{
			fullname += lastname + (firstname != '' ? " " + firstname : "");
		}
		else
		{
			fullname += personTitle;
		}
		
		if (i != 0)
		{
			displayValue += ", ";
		}
		displayValue += '&lt;a href="javascript:org.ametys.odf.widgets.PersonWidget._openPerson(\'' + id + '\');"&gt;' + fullname + '&lt;/a&gt;';
	
		persons[id] = {};
		persons[id]['fullname'] = fullname;
		
		this._users[id] = fullname;
	}	
	displayValue = org.ametys.utils.Utils.getTruncatedText (this.displayField.el, displayValue, this.displayField.getWidth() != 0 ? this.displayField.getWidth() : this.displayField.width);
	this.displayField.el.update(displayValue);
	
	this._setTooltip (persons);
}

org.ametys.odf.widgets.PersonWidget.prototype._setTooltip = function (persons)
{
	// Remove if exists
	var tooltip = Ext.getCmp(this.id + '-tooltip');
	if (tooltip)
		tooltip.destroy();
	
	var text = "&lt;div class='person-tooltip'&gt;";
	
	for (var i in persons)
	{
		text += persons[i].fullname;
		text += "&lt;br/&gt;";
	}
	
	text += "&lt;/div&gt;";
	
	// Create tooltip
	new Ext.ToolTip({
		id: this.id + '-tooltip',
	    target: this.id + '-display',
	    html: text
	});
}

org.ametys.odf.widgets.PersonWidget._openPerson = function (id)
{
	org.ametys.uitool.ToolsManager.getInstance().openTool ("uitool-content", {'id' : id});
}

