/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.odf.enumeration.OdfEnumerationConstant;
import org.ametys.odf.enumeration.OdfEnumerationHelper;
import org.ametys.odf.enumeration.OdfEnumerationI18nCache;
import org.ametys.runtime.config.Config;

/**
 * Helper component to be used from XSL stylesheets.
 */
public class OdfXSLTHelper implements Serviceable
{
    private static OdfEnumerationI18nCache _i18nCache;
    private static OdfEnumerationHelper _enumerationHelper;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        _i18nCache = (OdfEnumerationI18nCache) smanager.lookup(OdfEnumerationI18nCache.ROLE);
        _enumerationHelper = (OdfEnumerationHelper) smanager.lookup(OdfEnumerationHelper.ROLE);
    }
    
    /**
     * Get the label associated with the degree key
     * @param cdmValue The code of degree
     * @return The label of degree or code if not found
     */
    public static String degreeLabel (String cdmValue)
    {
        String code = _enumerationHelper.getItemCode (OdfEnumerationConstant.DEGREE, cdmValue);
        String label = _i18nCache.getTranslatedValue(OdfEnumerationConstant.DEGREE, Config.getInstance().getValueAsString("odf.programs.lang"), code);
        return label != null ? label : code;
    }
}
