/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf;

import org.ametys.odf.contenttype.ODFContentType;
import org.ametys.plugins.repository.query.expression.AndExpression;
import org.ametys.plugins.repository.query.expression.BooleanExpression;
import org.ametys.plugins.repository.query.expression.Expression;
import org.ametys.plugins.repository.query.expression.MetadataExpression;
import org.ametys.plugins.repository.query.expression.NotExpression;
import org.ametys.plugins.repository.query.expression.OrExpression;
import org.ametys.plugins.repository.query.expression.StringExpression;

/**
 * Constructs an {@link Expression} for synchronized fields
 *
 */
public class SynchronizeExpression extends OrExpression
{
    private Expression _expr;

    /**
     * Creates an {@link Expression} for a synchronized metadata
     * @param metadata the metadata
     * @param value the value to test
     */
    public SynchronizeExpression(String metadata, String value)
    {
        Expression exprSync = new AndExpression(new BooleanExpression(metadata + ODFContentType.SYNC_SUFFIX, true), new StringExpression(metadata + ODFContentType.REMOTE_SUFFIX, Operator.EQ, value));
        Expression exprNotSync = new AndExpression(new OrExpression(new NotExpression(new MetadataExpression(metadata + ODFContentType.SYNC_SUFFIX)), new BooleanExpression(metadata + ODFContentType.SYNC_SUFFIX, Operator.NE, true)), new StringExpression(metadata, Operator.EQ, value));
        _expr = new OrExpression(exprSync, exprNotSync);
    }
    
    @Override
    public String build()
    {
        return _expr.build();
    }
}
