/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.catalog.actions;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.odf.catalog.Catalog;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Action for renaming a catalog
 */
public class CatalogRenameAction extends ServiceableAction
{
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager sManager) throws ServiceException
    {
        super.service(sManager);
        _resolver = (AmetysObjectResolver) sManager.lookup(AmetysObjectResolver.ROLE);
    }

    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        @SuppressWarnings("unchecked")
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        Map<String, String> result = new HashMap<String, String>();
        
        String catalogTitle = (String) jsParameters.get("title");
        String id = (String) jsParameters.get("id");
        
        Catalog catalog = _resolver.resolveById(id);
        if (catalog != null)
        {
            catalog.getMetadataHolder().setMetadata(Catalog.TITLE, catalogTitle);
            catalog.saveChanges();
            
            result.put("id", catalog.getId());
            result.put("title", catalog.getTitle());
        }
        else
        {
            result.put("message", "not-found");
        }
        
        return result;
    }
}
