/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.catalog.generators;

import java.io.IOException;
import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.odf.catalog.Catalog;
import org.ametys.odf.catalog.CatalogsManager;
import org.ametys.odf.program.Program;
import org.ametys.plugins.repository.AmetysObjectIterable;

/**
 * SAX existing catalogs
 */
public class CatalogsGenerator extends ServiceableGenerator
{
    private CatalogsManager _catalogsManager;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _catalogsManager = (CatalogsManager) serviceManager.lookup(CatalogsManager.ROLE);
    }
    
    
    public void generate() throws IOException, SAXException, ProcessingException
    {
        contentHandler.startDocument();
        XMLUtils.startElement(contentHandler, "items");
        
        List<Catalog> catalogs = _catalogsManager.getCatalogs();
        
        for (Catalog catalog : catalogs)
        {
            AttributesImpl attrs = new AttributesImpl();
            attrs.addCDATAAttribute("id", catalog.getId());
            XMLUtils.startElement(contentHandler, "item", attrs);
            
            XMLUtils.createElement(contentHandler, "title", catalog.getTitle());
            XMLUtils.createElement(contentHandler, "code", catalog.getName());
            
            AmetysObjectIterable<Program> programs = _catalogsManager.getPrograms(catalog.getName());
            XMLUtils.createElement(contentHandler, "nbPrograms", String.valueOf(programs.getSize()));
            
            XMLUtils.endElement(contentHandler, "item");
        }
        
        XMLUtils.endElement(contentHandler, "items");
        contentHandler.endDocument();
    }

}
