/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.odf.cdmfr;

import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

import org.ametys.odf.enumeration.OdfEnumerationHelper;
import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.plugins.repository.AmetysObject;

/**
 * Object exportable in CDM-fr format.
 */
public interface CDMEntity extends CDMFRTagsConstants, AmetysObject
{
    /**
     * Returns the CDM id.
     * @return the CDM id.
     */
    public String getCDMId();
    
    /**
     * Export this entity in CDM-fr format.
     * @param contentHandler the target handler
     * @param provider the provider of ODF constants
     * @param rootOrgUnitId The id of root {@link OrgUnit}
     * @throws SAXException if an error occurs during export.
     */
    @Deprecated
    public void toCDM(ContentHandler contentHandler, OdfEnumerationHelper provider, String rootOrgUnitId) throws SAXException;
    
    /**
     * Returns the main language of this object.
     * @return the main language of this object.
     */
    public String getLanguage();
}
