/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.cdmfr;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.Response;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.xml.sax.SAXException;

import org.ametys.cms.repository.Content;
import org.ametys.odf.program.Program;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Generates CDM-fr for a {@link CDMEntity}.
 */
public class ExportToCDMfrGenerator extends ServiceableGenerator
{
    private AmetysObjectResolver _resolver;
    private ExportCDMfrManager _exportCMDfrManager;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _resolver = (AmetysObjectResolver) smanager.lookup(AmetysObjectResolver.ROLE);
        _exportCMDfrManager = (ExportCDMfrManager) smanager.lookup(ExportCDMfrManager.ROLE);
    }
    
    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        String programId = request.getParameter("id");
        
        Program program = _resolver.resolveById(programId);
        
        request.setAttribute(Content.class.getName(), program);
        
        Response response = ObjectModelHelper.getResponse(objectModel);
        String fileName = program.getCdmCode();
        response.setHeader("Content-Disposition", "attachment; filename=\"" + fileName + ".xml" + "\"");
        
        _exportCMDfrManager.generateCDM(contentHandler, program);
    }
}
