/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.contenttype;

import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.lucene.document.Field.Index;
import org.apache.lucene.document.Field.Store;

import org.ametys.cms.FilterNameHelper;
import org.ametys.cms.contenttype.DefaultContentIndexer;
import org.ametys.cms.repository.Content;
import org.ametys.odf.program.Program;
import org.ametys.odf.program.SubProgram;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.AmetysObjectIterable;

/**
 * ODF content specific indexer.
 */
public class ODFContentIndexer extends DefaultContentIndexer
{
    
    /** The avalon role. */
    @SuppressWarnings("hiding")
    public static final String ROLE = ODFContentIndexer.class.getName();
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _metadataIndexer = (ODFMetadataIndexer) manager.lookup(ODFMetadataIndexer.ROLE);
    }
    
    
    @Override
    public void indexContent(Content content, Document document, Map<String, Object> parameters) throws Exception
    {
        super.indexContent(content, document, parameters);
        
        if (content instanceof Program)
        {
            AmetysObjectIterable<AmetysObject> children = ((Program) content).getChildren();
            for (AmetysObject child : children)
            {
                if (child instanceof SubProgram)
                {
                    String path = FilterNameHelper.filterName(((Content) child).getTitle()) + "-" + child.getName();
                    document.add(new Field("subprograms", path + ";" + ((Content) child).getTitle(), Store.YES, Index.NOT_ANALYZED));
                }
            }
        }
    }
}
