/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.course;

import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.apache.commons.lang.StringUtils;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

import org.ametys.odf.cdmfr.CDMFRTagsConstants;

/**
 * LOM Sheet object
 */
public class LOMSheet
{
    private String _url;
    private String _label;
    
    /**
     * Constructor
     * @param url URL of the LOM sheet
     * @param label Label of the LOM sheet
     */
    public LOMSheet(String url, String label)
    {
        _url = url;
        _label = label;
    }

    /**
     * Getter for the URL
     * @return the URL
     */
    public String getUrl()
    {
        return _url;
    }

    /**
     * Setter for the URL
     * @param url the URL
     */
    public void setUrl(String url)
    {
        _url = url == null ? "" : url;
    }

    /**
     * Getter for the label
     * @return the label
     */
    public String getLabel()
    {
        return _label;
    }

    /**
     * Setter for the label
     * @param label the label
     */
    public void setLabel(String label)
    {
        _label = label == null ? "" : label;
    }
    
    /**
     * Transform the LOM sheet to CDM
     * @param contentHandler
     * @throws SAXException
     */
    public void toCDM(ContentHandler contentHandler) throws SAXException
    {
        AttributesImpl attrs = new AttributesImpl();
        attrs.addCDATAAttribute(CDMFRTagsConstants.ATTRIBUTE_ROLE, "learningObjectMetadata");
        XMLUtils.startElement(contentHandler, CDMFRTagsConstants.TAG_WEB_LINK, attrs);
        if (StringUtils.isNotEmpty(_url))
        {
            XMLUtils.createElement(contentHandler, CDMFRTagsConstants.TAG_HREF, _url);
        }
        if (StringUtils.isNotEmpty(_label))
        {
            XMLUtils.createElement(contentHandler, CDMFRTagsConstants.TAG_LINK_NAME, _label);
        }
        XMLUtils.endElement(contentHandler, CDMFRTagsConstants.TAG_WEB_LINK);
    }
    
    @Override
    public boolean equals(Object obj)
    {
        if (obj == null)
        {
            return false;
        }
        
        if (!(obj instanceof LOMSheet))
        {
            return false;
        }
        
        LOMSheet lomSheet = (LOMSheet) obj;
        if (!StringUtils.equals(this.getUrl(), lomSheet.getUrl()) || !StringUtils.equals(this.getLabel(), lomSheet.getLabel()))
        {
            return false;
        }
        
        return true;
    }
    
    @Override
    public int hashCode()
    {
        return super.hashCode();
    }
}
