/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.course.actions;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.observation.AbstractNotifierAction;
import org.ametys.cms.observation.Event;
import org.ametys.cms.observation.ObservationConstants;
import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.WorkflowAwareContent;
import org.ametys.cms.workflow.AbstractContentWorkflowComponent;
import org.ametys.odf.course.Course;
import org.ametys.odf.program.Program;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.version.VersionableAmetysObject;
import org.ametys.plugins.workflow.Workflow;

import com.opensymphony.workflow.WorkflowException;
import com.opensymphony.workflow.spi.Step;

/**
 * Abstract action on ODF content
 */
public abstract class AbstractOdfAction extends AbstractNotifierAction
{
    /** Workflow instance. */
    protected Workflow _workflow;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _workflow = (Workflow) smanager.lookup(Workflow.ROLE);
    }
    
    /**
     * Get the first parent of type Program or Course
     * @param ao the child content
     * @return the first parent of type Program or Course
     */
    protected Content getParentProgramOrCourse (AmetysObject ao)
    {
        AmetysObject parent = ao;
        
        // Back up to first parent of type Program or Course
        while (!(parent instanceof Course) && !(parent instanceof Program))
        {
            parent = parent.getParent();
        }
        
        // Parent is necessarily a Course or a Program
        return (Content) parent;
    }
    
    /**
     * Back up to first parent of type Course or Program and apply changes
     * @param ao the direct parent of the deleted element
     * @throws WorkflowException 
     */
    protected void applyChangesToParent(AmetysObject ao) throws WorkflowException
    {
        // Back up to first parent of type Program or Course
        WorkflowAwareContent parent = (WorkflowAwareContent) getParentProgramOrCourse (ao);
        
        // Save changes
        parent.saveChanges();
        if (parent instanceof VersionableAmetysObject)
        {
            // Create new version
            ((VersionableAmetysObject) parent).checkpoint();
        }
        
        // Notify listeners
        _observationManager.notify(new Event(_getCurrentUser(), ObservationConstants.CONTENT_MODIFIED, parent));
       
        // Do workflow action
        Map<String, Object> inputs = new HashMap<String, Object>();
        inputs.put(AbstractContentWorkflowComponent.RESULT_MAP_KEY, new HashMap<String, Object>());
        inputs.put(AbstractContentWorkflowComponent.CONTENT_KEY, parent);
        _workflow.doAction(parent.getWorkflowId(), 22, inputs);
        
        Step currentStep = (Step) _workflow.getCurrentSteps(parent.getWorkflowId()).iterator().next();
        parent.setCurrentStepId(currentStep.getStepId());
        parent.saveChanges();
    }
}
