/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.course.actions;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.odf.course.Course;
import org.ametys.odf.courselist.CourseList;

/**
 * Insert {@link Course}s into an {@link CourseList}
 */
public class AddCoursesToListAction extends AbstractOdfAction
{
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        Map<String, String> result = new HashMap<String, String>();

        String id = (String) jsParameters.get("id");
        List<String> courseIds = (List<String>) jsParameters.get("courseIds");

        assert id != null;
        
        CourseList list = _resolver.resolveById(id);

        for (String courseId : courseIds)
        {
            if (!list.hasCourse(courseId))
            {
                list.addCourse(courseId);
                list.setMaxNumberOfCourses(list.getMaxNumberOfCourses() + 1);
            }
        }
        
        list.saveChanges();
        applyChangesToParent(list.getParent());

        return result;
    }
}
