/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.course.actions;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.odf.course.Course;
import org.ametys.odf.courselist.CourseList;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Moves a {@link Course} in the tree
 */
public class MoveCourseAction extends ServiceableAction
{
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager sManager) throws ServiceException
    {
        super.service(sManager);
        _resolver = (AmetysObjectResolver) sManager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        Map<String, String> result = new HashMap<String, String>();

        String id = request.getParameter("id");
        String oldParent = request.getParameter("oldParent");
        String newParent = request.getParameter("newParent");
        
        assert id != null;

        Course course = _resolver.resolveById(id);
        CourseList oldParentCL = _resolver.resolveById(oldParent);
        CourseList newParentCL = _resolver.resolveById(newParent);
        
        oldParentCL.removeCourse(course.getId());
        oldParentCL.setMaxNumberOfCourses(oldParentCL.getMaxNumberOfCourses() - 1);
        oldParentCL.saveChanges();
        
        newParentCL.addCourse(course.getId());
        newParentCL.setMaxNumberOfCourses(oldParentCL.getMaxNumberOfCourses() + 1);
        newParentCL.saveChanges();
        
        return result;
    }
}
