/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.course.generators;

import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.generation.Generator;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.apache.commons.lang.StringUtils;
import org.xml.sax.SAXException;

import org.ametys.cms.repository.Content;
import org.ametys.odf.course.Course;
import org.ametys.odf.courselist.CourseList;
import org.ametys.odf.program.Program;
import org.ametys.odf.program.generators.ProgramContentGenerator;
import org.ametys.odf.translation.TranslationHelper;
import org.ametys.plugins.repository.AmetysObjectIterable;
import org.ametys.runtime.config.Config;

/**
 * {@link Generator} for rendering raw content data for a {@link Course}.
 */
public class CourseContentGenerator extends ProgramContentGenerator
{
    @Override
    protected void _saxOtherData(Content content) throws SAXException, ProcessingException
    {
        super._saxOtherData(content);
        
        boolean isEditionMetadataSet = parameters.getParameterAsBoolean("isEditionMetadataSet", false);
        if (!isEditionMetadataSet)
        {
            if (content instanceof Course)
            {
                Course course = (Course) content;
                // Sax all the string metadatas of widget "odf-person".
                Set<String> personMetas = _getPersonMetadatas(content);
                for (String personMeta : personMetas)
                {
                    String[] personMetaIds = course.getStringArray(personMeta);
                    for (String personId : personMetaIds)
                    {
                        if (StringUtils.isNotEmpty(personId))
                        {
                            saxPersonContent(personMeta, personId);
                        }
                    }
                }
                
                List<String> orgUnits = course.getOrgUnits();
                saxOrgUnits(orgUnits);
                
                AmetysObjectIterable<CourseList> courseLists = course.getCourseLists();
                for (CourseList courseList : courseLists)
                {
                    saxCourseList (courseList, course.getContextPath());
                }
                
            }
        }
        
        Request request = ObjectModelHelper.getRequest(objectModel);
        request.setAttribute(Content.class.getName(), content);
        
        // Programs referenced
        Boolean showReferences = Config.getInstance().getValueAsBoolean("odf.course.showReferences");
        if (showReferences && content instanceof Course)
        {
            List<Program> referencingPrograms = ((Course) content).getReferencingPrograms();
            // Transform to set to avoid remove double
            Set<Program> distinctRefPrograms = new HashSet<Program>(referencingPrograms);
            
            for (Program program : distinctRefPrograms)
            {
                AttributesImpl attrs = new AttributesImpl();
                attrs.addCDATAAttribute("id", program.getId());
                XMLUtils.createElement(contentHandler, "refProgram", attrs, program.getTitle());
            }
        }
        
        // Sax existing translations
        Map<String, String> translations = TranslationHelper.getTranslations(content);
        if (!translations.isEmpty())
        {
            saxTranslations(translations);
        }
    }
}
