/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.courselist.actions;

import java.util.HashMap;
import java.util.Map;

import javax.jcr.Node;
import javax.jcr.RepositoryException;
import javax.jcr.lock.Lock;
import javax.jcr.lock.LockManager;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.odf.SynchronizableContent;
import org.ametys.odf.course.actions.AbstractDeleteOdfAction;
import org.ametys.odf.courselist.CourseList;
import org.ametys.plugins.repository.RepositoryConstants;
import org.ametys.plugins.repository.lock.LockHelper;

/**
 * Delete a {@link CourseList}
 */
public class DeleteCourseListAction extends AbstractDeleteOdfAction
{
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);

        String id = request.getParameter("id");
        CourseList list = _resolver.resolveById(id);

        SynchronizableContent parent = (SynchronizableContent) list.getParent();
        
        if (parent.isLocked() && !LockHelper.isLockOwner(parent, _getCurrentUser()))
        {
            Map<String, String> result = new HashMap<String, String>();
            result.put("message", "locked");
            return result;
        }
        
        _checkLock (parent.getNode());
        list.remove();
        
        // Apply changes to parent
        applyChangesToParent(parent);
        
        return EMPTY_MAP;
    }
    
    private void _checkLock(Node node) throws RepositoryException
    {
        if (node.isLocked())
        {
            LockManager lockManager = node.getSession().getWorkspace().getLockManager();
            
            Lock lock = lockManager.getLock(node.getPath());
            Node lockHolder = lock.getNode();
            
            lockManager.addLockToken(lockHolder.getProperty(RepositoryConstants.METADATA_LOCKTOKEN).getString());
        }
    }
}
