/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.courselist.generators;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.odf.SynchronizableContent;
import org.ametys.odf.courselist.CourseList;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * SAX events for a {@link CourseList}
 */
public class CourseListGenerator extends ServiceableGenerator
{
    private AmetysObjectResolver _resolver;

    @Override
    public void service(ServiceManager sManager) throws ServiceException
    {
        super.service(sManager);
        _resolver = (AmetysObjectResolver) sManager.lookup(AmetysObjectResolver.ROLE);
    }

    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        String id = request.getParameter("id");

        CourseList list = _resolver.resolveById(id);
        
        contentHandler.startDocument();
        
        XMLUtils.startElement(contentHandler, "course-list");
        
        XMLUtils.createElement(contentHandler, "title", list.getMetadataHolder().getString(CourseList.COURSE_LIST_TITLE, ""));
        XMLUtils.createElement(contentHandler, "title_remote", list.getMetadataHolder().getString(CourseList.COURSE_LIST_TITLE + SynchronizableContent.REMOTE_SUFFIX, ""));
        XMLUtils.createElement(contentHandler, "title_sync", String.valueOf(list.getMetadataHolder().getBoolean(CourseList.COURSE_LIST_TITLE + SynchronizableContent.SYNC_SUFFIX, false)));
        
        XMLUtils.createElement(contentHandler, "type", list.getMetadataHolder().getString(CourseList.CHOICE_TYPE, ""));
        XMLUtils.createElement(contentHandler, "type_remote", list.getMetadataHolder().getString(CourseList.CHOICE_TYPE + SynchronizableContent.REMOTE_SUFFIX, ""));
        XMLUtils.createElement(contentHandler, "type_sync", String.valueOf(list.getMetadataHolder().getBoolean(CourseList.CHOICE_TYPE + SynchronizableContent.SYNC_SUFFIX, false)));
        
        XMLUtils.createElement(contentHandler, "ects", list.getMetadataHolder().getString(CourseList.ECTS, ""));
        XMLUtils.createElement(contentHandler, "ects_remote", list.getMetadataHolder().getString(CourseList.ECTS + SynchronizableContent.REMOTE_SUFFIX, ""));
        XMLUtils.createElement(contentHandler, "ects_sync", String.valueOf(list.getMetadataHolder().getBoolean(CourseList.ECTS + SynchronizableContent.SYNC_SUFFIX, false)));
        
        XMLUtils.createElement(contentHandler, "nb-choices", list.getMetadataHolder().getString(CourseList.MIN_COURSES, ""));
        XMLUtils.createElement(contentHandler, "nb-choices_remote", list.getMetadataHolder().getString(CourseList.MIN_COURSES + SynchronizableContent.REMOTE_SUFFIX, ""));
        XMLUtils.createElement(contentHandler, "nb-choices_sync", String.valueOf(list.getMetadataHolder().getBoolean(CourseList.MIN_COURSES + SynchronizableContent.SYNC_SUFFIX, false)));
            
        XMLUtils.createElement(contentHandler, "available-choices", list.getMetadataHolder().getString(CourseList.MAX_COURSES, ""));
        XMLUtils.createElement(contentHandler, "available-choices_remote", list.getMetadataHolder().getString(CourseList.MAX_COURSES + SynchronizableContent.REMOTE_SUFFIX, ""));
        XMLUtils.createElement(contentHandler, "available-choices_sync", String.valueOf(list.getMetadataHolder().getBoolean(CourseList.MAX_COURSES + SynchronizableContent.SYNC_SUFFIX, false)));
        
        XMLUtils.endElement(contentHandler, "course-list");
        contentHandler.endDocument();
    }

}
