/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import java.util.Map;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.runtime.util.I18nizableText;
import org.ametys.runtime.util.parameter.Enumerator;

/**
 * Abstract {@link Enumerator} for ODF enumeration
 */
public abstract class AbstractODFEnumerator implements Enumerator, Serviceable, Configurable
{
    /** Enumeration helper */
    protected OdfEnumerationHelper _enumerationHelper;
    
    /** All option : 'disabled' to disable the 'all' option, 
     * 'blank' to use a blank value for 'all' option,
     * or 'concat' to concat all content types' ids for 'all' option
     **/
    protected String _allOption;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _enumerationHelper = (OdfEnumerationHelper) manager.lookup(OdfEnumerationHelper.ROLE);
    }
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        Configuration allOptConf = configuration.getChild("all-option", false);
        if (allOptConf == null)
        {
            allOptConf = configuration.getChild("enumeration").getChild("custom-enumerator").getChild("all-option", false);
        }
        _allOption = allOptConf != null ? allOptConf.getValue("blank") : "";
    }
    
    @Override
    public Map<Object, I18nizableText> getEntries() throws Exception
    {
        Map<Object, I18nizableText> entries;
        if (useSubitems())
        {
            entries = _enumerationHelper.getSubitemsLabel(getEnumerationName());
        }
        else
        {
            entries = _enumerationHelper.getItemsLabel(getEnumerationName());
        }
        
        // All all
        if (_allOption.equals("blank"))
        {
            entries.put("", new I18nizableText("plugin.cms", "WIDGET_COMBOBOX_ALL_OPTIONS"));
        }
        
        return entries;
        
    }

    @Override
    public I18nizableText getEntry(String value) throws Exception
    {
        return _enumerationHelper.getItemLabel(getEnumerationName(), value);
    }
    
    /**
     * Returns the enumeration name
     * @return the enumeration name
     */
    protected abstract String getEnumerationName ();
    
    /**
     * Returns the enumeration name
     * @return the enumeration name
     */
    protected boolean useSubitems()
    {
        return false;
    }
    
}
