/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.contenttype.ContentType;
import org.ametys.cms.contenttype.ContentTypeExtensionPoint;
import org.ametys.cms.contenttype.MetadataDefinition;
import org.ametys.odf.contenttype.ODFContentType;
import org.ametys.runtime.util.I18nizableText;
import org.ametys.runtime.util.parameter.Enumerator;

/**
 * Lists the enumerated metadatas on the program content type.
 */
public class EnumeratedMetadataEnumerator extends AbstractLogEnabled implements Enumerator, Serviceable
{
    
    /** The content type extension point. */
    protected ContentTypeExtensionPoint _cTypeEP;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        _cTypeEP = (ContentTypeExtensionPoint) serviceManager.lookup(ContentTypeExtensionPoint.ROLE);
    }
    
    @Override
    public Map<Object, I18nizableText> getEntries() throws Exception
    {
        ContentType programCType = _cTypeEP.getExtension("org.ametys.plugins.odf.Content.program");
        
        Map<Object, I18nizableText> entries = new LinkedHashMap<Object, I18nizableText>();
        
        if (programCType instanceof ODFContentType)
        {
            Map<String, MetadataDefinition> enumeratedMetadatas = ((ODFContentType) programCType).getEnumeratedMetadatas();
            
            for (String path : enumeratedMetadatas.keySet())
            {
                MetadataDefinition metadataDefinition = enumeratedMetadatas.get(path);
                
                entries.put(path, metadataDefinition.getLabel());
            }
        }
        
        return entries;
    }
    
    @Override
    public I18nizableText getEntry(String value) throws Exception
    {
        return getEntries().get(value);
    }
    
}
