/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.commons.lang.StringUtils;
import org.xml.sax.SAXException;

import org.ametys.cms.contenttype.ContentType;
import org.ametys.cms.contenttype.ContentTypeExtensionPoint;
import org.ametys.cms.contenttype.MetadataDefinition;

/**
 * Generate the values of an enumerated metadata of the program content type.
 */
public class EnumeratedMetadataValuesGenerator extends ServiceableGenerator
{
    /** The content type extension point. */
    protected ContentTypeExtensionPoint _cTypeEP;
    /** The ODf enumeration helper */
    protected OdfEnumerationHelper _odfEnumHelper;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _cTypeEP = (ContentTypeExtensionPoint) serviceManager.lookup(ContentTypeExtensionPoint.ROLE);
        _odfEnumHelper = (OdfEnumerationHelper) serviceManager.lookup(OdfEnumerationHelper.ROLE);
    }
    
    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        ContentType programCType = _cTypeEP.getExtension("org.ametys.plugins.odf.Content.program");
        
        String metadataPath = parameters.getParameter("metadataPath", "");
        
        MetadataDefinition metaDef = _getMetadataDefinition(programCType, metadataPath);
        
        contentHandler.startDocument();
        
        try
        {
            _odfEnumHelper.saxEnumeration(contentHandler, metaDef);
        }
        catch (Exception e)
        {
            throw new ProcessingException("Error retrieving the values of metadata '" + metadataPath + "'", e);
        }
        
        contentHandler.endDocument();
    }
    
    /**
     * Get a metadata definition from its path.
     * @param contentType the content type.
     * @param metadataPath the metadata path.
     * @return the metadata definition or null if not found.
     */
    protected MetadataDefinition _getMetadataDefinition(ContentType contentType, String metadataPath)
    {
        String[] pathSegments = StringUtils.split(metadataPath, '/');
        
        if (pathSegments.length == 0)
        {
            return null;
        }
        
        MetadataDefinition metadataDef = contentType.getMetadataDefinition(pathSegments[0]);

        for (int i = 1;  i < pathSegments.length && metadataDef != null; i++)
        {
            metadataDef = metadataDef.getMetadataDefinition(pathSegments[i]);
        }

        return metadataDef;
    }
    
}
