/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.runtime.util.I18nizableText;
import org.ametys.runtime.util.parameter.Enumerator;

/**
 * {@link Enumerator} for the ODF "mention" enumeration
 * 
 */
public class MentionsEnumerator implements Enumerator, Serviceable
{
    private OdfEnumerationHelper _enumerationHelper;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _enumerationHelper = (OdfEnumerationHelper) manager.lookup(OdfEnumerationHelper.ROLE);
    }

    public I18nizableText getEntry(String value) throws Exception
    {
        I18nizableText label = _enumerationHelper.getItemLabel(OdfEnumerationConstant.MENTION_LICENCE, value);
        if (label != null)
        {
            return label;
        }
        
        label = _enumerationHelper.getItemLabel(OdfEnumerationConstant.MENTION_LICENCEPRO, value);
        
        if (label != null)
        {
            return label;
        }
        
        label = _enumerationHelper.getItemLabel(OdfEnumerationConstant.MENTION_MASTER, value);
        if (label != null)
        {
            return label;
        }
        
        return null;
    }

    @Override
    public Map<Object, I18nizableText> getEntries() throws Exception
    {
        // Empty collection
        return new HashMap<Object, I18nizableText>();
    }

}
