/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.odf.enumeration.OdfEnumerationConstant;
import org.ametys.odf.enumeration.OdfEnumerationGenerator;
import org.ametys.runtime.config.Config;

/**
 * Generate the list of mentions, according to a parameter "degree"
 */
public class MentionsGenerator extends OdfEnumerationGenerator
{
    @Override
    public void generate() throws SAXException
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        String degree = request.getParameter("degree");
        
        contentHandler.startDocument();
        XMLUtils.startElement(contentHandler, "items");

        if (degree != null)
        {
            if (degree.equals(Config.getInstance().getValueAsString("odf.programs.degree.license")))
            {
                _saxItems(_enumerationHelper.getItems(OdfEnumerationConstant.MENTION_LICENCE), 0);
            }
            else if (degree.equals(Config.getInstance().getValueAsString("odf.programs.degree.licensepro")))
            {
                _saxItems(_enumerationHelper.getItems(OdfEnumerationConstant.MENTION_LICENCEPRO), 0);
            }
            else if (degree.equals(Config.getInstance().getValueAsString("odf.programs.degree.master")))
            {
                _saxItems(_enumerationHelper.getItems(OdfEnumerationConstant.MENTION_MASTER), 0);
            }
        }

        XMLUtils.endElement(contentHandler, "items");
        contentHandler.endDocument();
    }
}
