/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.runtime.util.I18nizableText;

/**
 * SAX all items of a constant.
 */
public class OdfEnumerationGenerator extends ServiceableGenerator
{
    /** The enumeration helper for ODF */
    protected OdfEnumerationHelper _enumerationHelper;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _enumerationHelper = (OdfEnumerationHelper) smanager.lookup(OdfEnumerationHelper.ROLE);
    }

    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        String enumerationName = parameters.getParameter("enumeration-name", "");
        int depth = parameters.getParameterAsInteger("depth", 0);
        
        contentHandler.startDocument();
        
        AttributesImpl attr = new AttributesImpl();
        attr.addCDATAAttribute("id", enumerationName);
        XMLUtils.startElement(contentHandler, "items", attr);
        
        Map<String, OdfEnumerationItem> items = _enumerationHelper.getItems(enumerationName.toUpperCase());
        _saxItems(items, depth);
        
        XMLUtils.endElement(contentHandler, "items");
        contentHandler.endDocument();
    }
    
    /**
     * SAX items
     * @param items the items
     * @param depth the depth
     * @throws SAXException
     */
    protected void _saxItems (Map<String, OdfEnumerationItem> items, int depth) throws SAXException
    {
        for (String code : items.keySet())
        {
            OdfEnumerationItem item = items.get(code);
            
            XMLUtils.startElement(contentHandler, "item");
            
            XMLUtils.createElement(contentHandler, "id", item.getCode());
            I18nizableText label = items.get(code).getLabel();
            label.toSAX(contentHandler, "value");
            
            if (depth > 0)
            {
                // Sub-items
                _saxSubItems (item);
            }
            
            XMLUtils.endElement(contentHandler, "item");
        }
    }
    
    private void _saxSubItems (OdfEnumerationItem item) throws SAXException
    {
        Map<String, OdfEnumerationItem> subitems = item.getChildren();
        
        for (String sCode : subitems.keySet())
        {
            OdfEnumerationItem sItem = subitems.get(sCode);
            
            XMLUtils.startElement(contentHandler, "subitem");
            
            XMLUtils.createElement(contentHandler, "id", sItem.getCode());
            I18nizableText label = subitems.get(sCode).getLabel();
            label.toSAX(contentHandler, "value");
            XMLUtils.endElement(contentHandler, "subitem");
        }
    }

}
