/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import java.util.LinkedHashMap;
import java.util.Map;

import org.ametys.runtime.util.I18nizableText;

/**
 * Class representing an item of a ODF enumeration
 */
public class OdfEnumerationItem
{
    /** The constant item code. */
    protected String _code;
    
    /** The constant item label. */
    protected I18nizableText _label;
    
    /** The CDM value. */
    protected String _cdmValue;
    
    /** The constant item children. */
    protected Map<String, OdfEnumerationItem> _children;
    
    /**
     * Build a constant item.
     * @param code
     * @param label
     * @param cdmValue
     */
    public OdfEnumerationItem(String code, I18nizableText label, String cdmValue)
    {
        this(code, label, cdmValue, new LinkedHashMap<String, OdfEnumerationItem>());
    }
    
    /**
     * Build a constant item.
     * @param code
     * @param label
     * @param cdmValue
     * @param children
     */
    public OdfEnumerationItem(String code, I18nizableText label, String cdmValue, Map<String, OdfEnumerationItem> children)
    {
        this._code = code;
        this._label = label;
        this._cdmValue = cdmValue;
        this._children = children;
    }

    /**
     * Get the code.
     * @return the code
     */
    public String getCode()
    {
        return _code;
    }

    /**
     * Set the code.
     * @param code the code to set
     */
    public void setCode(String code)
    {
        this._code = code;
    }

    /**
     * Get the label.
     * @return the label
     */
    public I18nizableText getLabel()
    {
        return _label;
    }

    /**
     * Set the label.
     * @param label the label to set
     */
    public void setLabel(I18nizableText label)
    {
        this._label = label;
    }

    /**
     * Get the CDM value.
     * @return the CDM value
     */
    public String getCDMValue()
    {
        return _cdmValue;
    }

    /**
     * Set the CDM value.
     * @param cdmValue value the CDM value to set
     */
    public void setCDMValue(String cdmValue)
    {
        this._cdmValue = cdmValue;
    }
    
    /**
     * Get the children.
     * @return the children
     */
    public Map<String, OdfEnumerationItem> getChildren()
    {
        return _children;
    }

    /**
     * Set the children.
     * @param children the children to set
     */
    public void setChildren(Map<String, OdfEnumerationItem> children)
    {
        this._children = children;
    }
    
}
