/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.enumeration;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.runtime.util.parameter.Enumerator;

/**
 * {@link Enumerator} for a ODF enumeration.
 * The classes {@link DomainsEnumerator}, {@link CodeErasmusEnumerator}, {@link LevelsEnumerator}, etc, .. should be replaced by this class.
 */
public class StaticODFEnumerator extends AbstractODFEnumerator
{
    private String _enumerationName;
    
    private boolean _useSubitems;
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        super.configure(configuration);
        
        Configuration constantConf = configuration.getChild("constant", false);
        if (constantConf == null)
        {
            constantConf = configuration.getChild("enumeration").getChild("custom-enumerator").getChild("constant", false);
        }
        
        if (constantConf == null)
        {
            throw new ConfigurationException("Missing 'constant' configuration for static ODF enumerator");
        }
        
        _enumerationName = constantConf.getValue();
        
        _useSubitems = configuration.getChild("enumeration").getChild("custom-enumerator").getChild("use-subitems").getValueAsBoolean(false);
    }
    
    @Override
    protected String getEnumerationName()
    {
        return _enumerationName;
    }
    
    @Override
    protected boolean useSubitems()
    {
        return _useSubitems;
    }
}
