/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.export.pdf;

import java.util.Collections;
import java.util.Map;
import java.util.Timer;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.logger.Logger;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.lang.StringUtils;

import org.ametys.runtime.config.Config;
import org.ametys.runtime.user.CurrentUserProvider;
import org.ametys.runtime.user.User;
import org.ametys.runtime.user.UsersManager;

/**
 * Action starting generation of the program's catalog in PDF format
 */
public class GeneratePDFAction extends ServiceableAction implements Contextualizable, Configurable
{
    /** The component configuration. */
    protected Configuration _configuration;
    
    /** The avalon context. */
    protected Context _context;
    
    /** The logger. */
    protected Logger _logger;
    
    /** The timer. */
    protected Timer _timer;
    
    /** The manager */
    protected ServiceManager _manager;
 
    /** The current user provider */
    protected CurrentUserProvider _currentUserProvider;

    /** The users manager */
    protected UsersManager _usersManager;

    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _configuration = configuration;
    }
    
    @Override
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public void service(ServiceManager sManager) throws ServiceException
    {
        _manager = sManager;
        _currentUserProvider = (CurrentUserProvider) sManager.lookup(CurrentUserProvider.ROLE);
        _usersManager = (UsersManager) sManager.lookup(UsersManager.ROLE);
    }
    
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        if (GeneratePDFEngine.isRunning())
        {
            return Collections.singletonMap("error", "already-running");
        }
        else
        {
            GeneratePDFEngine generatePDFEngine = new GeneratePDFEngine();
            
            Request request = ObjectModelHelper.getRequest(objectModel);
            String lang = request.getParameter("lang");
            
            if (StringUtils.isEmpty(lang))
            {
                lang = Config.getInstance().getValueAsString("odf.programs.lang");
            }
            
            String login = _currentUserProvider.getUser();
            User currentUser = _usersManager.getUser(login);
            
            generatePDFEngine.setLanguage(lang);
            generatePDFEngine.setCatalog(source);
            generatePDFEngine.setMailTo(currentUser.getEmail());
            
            try
            {
                // Initialize and configure the engine.
                generatePDFEngine.initialize(_manager, _context);
                
                // Create the thread, mark it as daemon and start it.
                Thread engineThread = new Thread(generatePDFEngine, "GeneratePDFEngine");
                engineThread.setDaemon(true);
                engineThread.start();
                
                return EMPTY_MAP;
            }
            catch (Exception e)
            {
                throw new RuntimeException("Unable to initialize the generate pdf engine", e);
            }
        }
    }
}
