/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.export.pdf;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.odf.catalog.Catalog;
import org.ametys.odf.catalog.CatalogsManager;

/**
 * Get the name of catalog from source.
 * If "_default" keyword is used, get the name of first catalog.
 */
public class GetCatalogNameAction extends ServiceableAction
{
    private CatalogsManager _catalogManager;
    
    @Override
    public void service(ServiceManager sManager) throws ServiceException
    {
        super.service(sManager);
        _catalogManager = (CatalogsManager) sManager.lookup(CatalogsManager.ROLE);
    }
    
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Map<String, String> result = new HashMap<String, String>();
        
        if ("_default".equals(source))
        {
            Catalog catalog = _catalogManager.getCatalogs().get(0); // Get the first catalog, to use when there is only one catalog
            result.put("catalog", catalog.getName());
        }
        else
        {
            result.put("catalog", source);
        }
        
        return result;
    }

}
