/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.oai;

import java.io.IOException;
import java.util.Arrays;
import java.util.Collection;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.odf.enumeration.OdfEnumerationHelper;
import org.ametys.odf.orgunit.RootOrgUnitProvider;
import org.ametys.odf.program.Program;
import org.ametys.plugins.repository.AmetysObjectIterable;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.query.QueryHelper;
import org.ametys.plugins.repository.query.expression.Expression.Operator;
import org.ametys.plugins.repository.query.expression.StringExpression;

/**
 * Generator for the <code>GetRecord</code> verb.
 */
public class GetRecordGenerator extends OAIVerbGenerator implements Serviceable
{
    private OdfEnumerationHelper _enumerationHelper;
    private RootOrgUnitProvider _rootOrgUnitProvider;
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        _enumerationHelper = (OdfEnumerationHelper) serviceManager.lookup(OdfEnumerationHelper.ROLE);
        _rootOrgUnitProvider = (RootOrgUnitProvider) serviceManager.lookup(RootOrgUnitProvider.ROLE);
        _resolver = (AmetysObjectResolver) serviceManager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    protected Collection<String> getRequiredParameters()
    {
        return Arrays.asList("verb", "identifier", "metadataPrefix");
    }

    @Override
    protected Collection<String> getAllowedParameters()
    {
        return Arrays.asList("verb", "identifier", "metadataPrefix");
    }

    @Override
    protected void generateVerb() throws IOException, SAXException, ProcessingException
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        String identifier = request.getParameter("identifier");
        String metadataPrefix = request.getParameter("metadataPrefix");
        
        if (!metadataPrefix.equals("cdm") && !metadataPrefix.equals("oai_dc"))
        {
            generateError("cannotDisseminateFormat", "The value of the metadataPrefix argument is not supported by the repository.");
            return;
        }
        
        String prefix = "FRUAI" + _rootOrgUnitProvider.getRoot().getUAICode() + "PR";
        
        if (prefix.length() > identifier.length())
        {
            generateError("idDoesNotExist", "The value of the identifier argument is malformed");
            return;
        }
        
        String cdmId = identifier.substring(prefix.length());
        
        String query = QueryHelper.getXPathQuery(null, "ametys:programContent", new StringExpression("cdmCode", Operator.EQ, cdmId));
        
        AmetysObjectIterable<Program> programs = _resolver.query(query);
        
        if (!programs.hasNext())
        {
            generateError("idDoesNotExist", "The value of the identifier argument is unknown");
            return;
        }
        
        Program program = programs.next();
        
        XMLUtils.startElement(contentHandler, "GetRecord");
        
        RecordHelper.saxProgram(program, contentHandler, metadataPrefix, _enumerationHelper, _rootOrgUnitProvider);
        
        XMLUtils.endElement(contentHandler, "GetRecord");
    }
}
