/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.observation;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.logger.Logger;

import org.ametys.cms.observation.Event;
import org.ametys.cms.observation.ObservationConstants;
import org.ametys.cms.observation.Observer;
import org.ametys.odf.CallWSHelper;
import org.ametys.odf.program.AbstractProgram;
import org.ametys.odf.program.Program;
import org.ametys.runtime.config.Config;
import org.ametys.runtime.util.LoggerFactory;

/**
 * Observes {@link Program} content deletion in order to synchronize with remote server
 */
public class RemoteProgramDeletedObserver implements Observer
{
    private static Logger _logger = LoggerFactory.getLoggerFor(RemoteProgramDeletedObserver.class.getName());
    
    @Override
    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.CONTENT_DELETING) && Config.getInstance().getValueAsBoolean("odf.publish.server") && event.getTarget() instanceof Program;
    }

    @Override
    public int getPriority(Event event)
    {
        return 0;
    }

    @Override
    public void observe(Event event)
    {
        Program program = (Program) event.getTarget();
        
        Map<String, String> params = new HashMap<String, String>();
        params.put(AbstractProgram.CDM_CODE, program.getCdmCode());
        
        // Delete program on remote application
        CallWSHelper.callWS("_odf-sync/delete-program", params, _logger);
    }

}
