/*
 *  Copyright 2009 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.orgunit;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Component to provide the root OrgUnit
 */
public class RootOrgUnitProvider extends AbstractLogEnabled implements Component, Serviceable
{
    /** Avalon role. */
    public static final String ROLE = RootOrgUnitProvider.class.getName();
    
    private AmetysObjectResolver _resolver;
    
    private String _rootID;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        _resolver = (AmetysObjectResolver) smanager.lookup(AmetysObjectResolver.ROLE);
    }
    
    /**
     * Set the OrgUnits root id
     * @param rootID the root id
     */
    public void setRootId (String rootID)
    {
        _rootID = rootID;
    }
    
    /**
     * Get the root id
     * @return the root id
     */
    public String getRootId ()
    {
        return _rootID;
    }
    
    /**
     * Returns the root {@link OrgUnit}.
     * @return the root {@link OrgUnit}.
     */
    public OrgUnit getRoot()
    {
        if (_rootID != null)
        {
            return _resolver.resolveById(_rootID);
        }
        
        return null;
    }
    
    /**
     * Determines the given id is the root orgunit id
     * @param id the id to test
     * @return true if is root
     */
    public boolean isRoot (String id)
    {
        return id.equals(_rootID);
    }
    
    /**
     * Determines the given orgunit is the root orgunit
     * @param orgUnit the orgunit to test
     * @return true if is root
     */
    public boolean isRoot (OrgUnit orgUnit)
    {
        return orgUnit.getId().equals(_rootID);
    }
}
