/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.orgunit.actions;

import javax.jcr.RepositoryException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.repository.Content;
import org.ametys.odf.course.actions.AbstractDeleteOdfAction;
import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.odf.orgunit.RootOrgUnitProvider;

/**
 * Delete a {@OrgUnit}
 */
public class DeleteOrgUnitAction extends AbstractDeleteOdfAction
{
    /** The root orgunit provider */
    private RootOrgUnitProvider _rootOrgUnitProvider;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _rootOrgUnitProvider = (RootOrgUnitProvider) smanager.lookup(RootOrgUnitProvider.ROLE);
    }
    
    @Override
    protected void doSpecificBeforeDeletion(Content content) throws RepositoryException
    {
        // Nothing
    }
    
    @Override
    protected boolean hasReferences(Content content) throws RepositoryException
    {
        if (content instanceof OrgUnit)
        {
            return !((OrgUnit) content).getSubOrgUnits().isEmpty() || _rootOrgUnitProvider.isRoot((OrgUnit) content);
        }
        
        return false;
    }
    
    
   
}
