/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.orgunit.actions;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.lang.StringUtils;

import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Check if the parents orgunits are valid
 *
 */
public class IsHierarchyValidAction extends ServiceableAction
{
    /** Ametys object resolver. */
    protected AmetysObjectResolver _resolver;

    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _resolver = (AmetysObjectResolver) serviceManager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Map<String, String> result = new HashMap<String, String>();
        
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        List<String> contentsId = (List<String>) jsParameters.get("contentId");
        
        List<String> ouWithInvalidParents = new ArrayList<String>();
        for (String contentId : contentsId)
        {
            OrgUnit ou = _resolver.resolveById(contentId);
            
            OrgUnit parentOU = ou.getParentOrgUnit();
            while (parentOU != null)
            {
                if (parentOU.getCurrentStepId() != 3)
                {
                    ouWithInvalidParents.add(ou.getTitle());
                    parentOU = null;
                }
                else
                {
                    parentOU = parentOU.getParentOrgUnit();
                }
            }
        }
        
        result.put("ou-invalid-hierarchy", StringUtils.join(ouWithInvalidParents.toArray(new String[ouWithInvalidParents.size()]), ", "));
        return result;
    }

}
