/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.orgunit.actions;

import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Moves a {@link OrgUnit}
 *
 */
public class MoveOrgUnitAction extends ServiceableAction
{
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _resolver = (AmetysObjectResolver) serviceManager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);

        String id = request.getParameter("id");
        String oldParent = request.getParameter("oldParent");
        String newParent = request.getParameter("newParent");
        
        OrgUnit orgUnit = _resolver.resolveById(id);
        OrgUnit oldParentOrgUnit = _resolver.resolveById(oldParent);
        OrgUnit newParentOrgUnit = _resolver.resolveById(newParent);
        
        newParentOrgUnit.addSubOrgUnit(orgUnit.getId());
        oldParentOrgUnit.removeSubOrgUnit(orgUnit.getId());
        
        newParentOrgUnit.saveChanges();
        oldParentOrgUnit.saveChanges();
        
        return EMPTY_MAP;
    }

}
