/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.orgunit.generators;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.cms.repository.Content;
import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.odf.orgunit.RootOrgUnitProvider;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.UnknownAmetysObjectException;

/**
 * Get an {@link OrgUnit} id from its path
 */
public class ConvertOrgUnitPathToId extends ServiceableGenerator
{
    /** The root orgunit provider */
    protected RootOrgUnitProvider _rootOrgUnitProvider;
    
    private AmetysObjectResolver _resolver;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _resolver = (AmetysObjectResolver) smanager.lookup(AmetysObjectResolver.ROLE);
        _rootOrgUnitProvider = (RootOrgUnitProvider) manager.lookup(RootOrgUnitProvider.ROLE);
    }
    
    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        
        String path = (String) jsParameters.get("path");
        
        contentHandler.startDocument();
        
        try
        {
            if (path != null)
            {
                String name = path.lastIndexOf("/") > 0 ? path.substring(path.lastIndexOf("/")) : path;
                // FIXME et dans le cas du web ??
                Content ou = _resolver.resolve("/ametys:odf/ametys:contents/" + name);
                
                XMLUtils.createElement(contentHandler, "content", ou.getId());
            }
            else
            {
                Content ou = _rootOrgUnitProvider.getRoot();
                XMLUtils.createElement(contentHandler, "content", ou.getId());
            }
        }
        catch (UnknownAmetysObjectException e)
        {
            XMLUtils.createElement(contentHandler, "content");
        }
        
        contentHandler.endDocument();
    }
}
