/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.orgunit.generators;

import java.util.List;

import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.generation.Generator;
import org.apache.commons.lang.StringUtils;
import org.xml.sax.SAXException;

import org.ametys.cms.repository.Content;
import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.odf.program.generators.ProgramContentGenerator;

/**
 * {@link Generator} for rendering raw content data for a {@link OrgUnit}.
 */
public class OrgUnitContentGenerator extends ProgramContentGenerator
{
    @Override
    protected void _saxOtherData(Content content) throws SAXException, ProcessingException
    {
        super._saxOtherData(content);
        
        boolean isEditionMetadataSet = parameters.getParameterAsBoolean("isEditionMetadataSet", false);
        if (!isEditionMetadataSet)
        {
            if (content instanceof OrgUnit)
            {
                OrgUnit orgunit = (OrgUnit) content;
                
                List<String> contactIds = orgunit.getContacts();
                for (String contactId : contactIds)
                {
                    if (StringUtils.isNotEmpty(contactId))
                    {
                        saxPersonContent("contact", contactId);
                    }
                }
    
                List<String> orgUnits = orgunit.getSubOrgUnits();
                saxOrgUnits(orgUnits);
    
            }
        }
        
        Request request = ObjectModelHelper.getRequest(objectModel);
        request.setAttribute(Content.class.getName(), content);
    }
    
}
