/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.orgunit.generators;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.odf.orgunit.RootOrgUnitProvider;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * SAX a {@link OrgUnit}
 * 
 */
public class OrgUnitGenerator extends ServiceableGenerator
{
    /** The Ametys object resolver */
    protected AmetysObjectResolver _resolver;
    /** The OrgUnit root provider */
    protected RootOrgUnitProvider _orgUnitProvider;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _resolver = (AmetysObjectResolver) smanager.lookup(AmetysObjectResolver.ROLE);
        _orgUnitProvider = (RootOrgUnitProvider) smanager.lookup(RootOrgUnitProvider.ROLE);
    }

    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        String[] ids = request.getParameterValues("id");

        contentHandler.startDocument();
        XMLUtils.startElement(contentHandler, "orgunits");
        
        for (String id : ids)
        {
            OrgUnit orgunit = null;
            if (id.equalsIgnoreCase("root"))
            {
                orgunit = _orgUnitProvider.getRoot();
            }
            else
            {
                orgunit = _resolver.resolveById(id);
            }
            _sax(orgunit);
        }

        XMLUtils.endElement(contentHandler, "orgunits");
        contentHandler.endDocument();
    }

    /**
     * SAX a {@link OrgUnit}
     * 
     * @param orgunit The orgunit to SAX
     * @throws SAXException if an error occurred while SAXing
     */
    protected void _sax(OrgUnit orgunit) throws SAXException
    {
        AttributesImpl attr = new AttributesImpl();

        attr.addCDATAAttribute("name", orgunit.getName());
        attr.addCDATAAttribute("title", orgunit.getTitle());
        attr.addCDATAAttribute("id", orgunit.getId());

        XMLUtils.createElement(contentHandler, "orgunit", attr);
    }

}
