/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.person;

import java.util.Collection;
import java.util.Map;

import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

import org.ametys.odf.person.ldap.LdapEntity;

/**
 * 
 * Abstraction for getting users list and verify the presence of a particular user.
 *
 */
public interface ContactManager
{
    /** Avalon role. */
    public static final String ROLE = ContactManager.class.getName();
    
    /**
     * Get the list of all users.
     * @return list of users as Collection of <code>LdapEntity</code>s, empty if a problem occurs.
     */
    public Collection<LdapEntity> getPersons();

    /**
     * Get a particular user by his login.
     * @param login Login of the user to get. Cannot be null.
     * @return User's information as a <code>LdapEntity</code> instance or null if the user login does not exists.
     */
    public LdapEntity getPerson(String login);
    
    /**
     * Sax a particular user
     * @param login the login of the user. Cannot be null.
     * @param handler The content handler to sax in.
     * @throws SAXException If an error occurs while saxing.
     */
    public void saxPerson(String login, ContentHandler handler) throws SAXException;
    
    /**
     * Sax the user list.
     * @param handler The content handler to sax in.
     * @param count The maximum number of users to sax. (-1 to sax all)
     * @param offset The offset to start with, first is 0.
     * @param parameters Parameters for saxing user list differently, see implementation.
     * @throws SAXException If an error occurs while saxing.
     */
    public void toSAX(ContentHandler handler, int count, int offset, Map parameters) throws SAXException;
    
    /**
     * Return the xpath query allowing to check if a person already exists
     * @param login
     * @return String
     */
    public String getXPathQueryForPerson(String login);
}
