/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.person.generators;

import org.apache.cocoon.environment.Request;

import org.ametys.cms.contenttype.ContentType;
import org.ametys.cms.contenttype.MetadataDefinitionReference;
import org.ametys.cms.contenttype.MetadataSet;
import org.ametys.cms.contenttype.MetadataType;
import org.ametys.odf.person.Person;
import org.ametys.plugins.repository.query.expression.Expression;
import org.ametys.plugins.repository.query.expression.OrExpression;
/**
 * Search the {@link Person}s matching criteria passed in request parameters
 * 
 */
public class PersonSearchForWidgetGenerator extends PersonSearchGenerator
{
    @Override
    protected Expression getMetadataExpression(Request request)
    {
        String criteria = request.getParameter("criteria");
        
        Expression lastNameExpr = getWildcardExpression(MetadataType.STRING, Person.NAME, criteria);
        Expression loginExpr = getWildcardExpression(MetadataType.STRING, Person.LOGIN, criteria);
        
        return new OrExpression(lastNameExpr, loginExpr);
    }
    
    @Override
    protected MetadataSet getMetadataToSAX(Request request, ContentType contentType)
    {
        MetadataSet metadataSet = new MetadataSet();
        
        metadataSet.addElement(new MetadataDefinitionReference(Person.LOGIN));
        metadataSet.addElement(new MetadataDefinitionReference(Person.NAME));
        metadataSet.addElement(new MetadataDefinitionReference(Person.GIVEN_NAME));
        metadataSet.addElement(new MetadataDefinitionReference(Person.TITLE));
        
        return metadataSet;
    }
}


