/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.person.generators;

import org.apache.cocoon.environment.Request;

import org.ametys.cms.contenttype.MetadataType;
import org.ametys.cms.repository.ContentTypeExpression;
import org.ametys.odf.person.Person;
import org.ametys.odf.person.PersonFactory;
import org.ametys.odf.program.generators.ProgramSearchGenerator;
import org.ametys.plugins.repository.query.SortCriteria;
import org.ametys.plugins.repository.query.expression.Expression;
import org.ametys.plugins.repository.query.expression.Expression.Operator;
import org.ametys.plugins.repository.query.expression.OrExpression;
/**
 * Search the {@link Person}s matching criteria passed in request parameters
 * 
 */
public class PersonSearchGenerator extends ProgramSearchGenerator
{
    @Override
    protected Expression createContentTypeExpressions(Request request)
    {
        return new ContentTypeExpression(Operator.EQ, PersonFactory.PERSON_CONTENT_TYPE);
    }
    
    @Override
    protected String getXPathQuery(Request request)
    {
        Expression expr = createExpression(request);
        SortCriteria sortCriteria = getSortCriteria(request);
        
        return org.ametys.plugins.repository.query.QueryHelper.getXPathQuery(null, PersonFactory.PERSON_NODETYPE, expr, sortCriteria);
    }

    @Override
    protected Expression getWildcardExpression(MetadataType type, String metadataName, String value)
    {
        if (Person.NAME.equals(metadataName))
        {
            Expression expr1 = super.getWildcardExpression(type, metadataName, value);
            Expression expr2 = super.getWildcardExpression(type, Person.GIVEN_NAME, value);
            Expression expr3 = super.getWildcardExpression(type, Person.TITLE, value);
            return new OrExpression(expr1, expr2, expr3);
        }
        else
        {
            return super.getWildcardExpression(type, metadataName, value);
        }
    }

}


