/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.program;

import javax.jcr.Node;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.odf.SynchronizableTraversableContentFactory;
import org.ametys.odf.cdmfr.ExportCDMfrManager;
import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.repository.RepositoryConstants;

/**
 * {@link ContainerFactory} for handling {@link Container}
 */
public class ContainerFactory extends SynchronizableTraversableContentFactory
{
    /** {@link Program} nodetype for resources collection */
    public static final String CONTAINER_NODETYPE = RepositoryConstants.NAMESPACE_PREFIX + ":container";

    /** {@link Program} content type */
    public static final String CONTAINER_CONTENT_TYPE = "org.ametys.plugins.odf.Content.container";
    
    private ExportCDMfrManager _exportCDMfrManager;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _exportCDMfrManager = (ExportCDMfrManager) manager.lookup(ExportCDMfrManager.ROLE);
    }
    
    @Override
    public Container getAmetysObject(Node node, String parentPath) throws AmetysRepositoryException
    {
        return new Container(node, parentPath, this);
    }
    
    ExportCDMfrManager _getExportCDMfrManager()
    {
        return _exportCDMfrManager;
    }
}
