/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.program;

import javax.jcr.Node;

import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

import org.ametys.odf.cdmfr.CDMEntity;
import org.ametys.odf.enumeration.OdfEnumerationHelper;
import org.ametys.plugins.repository.AmetysRepositoryException;

/**
 * Program.
 */
public class Program extends AbstractProgram<ProgramFactory> implements CDMEntity
{
    /** Constants for metadata 'catalog' */
    public static final String CATALOG = "catalog";
    
    /**
     * Constructor.
     * @param node the JCR Node backing this Content.
     * @param parentPath the parent path in the Ametys hierarchy.
     * @param factory the corresponding {@link ProgramFactory}.
     */
    public Program(Node node, String parentPath, ProgramFactory factory)
    {
        super(node, parentPath, factory);
    }
    
    @Override
    public String getTagName()
    {
        return TAG_PROGRAM;
    }
    
    /**
     * Get the catalog of this {@link Program}
     * @return the catalog or null if not set
     */
    public String getCatalog()
    {
        return getString(CATALOG);
    }

    /**
     * Set the catalog
     * @param catalog the catalog to set
     * @throws AmetysRepositoryException if an error occurred
     */
    public void setCatalog(String catalog) throws AmetysRepositoryException
    {
        getMetadataHolder().setMetadata(CATALOG, catalog);
    }
    
    @Override
    @Deprecated
    public void toCDM(ContentHandler contentHandler, OdfEnumerationHelper provider, String rootOrgUnitId) throws SAXException
    {
        _getFactory()._getExportCDMfrManager().program2CDM(contentHandler, this);
    }
}
