/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.program;

import java.util.Set;

import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

import org.ametys.odf.course.Course;
import org.ametys.odf.courselist.CourseListContainer;
import org.ametys.odf.enumeration.OdfEnumerationHelper;
import org.ametys.odf.orgunit.OrgUnit;
import org.ametys.odf.person.Person;
import org.ametys.plugins.repository.jcr.JCRTraversableAmetysObject;

/**
 * Represents a part of a {@link Program}, be it the Program itself, a {@link SubProgram} or a {@link Container}.
 */
public interface ProgramPart extends JCRTraversableAmetysObject, CourseListContainer
{
    /**
     * Returns the CDM id.
     * @return the CDM id.
     */
    public String getCDMId();
    
    /**
     * Send the CDM-fr representation of thei ProgramPart to the given Contenthandler.<br>
     * Also collects referenced orgUnits, persons and courses, so that they could be sent afterwards.
     * @param contentHandler the receiving contentHandler.
     * @param provider the {@link OdfEnumerationHelper}.
     * @param persons collected {@link Person} ids.
     * @param orgUnits collected {@link OrgUnit} ids.
     * @param courses collected {@link Course} ids.
     * @throws SAXException if an error occurs during CDM processing.
     */
    public void toCDM(ContentHandler contentHandler, OdfEnumerationHelper provider, Set<String> persons, Set<String> orgUnits, Set<String> courses) throws SAXException;
}
