/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.program.actions;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.cms.workflow.AbstractContentWorkflowComponent;
import org.ametys.odf.course.Course;
import org.ametys.odf.course.CourseContainer;
import org.ametys.odf.courselist.CourseList;
import org.ametys.odf.program.Program;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.jcr.DefaultAmetysObject;
import org.ametys.plugins.workflow.Workflow;

import com.opensymphony.workflow.spi.Step;

/**
 * Add an {@link Course} into a {@link CourseContainer} object
 */
public class AddCourseAction extends ServiceableAction
{
    private AmetysObjectResolver _resolver;
    private Workflow _workflow;
    
    @Override
    public void service(ServiceManager sManager) throws ServiceException
    {
        super.service(sManager);

        _resolver = (AmetysObjectResolver) sManager.lookup(AmetysObjectResolver.ROLE);
        _workflow = (Workflow) sManager.lookup(Workflow.ROLE);
    }

    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        Map<String, String> result = new HashMap<String, String>();

        String id = (String) jsParameters.get("id");
        List<String> courseIds = (List<String>) jsParameters.get("courseIds");

        assert id != null;
        
        DefaultAmetysObject object = _resolver.resolveById(id);

        if (object instanceof CourseContainer)
        {
            for (String courseId : courseIds)
            {
                if (!((CourseContainer) object).hasCourse(courseId))
                {
                    ((CourseContainer) object).addCourse(courseId);
                }
            }
        }
        
        object.saveChanges();
        
        // Invalidate parent programs
        if (object instanceof CourseList)
        {
            List<Program> referencingPrograms = ((CourseList) object).getReferencingPrograms();
            for (Program program : referencingPrograms)
            {
                if (program.getCurrentStepId() != 1)
                {
                    Map<String, Object> inputs = new HashMap<String, Object>();
                    inputs.put(AbstractContentWorkflowComponent.RESULT_MAP_KEY, new HashMap<String, Object>());
                    inputs.put(AbstractContentWorkflowComponent.CONTENT_KEY, program);
                    _workflow.doAction(program.getWorkflowId(), 22, inputs);
                    
                    Step currentStep = (Step) _workflow.getCurrentSteps(program.getWorkflowId()).iterator().next();
                    program.setCurrentStepId(currentStep.getStepId());
                    
                    program.saveChanges();
                }
            }
        }

        return result;
    }
}
