/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.Set;

import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.DefaultContent;
import org.ametys.cms.repository.WorkflowStepExpression;
import org.ametys.cms.workflow.WorkflowTasksComponent;
import org.ametys.plugins.repository.AmetysObjectIterable;
import org.ametys.plugins.repository.query.SortCriteria;
import org.ametys.plugins.repository.query.expression.AndExpression;
import org.ametys.plugins.repository.query.expression.Expression;
import org.ametys.plugins.repository.query.expression.Expression.Operator;
import org.ametys.plugins.repository.query.expression.OrExpression;
import org.ametys.plugins.repository.query.expression.StringExpression;
import org.ametys.runtime.user.User;

/**
 * Override WorkflowTasksComponent to target ODF contents
 */
public abstract class AbstractOdfWorkflowTasksComponent extends WorkflowTasksComponent
{
    @Override
    protected AmetysObjectIterable<Content> _getContents(TaskStep step, User user)
    {
        Expression expr = null;
        Set<Integer> stepIds = step.getStepIds();
        for (Integer stepId : stepIds)
        {
            Expression stepExpr = new WorkflowStepExpression(Operator.EQ, stepId);
            expr = expr == null ? stepExpr : new OrExpression(expr, stepExpr);
        }
        
        Expression contentExpr = null;
        if (step.getUserContentsOnly())
        {
            contentExpr = new StringExpression(DefaultContent.METADATA_CONTRIBUTOR, Operator.EQ, user.getName());
            expr = new AndExpression(expr, contentExpr);
        }

        Expression contentTypeExpr = getContentTypeExpression();
        expr = new AndExpression(expr, contentTypeExpr);
        
        SortCriteria sort = new SortCriteria();
        sort.addCriterion(DefaultContent.METADATA_MODIFIED, false, false);
        String xpathQuery = org.ametys.plugins.repository.query.QueryHelper.getXPathQuery(null, "ametys:content", expr, sort);

        return _objectResolver.query(xpathQuery);
    }
    
    /**
     * Get the content type expression concerned by this component
     * @return the content type expression
     */
    protected abstract Expression getContentTypeExpression ();

}
