/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.activity.Initializable;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.environment.Request;

import org.ametys.cms.repository.WorkflowAwareContent;
import org.ametys.cms.workflow.AbstractContentWorkflowComponent;
import org.ametys.odf.program.Container;
import org.ametys.odf.program.Program;
import org.ametys.odf.program.SubProgram;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.workflow.Workflow;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.FunctionProvider;
import com.opensymphony.workflow.WorkflowException;
import com.opensymphony.workflow.spi.Step;

/**
 * OSWorkflow function to edit a {@link Program} content.
 */
public class ChangeProgramStateFunction extends AbstractContentWorkflowComponent implements FunctionProvider, Initializable
{
    private static final int __EDIT_WORKFLOW_ACTION_ID = 22;
    
    /** Workflow instance. */
    protected Workflow _workflow;
    
    /** Ametys object resolver. */
    protected AmetysObjectResolver _resolver;
    
    public void initialize() throws Exception
    {
        _workflow = (Workflow) _manager.lookup(Workflow.ROLE);
    }
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    public void execute(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        // Retrieve current content
        WorkflowAwareContent content = getContent(transientVars);
        
        if (content instanceof SubProgram || content instanceof Container)
        {
            // retrieve the program parent
            AmetysObject parent = content.getParent();
            while (!(parent instanceof Program))
            {
                parent = parent.getParent();
            }
            try
            {
                if (((WorkflowAwareContent) parent).getCurrentStepId() != 1)
                {
                    Map<String, Object> inputs = new HashMap<String, Object>();
                    inputs.put(AbstractContentWorkflowComponent.RESULT_MAP_KEY, new HashMap<String, Object>());
                    inputs.put(AbstractContentWorkflowComponent.CONTENT_KEY, parent);
                    _workflow.doAction(((WorkflowAwareContent) parent).getWorkflowId(), __EDIT_WORKFLOW_ACTION_ID, inputs);
                    
                    Step currentStep = (Step) _workflow.getCurrentSteps(((WorkflowAwareContent) parent).getWorkflowId()).iterator().next();
                    ((Program) parent).setCurrentStepId(currentStep.getStepId());
                    
                    ((Program) parent).saveChanges();
                }
            }
            catch (AmetysRepositoryException e)
            {
                // FIXME : le current step n'existe pas si la formation viens d'etre créée.
            }
        }
    }

    /**
     * Retrieve the content associated with the workflow.
     * @param transientVars the parameters from the call.
     * @return the content.
     * @throws WorkflowException if the content is not found.
     */
    @Override
    protected WorkflowAwareContent getContent(Map transientVars) throws WorkflowException
    {
        WorkflowAwareContent content = (WorkflowAwareContent) transientVars.get(CONTENT_KEY);
        
        if (content == null)
        {
            Request request = getRequest();
            if (request == null)
            {
                throw new WorkflowException("The request is null, unable to retrieve content");
            }
            
            content = (WorkflowAwareContent) request.getAttribute(CONTENT_KEY);
            
            if (content == null)
            {
                Map<String, Object> map = (Map<String, Object>) transientVars.get(RESULT_MAP_KEY);
                if (map != null)
                {
                    String contentId = (String) map.get("contentId");
                    if (contentId != null)
                    {
                        content = _resolver.resolveById(contentId);
                    }
                    else
                    {
                        throw new WorkflowException("Unable to retrieve content");
                    }
                }
            }
        }
        
        // Found in transient variables map
        return content;
    }
}
