/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.repository.ModifiableContent;
import org.ametys.cms.workflow.AbstractContentWorkflowComponent;
import org.ametys.odf.course.Course;
import org.ametys.odf.course.CourseContainer;
import org.ametys.odf.course.CourseFactory;
import org.ametys.odf.courselist.CourseList;
import org.ametys.odf.program.AbstractProgram;
import org.ametys.odf.program.Program;
import org.ametys.plugins.repository.jcr.DefaultAmetysObject;
import org.ametys.plugins.workflow.Workflow;
import org.ametys.runtime.util.StringUtils;

import com.opensymphony.workflow.WorkflowException;
import com.opensymphony.workflow.spi.Step;

/**
 * OSWorkflow function for creating a {@link Course} content
 */
public class CreateCourseFunction extends CreateODFContentFunction
{
    /** Content name prefix for programs */
    public static final String CONTENT_NAME_PREFIX = "course-";
    
    private Workflow _workflow;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _workflow = (Workflow) manager.lookup(Workflow.ROLE);
    }
    
    @Override
    protected String _getContentNamePrefix()
    {
        return CONTENT_NAME_PREFIX;
    }
    
    @Override
    protected String _getNodeType()
    {
        return CourseFactory.COURSE_NODETYPE;
    }
    
    @Override
    protected void _populateAdditionalData(Map transientVars, ModifiableContent content) throws WorkflowException
    {
        // Set a unique CDM code if not exist
        String cdmCode = content.getMetadataHolder().getString(AbstractProgram.CDM_CODE, null);
        if (org.apache.commons.lang.StringUtils.isEmpty(cdmCode))
        {
            content.getMetadataHolder().setMetadata(AbstractProgram.CDM_CODE, StringUtils.generateKey().toUpperCase());
        }
    }
    
    @Override
    protected void _populateContent(Map transientVars, ModifiableContent content) throws WorkflowException
    {
        super._populateContent(transientVars, content);
        
        String parentId = (String) transientVars.get(CONTENT_PARENT_ID);
        if (parentId != null)
        {
            DefaultAmetysObject parent = _resolver.resolveById(parentId);
            if (parent instanceof CourseContainer)
            {
                ((CourseContainer) parent).addCourse(content.getId());
                parent.saveChanges();
            }
            
            // Invalidate parent programs
            if (parent instanceof CourseList)
            {
                List<Program> referencingPrograms = ((CourseList) parent).getReferencingPrograms();
                for (Program program : referencingPrograms)
                {
                    if (program.getCurrentStepId() != 1)
                    {
                        Map<String, Object> inputs = new HashMap<String, Object>();
                        inputs.put(AbstractContentWorkflowComponent.RESULT_MAP_KEY, new HashMap<String, Object>());
                        inputs.put(AbstractContentWorkflowComponent.CONTENT_KEY, program);
                        _workflow.doAction(program.getWorkflowId(), 22, inputs);
                        
                        Step currentStep = (Step) _workflow.getCurrentSteps(program.getWorkflowId()).iterator().next();
                        program.setCurrentStepId(currentStep.getStepId());
                        
                        program.saveChanges();
                    }
                }
            }
        }
    }
}
