/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.Map;

import org.ametys.cms.repository.ModifiableContent;
import org.ametys.odf.program.AbstractProgram;
import org.ametys.odf.program.Program;
import org.ametys.odf.program.ProgramFactory;
import org.ametys.runtime.util.StringUtils;

import com.opensymphony.workflow.WorkflowException;

/**
 * OSWorkflow function for creating a {@link Program} content.
 */
public class CreateProgramFunction extends CreateODFContentFunction
{
    /** Content name prefix for programs */
    public static final String CONTENT_NAME_PREFIX = "program-";
    
    @Override
    protected String _getContentNamePrefix()
    {
        return CONTENT_NAME_PREFIX;
    }
    
    @Override
    protected String _getNodeType()
    {
        return ProgramFactory.PROGRAM_NODETYPE;
    }
    
    @Override
    protected void _populateAdditionalData(Map transientVars, ModifiableContent content) throws WorkflowException
    {
        // Set a unique CDM code if not exist
        String cdmCode = content.getMetadataHolder().getString(AbstractProgram.CDM_CODE, null);
        if (org.apache.commons.lang.StringUtils.isEmpty(cdmCode))
        {
            content.getMetadataHolder().setMetadata(AbstractProgram.CDM_CODE, StringUtils.generateKey().toUpperCase());
        }
    }
}
