/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.Map;

import javax.jcr.RepositoryException;

import org.ametys.cms.repository.ModifiableContent;
import org.ametys.cms.repository.WorkflowAwareContent;
import org.ametys.cms.workflow.AbstractContentWorkflowComponent;
import org.ametys.plugins.repository.AmetysRepositoryException;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.FunctionProvider;
import com.opensymphony.workflow.WorkflowException;

/**
 * OSWorkflow function for deleting a content.
 */
public class DeleteContentFunction extends AbstractContentWorkflowComponent implements FunctionProvider
{
    public void execute(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        _logger.info("Performing content deletion");
        
        try
        {
            WorkflowAwareContent content = getContent(transientVars);
            if (!(content instanceof ModifiableContent))
            {
                throw new IllegalArgumentException("The provided content " + content.getId() + " is not a ModifiableContent.");
            }
            
            _removeContent((ModifiableContent) content);
        }
        catch (RepositoryException e)
        {
            throw new WorkflowException("Unable to link the workflow to the content", e);
        }
        catch (AmetysRepositoryException e)
        {
            throw new WorkflowException("Unable to delete the content", e);
        }
    }

    /**
     * Deletes the content.
     * @param content the content.
     * @throws WorkflowException if an error occurs.
     * @throws RepositoryException if an error occurs.
     */
    protected void _removeContent(ModifiableContent content) throws WorkflowException, RepositoryException
    {
        content.remove();
        content.saveChanges();
    }
}
