/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import org.ametys.cms.contenttype.ContentType;
import org.ametys.cms.contenttype.MetadataDefinition;
import org.ametys.cms.workflow.AllErrors;
import org.ametys.cms.workflow.EditContentFunction;
import org.ametys.odf.contenttype.ODFContentType;

import com.opensymphony.workflow.WorkflowException;

/**
* OSWorkflow function to edit a ODF content.
*/
public class EditODFContentFunction extends EditContentFunction
{
    @Override
    protected boolean _validateMetadata(ContentType cType, MetadataDefinition metadataDefinition, String metadataPath, AllErrors allErrors, Object value) throws WorkflowException
    {
        if (cType instanceof ODFContentType)
        {
            ODFContentType cTypeODF = (ODFContentType) cType;
            String metadataName = metadataDefinition.getName();
            
            if (!cTypeODF.isSynchronized(metadataName))
            {
                return super._validateMetadata(cType, metadataDefinition, metadataPath, allErrors, value);
            }
            
            // There is no way validate a synchronized metadata : the validation depends on the remote and sync value (the validation must be done in JS)
            return true;
        }
        
        return super._validateMetadata(cType, metadataDefinition, metadataPath, allErrors, value);
    }
}
