/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.List;
import java.util.Map;

import org.apache.cocoon.environment.Request;
import org.apache.commons.lang.StringUtils;

import org.ametys.cms.repository.Content;
import org.ametys.cms.workflow.AbstractContentWorkflowComponent;
import org.ametys.odf.program.Program;
import org.ametys.plugins.workflow.AbstractWorkflowComponent;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.Condition;
import com.opensymphony.workflow.WorkflowException;

/**
 * OSWorkflow condition to check mandatory properties of a {@link Program}.<p>
 */
public class MandatoryProgramMetadataCondition extends AbstractWorkflowComponent implements Condition
{
    
    @Override
    public boolean passesCondition(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        Content content = getContent(transientVars);
        if (content instanceof Program)
        {
            Program program = (Program) content;
            
            // Check orgUnits
            List<String> orgUnits = program.getOrgUnits();
            if (orgUnits.size() == 0 || (orgUnits.size() == 1 && StringUtils.isEmpty(orgUnits.get(0))))
            {
                return false;
            }
        }
        return true;
    }
    
    /**
     * Retrieve the content associated with the workflow.
     * @param transientVars the parameters from the call.
     * @return the content.
     * @throws WorkflowException if the content is not found.
     */
    protected Content getContent(Map transientVars) throws WorkflowException
    {
        Content content = (Content) transientVars.get(AbstractContentWorkflowComponent.CONTENT_KEY);
        
        if (content == null)
        {
            Request request = getRequest();
            if (request == null)
            {
                throw new WorkflowException("The request is null, unable to retrieve content");
            }
            
            // FIXME use CMSContextHandler for retrieving the current matched content
            content = (Content) request.getAttribute(AbstractContentWorkflowComponent.CONTENT_KEY);
            
            if (content == null)
            {
                throw new WorkflowException("Unable to retrieve content");
            }
        }
        
        // Found in transient variables map
        return content;
    }
    
}
