/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.Map;

import org.ametys.cms.repository.Content;
import org.ametys.cms.workflow.ContentCheckRightsCondition;
import org.ametys.odf.program.Container;
import org.ametys.odf.program.SubProgram;
import org.ametys.plugins.repository.AmetysObject;

import com.opensymphony.workflow.WorkflowException;

/**
 * Condition for checking rights of an user for the current action
 * using the right ODF content context.
 */
public class ODFContentCheckRightsCondition extends ContentCheckRightsCondition
{
    @Override
    protected String _computeContext(Map transientVars, Map args, String login, String right) throws WorkflowException
    {
        Content content = getContent(transientVars);
        String ctxSuffixe = content.getName();
        if (content instanceof SubProgram || content instanceof Container)
        {
            AmetysObject parent = content.getParent();
            while (parent instanceof Content)
            {
                ctxSuffixe = parent.getName() + "/" + ctxSuffixe;
                parent = parent.getParent(); 
            }
        }
        
        return "/contents/" + ctxSuffixe;
    }
}
