/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;

import org.ametys.cms.repository.Content;
import org.ametys.odf.SynchronizableContent;
import org.ametys.odf.course.Course;
import org.ametys.odf.program.Container;
import org.ametys.odf.program.Program;
import org.ametys.odf.program.SubProgram;

import com.opensymphony.workflow.WorkflowException;

/**
 * Condition for checking rights of an user for the current action
 * using the right ODF content context.
 */
public class ODFContentWithNoOUCheckRightsCondition extends ODFContentCheckRightsCondition
{
    @Override
    protected String _computeContext(Map transientVars, Map args, String login, String right) throws WorkflowException
    {
        Content content = getContent(transientVars);
        
        if (content instanceof SynchronizableContent)
        {
            List<String> orgUnits = getOrgUnits(content);
            if (orgUnits.isEmpty())
            {
                return "/contributor";
            }
        }
        
        return super._computeContext (transientVars, args, login, right);
    }
    
       /**
        * Get the orgunits for the content
        * @param content the content
        * @return the orgunits in a List
        */
    protected List<String> getOrgUnits (Content content)
    {
        List<String> ouIds = new ArrayList<String>();
        
        if (content instanceof Program)
        {
            ouIds = ((Program) content).getOrgUnits();
        }
        else if (content instanceof SubProgram)
        {
            ouIds = ((SubProgram) content).getOrgUnits();
        }
        else if (content instanceof Container)
        {
            Program program = ((Container) content).getParentProgram();
            ouIds = program.getOrgUnits();
        }
        else if (content instanceof Course)
        {
            ouIds = ((Course) content).getOrgUnits();
        }
        
        // Clear empty id
        List<String> ids = new ArrayList<String>();
        for (String id : ouIds)
        {
            if (StringUtils.isNotEmpty(id))
            {
                ids.add(id);
            }
        }
        return ids;
    }
}
