/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.environment.Redirector;
import org.apache.commons.lang.StringUtils;

import org.ametys.cms.workflow.AbstractContentWorkflowComponent;
import org.ametys.cms.workflow.ContentWorkflowAction;

import com.opensymphony.workflow.InvalidInputException;
import com.opensymphony.workflow.WorkflowException;

/**
 * Action for firing a transition on a content's workflow.<p>
 * The following parameters are supported:
 * <dl>
 *  <dt>actionId
 *  <dd>the id of the action to fire
 * </dl>
 */
public class ValidateProgramWorkflowAction extends ContentWorkflowAction
{
    @SuppressWarnings("unchecked")
    @Override
    protected Map _act(Redirector redirector, Map objectModel, String source, Parameters parameters, int actionId, Map inputs) throws InvalidInputException, WorkflowException
    {
        super._act(redirector, objectModel, source, parameters, actionId, inputs);
        
        Map<String, Object> workflowResult = (Map<String, Object>) inputs.get(AbstractContentWorkflowComponent.RESULT_MAP_KEY);
       
        String hasPublicationError = (String) workflowResult.get("cdmfr-publication-error");
        String pubUrlFailed = (String) workflowResult.get("cdmfr-publication-failed-url");
        String hasExportError = (String) workflowResult.get("cdmfr-export-error");
        
        Object invalidatedContents = workflowResult.get("invalidated-contents");
        
        Map<String, Object> result = new HashMap<String, Object>();
        
        result.put("cdmfr-publication-error", hasPublicationError);
        result.put("cdmfr-publication-failed-url", pubUrlFailed);
        result.put("cdmfr-export-error", hasExportError);
        
        if (invalidatedContents != null)
        {
            Set<String> contents = (Set<String>) invalidatedContents;
            result.put("invalidated-contents", StringUtils.join(contents.toArray(new String[contents.size()]), ", "));
        }
        return result;
    }
    
}
