<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2014 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
-->
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:docbook="http://docbook.org/ns/docbook"
                xmlns:xalan="http://xml.apache.org/xalan"
                xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:cms="http://ametys.org/cms/3.0"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:decoder="org.ametys.cms.transformation.xslt.URIDecoder" 
                exclude-result-prefixes="docbook decoder">
    
    <xsl:template match="/">
        <fo:root>
            <fo:layout-master-set>
                <fo:simple-page-master master-name="page"
                    page-width="210mm" page-height="297mm" margin-left="0cm"
                    margin-right="0cm" margin-top="2cm" margin-bottom="2cm">
                    <fo:region-body margin-top="0cm" margin-bottom="1cm">
                        <xsl:call-template name="region-body-definition"/>
                    </fo:region-body>
                    <fo:region-before extent="1cm">
                        <xsl:call-template name="region-before-definition"/>
                    </fo:region-before>
                    <fo:region-after extent="0.5cm">
                        <xsl:call-template name="region-after-definition"/>
                    </fo:region-after>
                </fo:simple-page-master>
            </fo:layout-master-set>
            
            <!-- Front page -->
            <xsl:call-template name="front-page"/>
            
            <!-- Table of contents -->
            <xsl:call-template name="toc"/>
            
            <!-- Contents -->
            <xsl:call-template name="contents"/>
        </fo:root>
    </xsl:template>
    
    <xsl:variable name="programTree"><xsl:call-template name="program-tree"/></xsl:variable>
    
    <xsl:template name="program-tree">   
        <programs>
            <xsl:for-each select="/programs/enumerated-metadata/items[@metadataName = 'degree']/item">
                <xsl:variable name="degree" select="@code"/>
                <xsl:if test="/programs/program[metadata/degree/@value = $degree]">
                    <degree value="{@code}" label="{.}">
                        <xsl:for-each select="/programs/program[metadata/degree/@value = $degree]">
                            <xsl:sort select="@title" />
                            <xsl:copy-of select="."/>
                        </xsl:for-each>
                    </degree>
                </xsl:if>
            </xsl:for-each>
        </programs>
    </xsl:template>
      
    <!-- +
         | Front page 
         + -->
    <xsl:template name="front-page">
        <fo:page-sequence master-reference="page" force-page-count="no-force">
            <xsl:call-template name="xsl-region-before"/>
            <xsl:call-template name="xsl-region-after"/>
            <fo:flow flow-name="xsl-region-body">
                <xsl:call-template name="front-page-header"/>
                <xsl:call-template name="front-page-image"/>
                <xsl:call-template name="front-page-footer"/>
            </fo:flow>
        </fo:page-sequence>
    </xsl:template>
    
    <xsl:template name="front-page-header">
        <fo:block text-align="center" font-size="25px">
            <fo:block margin-top="0.3cm">
                <i18n:text i18n:key="PLUGINS_ODF_PDF_CATALOG_TITLE" i18n:catalogue="plugin.odf"/>
            </fo:block>
            <fo:block margin-top="0.3cm" font-size="20px">
                <xsl:value-of select="/programs/catalog"/>
            </fo:block>
        </fo:block>
    </xsl:template>
    
    <xsl:template name="front-page-image"/>
    
    <xsl:template name="front-page-footer"/>
       
    <!-- +
         | Table of contents 
         + -->
    <xsl:template name="toc">   
        <fo:page-sequence master-reference="page" force-page-count="no-force">
            <xsl:call-template name="xsl-region-before"/>
            <xsl:call-template name="xsl-region-after"/>
            <fo:flow flow-name="xsl-region-body">
                <fo:block text-align="center" font-size="20px">
                    <i18n:text i18n:key="PLUGINS_ODF_PDF_CATALOG_TABLE_OF_CONTENTS" i18n:catalogue="plugin.odf"/>
                </fo:block>
                
                <xsl:apply-templates select="xalan:nodeset($programTree)/programs/degree" mode="toc"/>
            </fo:flow>
        </fo:page-sequence>
    </xsl:template>
    
    <xsl:template match="degree" mode="toc">
        <fo:block margin-top="0.5cm" margin-right="1.2cm" margin-left="1.2cm" font-size="14px" keep-with-next.within-page="always">
            <!-- <xsl:number level="multiple" count="degree" format="1. "/> -->
            <xsl:value-of select="@label"/>
        </fo:block>
        
         <xsl:apply-templates select="program" mode="toc"/>
    </xsl:template>
    
    <xsl:template match="program" mode="toc">
        <fo:block margin-right="1.2cm" margin-left="2cm" text-align='justify' text-align-last="justify" space-after="3pt">
            <fo:basic-link margin-top="0.7cm" font-size="14px">
                <xsl:variable name="ref"><xsl:call-template name="chapter-reference"/></xsl:variable>
                <xsl:attribute name='internal-destination'>chapter-refid-<xsl:value-of select="$ref"/></xsl:attribute>
                
                <xsl:call-template name="chapter-number"/>
                <xsl:value-of select="@title"/>&#160;<fo:leader leader-pattern='dots' rule-thickness='.2pt' leader-alignment='reference-area' font-size="10pt"/>&#160;
                
                <fo:page-number-citation>
                    <xsl:attribute name='ref-id'>chapter-refid-<xsl:value-of select="$ref"/></xsl:attribute>
                </fo:page-number-citation>
            </fo:basic-link>
        </fo:block>
        
        <xsl:apply-templates select="fo/fo:root/fo:page-sequence//fo:block[@role = 'heading']" mode="toc"/>
    </xsl:template>
    
    <xsl:template name="chapter-number">
        <xsl:number level="multiple" count="degree|program" format="1.1. "/>
    </xsl:template>
    
    <xsl:template name="chapter-reference">
        <xsl:number level="multiple" count="degree|program" format="1.1"/>
    </xsl:template>
    
    <xsl:template match="fo:block[@role = 'heading']" mode="toc">
        <fo:block margin-right="1.2cm" margin-left="2.8cm" text-align='justify' text-align-last="justify" space-after="3pt">
            <fo:basic-link margin-top="0.5cm" font-size="14px">
            
                <xsl:variable name="ref"><xsl:call-template name="ahead-reference"/></xsl:variable>
                <xsl:attribute name='internal-destination'>ahead-refid-<xsl:value-of select="$ref"/></xsl:attribute>
                
                <xsl:call-template name="ahead-number"/>
                <xsl:value-of select="."/>&#160;<fo:leader leader-pattern='dots' rule-thickness='.2pt' leader-alignment='reference-area' font-size="10pt"/>&#160;
                
                <fo:page-number-citation>
                    <xsl:attribute name='ref-id'>ahead-refid-<xsl:value-of select="$ref"/></xsl:attribute>
                </fo:page-number-citation>
            </fo:basic-link>
        </fo:block>
    </xsl:template>
    
    <xsl:template name="ahead-number">
        <xsl:number level="multiple" count="degree|program|fo:block[@role = 'heading']" format="1.1.1. "/>
    </xsl:template>
    
    <xsl:template name="ahead-reference">
        <xsl:number level="multiple" count="degree|program|fo:block[@role = 'heading']" format="1.1.1"/>
    </xsl:template>
    
    <!-- +
         | Contents
         + -->
    <xsl:template name="contents">   
        <fo:page-sequence master-reference="page">
            <xsl:call-template name="xsl-region-before"/>
            <xsl:call-template name="xsl-region-after"/>
                
            <fo:flow flow-name="xsl-region-body">
                <xsl:apply-templates select="xalan:nodeset($programTree)/programs//program/fo/fo:root/fo:page-sequence/fo:flow"/>
                
                <fo:block id="theEnd"/>
            </fo:flow>
        </fo:page-sequence>
    </xsl:template>
    
    <xsl:template match="fo:flow">
        <xsl:if test="position() != 1">
            <fo:block break-after="page" />
        </xsl:if>
    
        <xsl:variable name="ref"><xsl:call-template name="chapter-reference"/></xsl:variable>
        <fo:block id="chapter-refid-{$ref}"></fo:block>
        
        <xsl:apply-templates select="fo:block[not(@id = 'theEnd')]" mode="content"/>
    </xsl:template>
    
    <xsl:template match="@*|node()" mode="content">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="content"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="fo:block[@role = 'internal-chapter']" mode="content">
        <xsl:variable name="flowId" select="generate-id(ancestor::fo:flow[1])"/>
        <fo:block id="{concat($flowId, '-', @id)}"/>
    </xsl:template>
    
    <xsl:template match="fo:basic-link[@internal-destination]" mode="content">
        <xsl:copy>
            <xsl:copy-of select="@*[local-name() != 'internal-destination']"/>
            
            <xsl:variable name="flowId" select="generate-id(ancestor::fo:flow[1])"/>
            <xsl:attribute name='internal-destination'><xsl:value-of select="concat($flowId, '-', @internal-destination)"/></xsl:attribute>
            
            <!-- Remove page numbering and dots -->
            <xsl:apply-templates select="node()[local-name() != 'page-number-citation' and local-name() != 'leader']" mode="content"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="fo:block[@role = 'heading']" mode="content">
        <xsl:variable name="ref"><xsl:call-template name="ahead-reference"/></xsl:variable>
        <ahead><xsl:value-of select="$ref"/></ahead>
        <fo:block id="ahead-refid-{$ref}"></fo:block>
        
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="content"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template name="xsl-region-after">
        <fo:static-content flow-name="xsl-region-after">
            <fo:block margin-left="1cm" margin-right="1cm">
                <xsl:call-template name="main-region-after-block"/>
                
                <fo:table table-layout="fixed" margin-top="0pt" padding-top="0pt">
                    <fo:table-column column-width="4.5cm"/>
                    <fo:table-column column-width="10cm"/>
                    <fo:table-column column-width="4.5cm"/>
                    <fo:table-body>
                        <fo:table-row>
                            <xsl:call-template name="footer-date"/>
                            <xsl:call-template name="footer-text"/>
                            <xsl:call-template name="footer-page-number"/>
                        </fo:table-row>
                    </fo:table-body>
                </fo:table>
            </fo:block>
        </fo:static-content> 
    </xsl:template>
    
    <xsl:template name="footer-date">
        <fo:table-cell>
            <fo:block text-align="left">
                <xsl:variable name="now" select="date:date-time()"/>
                <xsl:number format="01" value="date:day-in-month($now)"/>
                <xsl:text>/</xsl:text>
                <xsl:number format="01" value="date:month-in-year($now)"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select="date:year($now)"/>
            </fo:block>
        </fo:table-cell>
    </xsl:template>
    
    <xsl:template name="footer-text">
        <fo:table-cell>
            <fo:block text-align="center" font-size="5px">
                <i18n:text i18n:key="PLUGINS_ODF_PDF_CATALOG_FOOTER_TEXT" i18n:catalogue="plugin.odf"/>
            </fo:block>
        </fo:table-cell>
    </xsl:template>
    
    <xsl:template name="footer-page-number">
        <fo:table-cell>
            <fo:block text-align="right"><i18n:text i18n:key="PLUGINS_ODF_PDF_CATALOG_FOOTER_PAGE_NUMBER" i18n:catalogue="plugin.odf"/> <fo:page-number /> / <fo:page-number-citation ref-id="theEnd" /></fo:block>
        </fo:table-cell>
    </xsl:template>
    
    <xsl:template name="xsl-region-before">
        <fo:static-content flow-name="xsl-region-before">
              <fo:block-container absolute-position="fixed" left="0in" top="0in" width="21cm" height="29.7cm">
                  <fo:block />
              </fo:block-container>
        </fo:static-content>
    </xsl:template>
    
    <xsl:template name="main-region-after-block">
        <xsl:attribute name="font-size">9px</xsl:attribute>
    </xsl:template>

    <xsl:template name="region-body-definition"/>
    
    <xsl:template name="region-before-definition"/>
    
    <xsl:template name="region-after-definition"/>

</xsl:stylesheet>